(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    281262,       5564]
NotebookOptionsPosition[    276432,       5472]
NotebookOutlinePosition[    277031,       5494]
CellTagsIndexPosition[    276988,       5491]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\"\<Circuit`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.621872063601459*^9, 3.6218720752530003`*^9}, {
  3.621872215193508*^9, 3.621872218724779*^9}},
 CellLabel->
  "In[152]:=",ExpressionUUID->"1e443fd8-a20d-4c31-8983-0abfb52fa59a"],

Cell[BoxData["\<\"Circuit`\"\>"], "Output",
 CellChangeTimes->{{3.813276793990148*^9, 3.813276795265028*^9}, 
   3.8132771016116323`*^9, 3.8132772238400583`*^9, 3.8132773327522383`*^9, 
   3.8132778443594646`*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"f1010c7f-e8d8-461c-b698-023490da1c01"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Circuit", "::", "usage"}], "=", 
   "\"\<Circuit is a package to draw arbitrary circuits.  DrawCircuit is the \
main circuit-drawing function.  It contanins the following functions for \
Circuit Elements: Wire, Node, Resistor, Capacitor, Inductor, Diode, \
DCVoltage, ACVoltage and InlineMeter, and also GraphicsLayering, \
GraphicsLayer, UndershadeWrapper and UndershadeRectangle.  Options for all \
circuit elements are in Options[DrawCircuit].\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DrawCircuit", "::", "usage"}], "=", 
   "\"\<DrawCircuit[\!\(\*StyleBox[\"nodes\",FontSlant->\"Italic\"]\), \
\!\(\*StyleBox[\"conn\",FontSlant->\"Italic\"]\) or \
{\!\(\*SubscriptBox[StyleBox[\"conn\",FontSlant->\"Italic\"], \"1\"]\), \
\!\(\*SubscriptBox[StyleBox[\"conn\",FontSlant->\"Italic\"], \"2\"]\), ...}, \
\!\(\*StyleBox[\"extraElementList\",FontSlant->\"Italic\"]\):{}, \
\!\(\*StyleBox[\"opts\",FontSlant->\"Italic\"]\)] is the main circuit-drawing \
function.\n   \!\(\*StyleBox[\"nodes\",FontSlant->\"Italic\"]\) are specified \
as an association \
\[LeftAssociation]\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \
\"1\"]\)\[Rule]\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \"1\
\"]\),\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \"2\"]\)\
\[Rule]\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"2\"]\),...\[RightAssociation], or as a list \
{{\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \
\"1\"]\),\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"1\"]\)},{\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \"2\"]\
\),\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \"2\"]\)},... } \
or most simply {\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"1\"]\),\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"2\"]\),...}, where the labels are sequential integers.\n   The second entry \
contains a list of connections where each connection has the form: \
{{\!\(\*SubscriptBox[StyleBox[\"node\",FontSlant->\"Italic\"], \
\"1\"]\),\!\(\*SubscriptBox[StyleBox[\"node\",FontSlant->\"Italic\"], \
\"2\"]\)},{\!\(\*SubscriptBox[StyleBox[\"element\",FontSlant->\"Italic\"], \
\"1\"]\),\!\(\*SubscriptBox[StyleBox[\"element\",FontSlant->\"Italic\"], \
\"2\"]\),...}}.\n   \
\!\(\*StyleBox[\"extraElementList\",FontSlant->\"Italic\"]\) is optional \
containing nodes to display and label. Each node has the form \
{\!\(\*StyleBox[\"lbl\",FontSlant->\"Italic\"]\),Node[\!\(\*StyleBox[\"string\
\",FontSlant->\"Italic\"]\),\!\(\*StyleBox[\"opts\",FontSlant->\"Italic\"]\)]}\
.\n   Options of all circuit elements are in Options[DrawCircuit]; this \
allows them to be specified for all elements in a graphic or for a specific \
element. Circuit elements have a size that is rescaled to fit the node \
positions. The scale of the elements is relative to a standard (8 turn) \
resistor having length 1 with a spacer of length 1/4 placed on each side of \
all elements.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GraphicsLayering", "::", "usage"}], "=", 
   "\"\<GraphicsLayering[expr] sorts the graphics labeled by GraphicsLayer \
and then removes the GraphicsLayer labels. Layers are ranked with higher on \
the top\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GraphicsLayer", "::", "usage"}], "=", 
   "\"\<GraphicsLayer[layer,expr] places the graphics expr above or below \
other graphics.  Unlabeled graphics has level zero with the higher layers on \
top.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Resistor", "::", "usage"}], "=", 
   "\"\<Resistor[string,options] is a circuit element. Its specific options \
(in Options[DrawCircuit]) are ResistorFlipped, ResistorTurnNumber, \
ResistorDirectives. Other options are: BaseElementDirectives, \
TextOffsetScale, TextOffset, DefaultTextOffset, ExtraTextArgumentsList and \
WrapperFunction\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Wire", "::", "usage"}], "=", 
   "\"\<Wire[x,opts] is a wire (line) of length x, where Wire[]=Wire[1/2]. \
The specific option is WireDirectives and other the other relevent option is \
WrapperFunction\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Node", "::", "usage"}], "=", 
   "\"\<Node[string,opts] where opts are options from DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Diode", "::", "usage"}], "=", 
   "\"\<Diode[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltage", "::", "usage"}], "=", 
   "\"\<DCVoltage[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are \
found in Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrent", "::", "usage"}], "=", 
   "\"\<DCCurrent[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. IT is a current source. All \
\!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are found in \
Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Capacitor", "::", "usage"}], "=", 
   "\"\<Capacitor[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are \
found in Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Inductor", "::", "usage"}], "=", 
   "\"\<Inductor[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are \
found in Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ACVoltage", "::", "usage"}], "=", 
   "\"\<ACVoltage[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are \
found in Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CurrentArrow", "::", "usage"}], "=", 
   "\"\<CurrentArrow[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are \
found in Options[DrawCircuit]. \>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"InlineMeter", "::", "usage"}], "=", 
   "\"\<DCVoltage[\!\(\*StyleBox[\"label\",FontSlant->\"Italic\"]\),\!\(\*\
StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a circuit element for \
DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are \
found in Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OffsetPoints", "::", "usage"}], "=", 
   "\"\<OffsetPoints[{\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\
\"], \"1\"]\),\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \"2\
\"]\)},\!\(\*StyleBox[\"gap\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\" \
\",FontSlant->\"Italic\"]\)\!\(\*StyleBox[\"fraction\",FontSlant->\"Italic\"]\
\),\!\(\*StyleBox[\"offset\",FontSlant->\"Italic\"]\),\!\(\*StyleBox[\"opts\",\
FontSlant->\"Italic\"]\)] is a circuit element for DrawCircuit. All \
\!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are found in \
Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ground", "::", "usage"}], "=", 
   "\"\<Ground[\!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\)] is a \
circuit element for DrawCircuit. All \
\!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\) are found in \
Options[DrawCircuit].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UnderShadeWrapper", "::", "usage"}], "=", 
   "\"\<UnderShadeWrapper[directives,opts][expr] is an option for a circuit \
element to wrap the element with a copy of itself but with the specified \
directives. It is placed below the element because \
Options[UnderShadeWrapper]={GraphicsLayer\[Rule]-1}\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UnderRectangleWrapper", "::", "usage"}], "=", 
   "\"\<UnderRectangleWrapper[directives,opts][expr]is an option for a \
circuit element to put a recatangle with the specified directives below the \
element. Options[UnderRectangleWrapper]={GraphicsLayer\[Rule]-1,OverLength\
\[Rule]0,OverWidth\[Rule]0}\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CircuitSwitch", "::", "usage"}], "=", 
   "\"\<CircuitSwitch[\!\(\*StyleBox[\"options\",FontSlant->\"Italic\"]\)] is \
a circuit element for DrawCircuit. All \!\(\*StyleBox[\"options\",FontSlant->\
\"Italic\"]\) are found in Options[DrawCircuit].\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.3886582408733397`*^9, 3.388658522838621*^9}, {
   3.388666451490673*^9, 3.388666460927568*^9}, {3.38866668438358*^9, 
   3.38866670056076*^9}, {3.3886667495901127`*^9, 3.388666847070352*^9}, {
   3.388666877512383*^9, 3.3886670423471003`*^9}, {3.388667092561722*^9, 
   3.388667100999569*^9}, {3.388669110693501*^9, 3.3886691255580263`*^9}, {
   3.388669310338039*^9, 3.388669369230874*^9}, {3.388669443255402*^9, 
   3.388669448079892*^9}, {3.3886695305193872`*^9, 3.3886695473963614`*^9}, {
   3.388669625457329*^9, 3.388669672157134*^9}, {3.3886701751680613`*^9, 
   3.3886702258967247`*^9}, {3.390134971026577*^9, 3.390134972263164*^9}, {
   3.390135013502082*^9, 3.390135018988927*^9}, {3.4012085173615828`*^9, 
   3.401208553669104*^9}, {3.401208589028859*^9, 3.401208850445516*^9}, {
   3.403605970677264*^9, 3.403605981249464*^9}, {3.403606011927302*^9, 
   3.403606159237121*^9}, {3.4036062245903*^9, 3.403606359385851*^9}, {
   3.403606416997161*^9, 3.4036064332638893`*^9}, {3.403607295937986*^9, 
   3.4036073830034647`*^9}, {3.403607416887114*^9, 3.403607490041697*^9}, 
   3.403607687375252*^9, {3.403607758678772*^9, 3.403607846922501*^9}, {
   3.40360802355027*^9, 3.4036080575183*^9}, {3.403608393655095*^9, 
   3.4036084842997704`*^9}, {3.4036085154407673`*^9, 3.403608529822206*^9}, {
   3.403608650694624*^9, 3.4036086524127607`*^9}, {3.403629963377969*^9, 
   3.403630107722196*^9}, {3.41182168505982*^9, 3.411821754042466*^9}, {
   3.438342772064332*^9, 3.4383428171223783`*^9}, {3.438457744526113*^9, 
   3.438457761399859*^9}, {3.43845783398841*^9, 3.438457847934724*^9}, {
   3.438475550730275*^9, 3.43847560562823*^9}, {3.438533257984229*^9, 
   3.438533268080351*^9}, {3.4385333065822906`*^9, 3.438533330702385*^9}, {
   3.438533363680187*^9, 3.438533413670622*^9}, {3.438533488403739*^9, 
   3.438533493853194*^9}, {3.438561292902841*^9, 3.4385613465255833`*^9}, {
   3.438561376643714*^9, 3.438561417081418*^9}, {3.4385616599563427`*^9, 
   3.43856166965022*^9}, {3.4385617004303207`*^9, 3.438561722205988*^9}, {
   3.4386017486475677`*^9, 3.43860178015552*^9}, {3.4389046584042253`*^9, 
   3.438904812113071*^9}, {3.438904842652467*^9, 3.4389048962187977`*^9}, 
   3.441805457510467*^9, 3.442086262239058*^9, {3.442086469032359*^9, 
   3.4420864704732847`*^9}, 3.4655930571747227`*^9, 3.46559311351787*^9, 
   3.465593144907406*^9, {3.465593207172619*^9, 3.465593223039661*^9}, {
   3.465594267697193*^9, 3.465594300549534*^9}, {3.465594458801002*^9, 
   3.465594570325433*^9}, {3.4655946155243187`*^9, 3.465594661961608*^9}, {
   3.465594696670368*^9, 3.465594779832048*^9}, {3.4655951992140493`*^9, 
   3.4655953737572107`*^9}, {3.4656026294687366`*^9, 
   3.4656026310326767`*^9}, {3.465602800842848*^9, 3.465602937865286*^9}, {
   3.4656033528994417`*^9, 3.4656033559959908`*^9}, {3.465607347425947*^9, 
   3.465607485717778*^9}, {3.465607537865285*^9, 3.4656075791044292`*^9}, {
   3.465609017146475*^9, 3.465609054235382*^9}, {3.465609191586895*^9, 
   3.465609199378097*^9}, {3.465938606277121*^9, 3.465938623038237*^9}, 
   3.465938703219887*^9, {3.465939804054509*^9, 3.465939809699603*^9}, 
   3.465942987749289*^9, {3.465943289392823*^9, 3.4659433672906322`*^9}, 
   3.465988616058826*^9, {3.465988699415959*^9, 3.465988703439335*^9}, 
   3.465988795624021*^9, {3.465989077770883*^9, 3.465989080826975*^9}, {
   3.465989374930913*^9, 3.465989393233678*^9}, {3.465989489251004*^9, 
   3.465989550846183*^9}, {3.465989591840188*^9, 3.4659896227900057`*^9}, {
   3.465989880516714*^9, 3.465989913716313*^9}, {3.46599040171961*^9, 
   3.4659904554468193`*^9}, {3.465990526696587*^9, 3.465990586647784*^9}, {
   3.4659906405200853`*^9, 3.465990771614661*^9}, 3.465991091207984*^9, {
   3.4659943487780724`*^9, 3.4659943518052483`*^9}, 3.4659968838021183`*^9, {
   3.465997069320036*^9, 3.4659971194468822`*^9}, {3.4659972069367857`*^9, 
   3.465997208433354*^9}, {3.465997277736758*^9, 3.465997286269699*^9}, {
   3.465997322095264*^9, 3.4659973546093063`*^9}, 3.465997391491983*^9, {
   3.4659975353341846`*^9, 3.465997544207633*^9}, {3.4660057946909*^9, 
   3.466005815719923*^9}, {3.466005977165887*^9, 3.466006024440464*^9}, {
   3.4660060559922132`*^9, 3.466006140580666*^9}, {3.4660152032761908`*^9, 
   3.4660152044584827`*^9}, {3.466015259632201*^9, 3.466015288808358*^9}, {
   3.466390520543336*^9, 3.4663905212718563`*^9}, {3.466419682747992*^9, 
   3.466419692645567*^9}, {3.466425157710904*^9, 3.46642516949927*^9}, {
   3.466426440463602*^9, 3.466426444077189*^9}, {3.4665992775338087`*^9, 
   3.466599280584593*^9}, {3.466629992591864*^9, 3.466630015605693*^9}, 
   3.466631284257303*^9, {3.466819031795046*^9, 3.4668190799587173`*^9}, {
   3.466819113054793*^9, 3.4668192483706903`*^9}, {3.466857411846363*^9, 
   3.466857478794859*^9}, {3.466857522292041*^9, 3.466857524497271*^9}, {
   3.466866017381885*^9, 3.466866045395048*^9}, 3.4668660891917543`*^9, {
   3.4668952798848763`*^9, 3.466895284515377*^9}, {3.466898929035076*^9, 
   3.4668989378483763`*^9}, 3.466900231825808*^9, 3.4669032299157248`*^9, {
   3.466939509244391*^9, 3.4669395479850397`*^9}, {3.466939622429214*^9, 
   3.466939640561816*^9}, 3.466939752066389*^9, 3.466939782701005*^9, {
   3.466939842468491*^9, 3.466939887037485*^9}, {3.466978215799006*^9, 
   3.466978256205811*^9}, {3.466979981294779*^9, 3.466980024790284*^9}, {
   3.466980122410994*^9, 3.466980145624982*^9}, 3.47030763472351*^9, 
   3.475670567084653*^9, {3.475670637979553*^9, 3.4756706843385887`*^9}, {
   3.5014527251568947`*^9, 3.5014527438277817`*^9}, 3.501452776354828*^9, {
   3.501453156891371*^9, 3.501453161850893*^9}, {3.5014609657268257`*^9, 
   3.501460971181902*^9}, {3.5014610598574944`*^9, 3.501461164178561*^9}, {
   3.501461227058552*^9, 3.501461458790757*^9}, {3.501461557527953*^9, 
   3.5014615678134327`*^9}, {3.5014616484247932`*^9, 3.501461661299625*^9}, {
   3.501461700400387*^9, 3.501461702337553*^9}, {3.501461773238063*^9, 
   3.50146182634988*^9}, {3.501504393641776*^9, 3.501504668901593*^9}, {
   3.5015047438778276`*^9, 3.50150489337606*^9}, {3.501504935009624*^9, 
   3.501504951641725*^9}, {3.50150852312134*^9, 3.501508536760117*^9}, {
   3.501508577129129*^9, 3.501508693638196*^9}, {3.501508728792266*^9, 
   3.501508833788498*^9}, {3.5015096317943897`*^9, 3.501509632968432*^9}, {
   3.501700561680862*^9, 3.501700571710394*^9}, {3.501700618684319*^9, 
   3.5017007625752077`*^9}, {3.501725067812355*^9, 3.501725134734894*^9}, {
   3.501725172170739*^9, 3.5017251798363028`*^9}, {3.501725536226622*^9, 
   3.501725634056837*^9}, {3.501725665361883*^9, 3.5017256754835653`*^9}, {
   3.50172570570965*^9, 3.5017257299557734`*^9}, {3.5017715379828167`*^9, 
   3.501771578278822*^9}, {3.5017716684436913`*^9, 3.501771708302195*^9}, {
   3.501771760468047*^9, 3.501771857578474*^9}, {3.501772001125836*^9, 
   3.501772031815219*^9}, {3.501772113658486*^9, 3.501772214782255*^9}, {
   3.5017722514146347`*^9, 3.501772260372447*^9}, {3.501772756541397*^9, 
   3.501772760980443*^9}, {3.50177284456152*^9, 3.501772855455414*^9}, {
   3.501858005350363*^9, 3.501858006890602*^9}, {3.501858055114584*^9, 
   3.501858107521488*^9}, {3.5018584427921867`*^9, 3.501858461403714*^9}, {
   3.5018585161603813`*^9, 3.501858585903022*^9}, {3.501858637893877*^9, 
   3.501858653782238*^9}, {3.6218620877069798`*^9, 3.621862099482967*^9}, {
   3.621862228896274*^9, 3.621862259550659*^9}, {3.6220344644471903`*^9, 
   3.622034491411557*^9}, {3.622034521742002*^9, 3.622034595490595*^9}, {
   3.622036016559505*^9, 3.6220361129947863`*^9}, {3.622039319517334*^9, 
   3.622039340624758*^9}, {3.622039437991523*^9, 3.622039445314638*^9}, {
   3.6230863083979273`*^9, 3.623086380555806*^9}, {3.623086415008054*^9, 
   3.6230864263446617`*^9}, {3.62308647952059*^9, 3.623086553598901*^9}, {
   3.623086656403545*^9, 3.623086734394931*^9}, {3.623086781699353*^9, 
   3.623086800998453*^9}, {3.62308689989485*^9, 3.623086902189638*^9}, {
   3.623250148204049*^9, 3.623250157688978*^9}, {3.6232502436192837`*^9, 
   3.623250286652083*^9}, {3.623250326323902*^9, 3.623250339442788*^9}, {
   3.623250556871087*^9, 3.623250585861964*^9}, {3.623250621529641*^9, 
   3.6232507262643213`*^9}, {3.6232546963200493`*^9, 
   3.6232546984317007`*^9}, {3.6232547416993847`*^9, 
   3.6232549096576357`*^9}, {3.623254983965345*^9, 3.623255210776628*^9}, {
   3.623255632317108*^9, 3.6232556668566217`*^9}, {3.62325586117348*^9, 
   3.6232559239093513`*^9}, {3.623256044184989*^9, 3.6232561040769997`*^9}, {
   3.6232562306008453`*^9, 3.623256246598588*^9}, {3.623257101643816*^9, 
   3.623257160972974*^9}, {3.6232572777894907`*^9, 3.623257282425991*^9}, {
   3.623257336966167*^9, 3.62325734249129*^9}, {3.623257886724313*^9, 
   3.623257891771061*^9}, {3.623260909241593*^9, 3.62326092245592*^9}, {
   3.6237071138561087`*^9, 3.623707125645509*^9}, 3.6237106738241367`*^9, {
   3.623712875870113*^9, 3.623712890753138*^9}, 3.62371300987012*^9, {
   3.623713045791855*^9, 3.623713112275548*^9}, {3.623801457596241*^9, 
   3.6238014609539413`*^9}, {3.813276740862681*^9, 3.8132767629252863`*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"2aa654ed-2356-4d99-a71f-a6231d4d0991"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"BaseElementDirectives", "::", "usage"}], "=", 
   "\"\<BaseElementDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TextOffsetScale", "::", "usage"}], "=", 
   "\"\<TextOffsetScale is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DefaultTextOffset", "::", "usage"}], "=", 
   "\"\<DefaultTextOffset is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ExtraTextArgumentsList", "::", "usage"}], "=", 
   "\"\<ExtraTextArgumentsList is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DefaultDiagonalTextOffset", "::", "usage"}], "=", 
   "\"\<DefaultDiagonalTextOffset is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"BaseElementDirectives", "::", "usage"}], "=", 
   "\"\<BaseElementDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ResistorFlipped", "::", "usage"}], "=", 
   "\"\<ResistorFlipped is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ResistorTurnNumber", "::", "usage"}], "=", 
   "\"\<ResistorTurnNumber is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ResistorDirectives", "::", "usage"}], "=", 
   "\"\<ResistorDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"WrapperFunction", "::", "usage"}], "=", 
   "\"\<WrapperFunction is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"WireDirectives", "::", "usage"}], "=", 
   "\"\<WireDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NodeDirectives", "::", "usage"}], "=", 
   "\"\<NodeDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NodeReplacementRules", "::", "usage"}], "=", 
   "\"\<NodeReplacementRules is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageDirectives", "::", "usage"}], "=", 
   "\"\<DCVoltageDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageNegativeTerminalDirectives", "::", "usage"}], "=", 
   "\"\<DCVoltageNegativeTerminalDirectives is an option for \
DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageNegativeTerminalScale", "::", "usage"}], "=", 
   "\"\<DCVoltageNegativeTerminalScale is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageFlipped", "::", "usage"}], "=", 
   "\"\<DCVoltageFlipped is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageShowPolarity", "::", "usage"}], "=", 
   "\"\<DCVoltageShowPolarity is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltagePolarityOffset", "::", "usage"}], "=", 
   "\"\<DCVoltagePolarityOffset is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltagePolarityStyle", "::", "usage"}], "=", 
   "\"\<DCVoltagePolarityStyle is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageWidth", "::", "usage"}], "=", 
   "\"\<DCVoltageWidth is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageGap", "::", "usage"}], "=", 
   "\"\<DCVoltageGap is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCVoltageNumberCells", "::", "usage"}], "=", 
   "\"\<DCVoltageNumberCells is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CapacitorGap", "::", "usage"}], "=", 
   "\"\<CapacitorGap is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CapacitorWidth", "::", "usage"}], "=", 
   "\"\<CapacitorWidth is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CapacitorDirectives", "::", "usage"}], "=", 
   "\"\<CapacitorDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InductorFlipped", "::", "usage"}], "=", 
   "\"\<InductorFlipped is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InductorTurnNumber", "::", "usage"}], "=", 
   "\"\<InductorTurnNumber is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InductorDirectives", "::", "usage"}], "=", 
   "\"\<InductorDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InductorTurnSegments", "::", "usage"}], "=", 
   "\"\<InductorTurnSegments is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InductorTurnTightness", "::", "usage"}], "=", 
   "\"\<InductorTurnTightness is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CurrentArrowScale", "::", "usage"}], "=", 
   "\"\<CurrentArrowScale is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CurrentArrowFlipped", "::", "usage"}], "=", 
   "\"\<CurrentArrowFlipped is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CurrentArrowDirectives", "::", "usage"}], "=", 
   "\"\<CurrentArrowDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"CurrentArrowType", "::", "usage"}], "=", 
   "\"\<CurrentArrowType is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InlinePolygonalArrowLength", "::", "usage"}], "=", 
   "\"\<InlinePolygonalArrowLength is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"OffsetArrowLength", "::", "usage"}], "=", 
   "\"\<OffsetArrowLength is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"OffsetArrowOffset", "::", "usage"}], "=", 
   "\"\<OffsetArrowOffset is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DiodeSize", "::", "usage"}], "=", 
   "\"\<DiodeSize is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DiodeFlipped", "::", "usage"}], "=", 
   "\"\<DiodeFlipped is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DiodeFilled", "::", "usage"}], "=", 
   "\"\<DiodeFilled is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DiodeWidthRatio", "::", "usage"}], "=", 
   "\"\<DiodeWidthRatio is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DiodeBarDirectives", "::", "usage"}], "=", 
   "\"\<DiodeBarDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DiodeDirectives", "::", "usage"}], "=", 
   "\"\<DiodeDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ACVoltageRadius", "::", "usage"}], "=", 
   "\"\<ACVoltageRadius is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ACVoltageDirectives", "::", "usage"}], "=", 
   "\"\<ACVoltageDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ACVoltageImageRatio", "::", "usage"}], "=", 
   "\"\<ACVoltageImageRatio is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentRadius", "::", "usage"}], "=", 
   "\"\<DCCurrentRadius is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentDirectives", "::", "usage"}], "=", 
   "\"\<DCCurrentDirectives is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentFlipped", "::", "usage"}], "=", 
   "\"\<DCCurrentFlipped is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentArrowBaseDirectives", "::", "usage"}], "=", 
   "\"\<DCCurrentArrowBaseDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentArrowDirectives", "::", "usage"}], "=", 
   "\"\<DCCurrentArrowDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentImageRatio", "::", "usage"}], "=", 
   "\"\<DCCurrentImageRatio is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentArrowTipLengthRatio", "::", "usage"}], "=", 
   "\"\<DCCurrentArrowTipLengthRatio is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrentArrowTipWidthRatio", "::", "usage"}], "=", 
   "\"\<DCCurrentArrowTipWidthRatio is an option for DrawCircuit.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InlineMeterRadius", "::", "usage"}], "=", 
   "\"\<InlineMeterRadius is an option for DrawCircuit.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"InlineMeterDirectives", "::", "usage"}], "=", 
   "\"\<InlineMeterDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundScale", "::", "usage"}], "=", 
   "\"\<GroundScale is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundHeightRatio", "::", "usage"}], "=", 
   "\"\<GroundHeightRatio is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundLineNumber", "::", "usage"}], "=", 
   "\"\<GroundLineNumber is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundMinWidthRatio", "::", "usage"}], "=", 
   "\"\<GroundMinWidthRatio is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundHeightRatio", "::", "usage"}], "=", 
   "\"\<GroundHeightRatio is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundOffsetRatio", "::", "usage"}], "=", 
   "\"\<GroundOffsetRatio is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GroundOffsetDirectives", "::", "usage"}], "=", 
  "\"\<GroundOffsetDirectives is an option for DrawCircuit\>\""}], "\
\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GroundDirectives", "::", "usage"}], "=", 
   "\"\<GroundDirectives is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GroundOrientation", "::", "usage"}], 
  "\"\<GroundOrientation is an option for DrawCircuit.\>\""}], "\
\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GraphicsLayer", "::", "usage"}], "=", 
   "\"\<GraphicsLayer is an option for UnderShadeWrapper and \
UnderRectangleWrapper.\>\""}], ";", 
  RowBox[{
   RowBox[{"OverLength", "::", "usage"}], "=", 
   "\"\<OverLength is an option for UnderRectangleWrapper.\>\""}], ";", 
  RowBox[{
   RowBox[{"OverWidth", "::", "usage"}], "=", 
   "\"\<OverWidth is an option for UnderRectangleWrapper.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CircuitSwitchSize", "::", "usage"}], "=", 
   "\"\<CircuitSwitchSize is an option for DrawCircuit\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CircuitSwitchPosition", "::", "usage"}], "=", 
   "\"\<CircuitSwitchPosition is an option for DrawCircuit\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CircuitSwitchOpenAngle", "::", "usage"}], "=", 
   "\"\<CircuitSwitchOpenAngle is an option for DrawCircuit\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CircuitSwitchOpenSense", "::", "usage"}], "=", 
   "\"\<CircuitSwitchOpenSense is an option for DrawCircuit\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CircuitSwitchPointSize", "::", "usage"}], "=", 
   "\"\<CircuitSwitchPointSize is an option for DrawCircuit\>\""}], ";", 
  RowBox[{
   RowBox[{"CircuitSwitchDirectives", "::", "usage"}], "=", 
   "\"\<CircuitSwitchDirectives is an option for DrawCircuit\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{
  3.621864881758669*^9, 3.621872116035676*^9, 3.62223472184126*^9, {
   3.623707460935422*^9, 3.623707574803713*^9}, {3.623710648676186*^9, 
   3.623710680967033*^9}, {3.62371396327273*^9, 3.6237139864052267`*^9}, {
   3.623718396282085*^9, 3.6237184206973467`*^9}, {3.813276224924406*^9, 
   3.813276510568372*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"a6e80938-2861-4c5e-a712-639360719455"],

Cell[BoxData["\<\"GroundOffsetDirectives is an option for DrawCircuit\"\>"], \
"Output",
 CellChangeTimes->{3.813276553227775*^9, 3.813276794303388*^9, 
  3.813277224217729*^9, 3.81327733307977*^9, 3.8132778445741367`*^9},
 CellLabel->
  "Out[236]=",ExpressionUUID->"e97e8280-42be-40c7-a0b1-e1ed4500542f"],

Cell[BoxData[
 RowBox[{"\<\"GroundOrientation is an option for DrawCircuit.\"\>", " ", 
  StyleBox[
   RowBox[{"GroundOrientation", "::", "usage"}], "MessageName"]}]], "Output",
 CellChangeTimes->{3.813276553227775*^9, 3.813276794303388*^9, 
  3.813277224217729*^9, 3.81327733307977*^9, 3.81327784467768*^9},
 CellLabel->
  "Out[238]=",ExpressionUUID->"8ad8db60-9104-40bf-a8c9-d79351d2715a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Begin", "[", "\"\<Global`\>\"", "]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"TextOffset", "::", "usage"}], "=", 
   "\"\<TextOffset is an option for DrawCircuit.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"End", "[", "]"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.622234739581964*^9, 3.622234759863637*^9}},
 CellLabel->
  "In[245]:=",ExpressionUUID->"38712928-3f06-4d03-b491-599a7ed5b535"],

Cell[BoxData["\<\"Global`\"\>"], "Output",
 CellChangeTimes->{3.813276553431765*^9, 3.813276794509775*^9, 
  3.813277224434717*^9, 3.8132773332847767`*^9, 3.813277844771309*^9},
 CellLabel->
  "Out[245]=",ExpressionUUID->"0a8eeb26-44f5-468d-a28c-0dede4a84bf0"],

Cell[BoxData["\<\"Global`\"\>"], "Output",
 CellChangeTimes->{3.813276553431765*^9, 3.813276794509775*^9, 
  3.813277224434717*^9, 3.8132773332847767`*^9, 3.813277844867877*^9},
 CellLabel->
  "Out[247]=",ExpressionUUID->"2e554868-9fed-4788-a552-07fa3838f566"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.621872168295719*^9, 3.621872197547449*^9}},
 CellLabel->
  "In[248]:=",ExpressionUUID->"affaa940-cf5d-4441-8db9-65f5d324642d"],

Cell[BoxData["\<\"Circuit`Private`\"\>"], "Output",
 CellChangeTimes->{3.813276553633669*^9, 3.813276794714864*^9, 
  3.813277224639735*^9, 3.813277333496516*^9, 3.8132778449838057`*^9},
 CellLabel->
  "Out[248]=",ExpressionUUID->"4392c946-b87a-46a0-9e3a-b07a10476354"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DrawCircuit", "::", "nodes"}], " ", "=", " ", 
   "\"\<The first argument `1` should be of the form \
\[LeftAssociation]\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \
\"1\"]\)\[Rule]\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \"1\
\"]\),\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \"2\"]\)\
\[Rule]\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"2\"]\),...\[RightAssociation], \
{{\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \
\"1\"]\),\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"1\"]\)},{\!\(\*SubscriptBox[StyleBox[\"lbl\",FontSlant->\"Italic\"], \"2\"]\
\),\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \"2\"]\)},... } \
or {\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"1\"]\),\!\(\*SubscriptBox[StyleBox[\"pt\",FontSlant->\"Italic\"], \
\"2\"]\),...}\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DrawCircuit", "::", "nodematch"}], " ", "=", " ", 
   "\"\<`1` contains an undefined node.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DrawCircuit", "::", "connection"}], " ", "=", " ", 
   "\"\<`1` is not a properly formed connection.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106302454693*^9}, {3.476106416559104*^9, 3.476106460235757*^9}, {
   3.476106581199346*^9, 3.476106634588523*^9}, {3.476107305994638*^9, 
   3.476107317380512*^9}, {3.476107760958149*^9, 3.476107778795526*^9}, {
   3.476107900121354*^9, 3.476107937996397*^9}, {3.476108071920807*^9, 
   3.4761080887319193`*^9}, {3.476108164418932*^9, 3.476108201306342*^9}, {
   3.476108692243926*^9, 3.476108768395046*^9}, {3.476109124682055*^9, 
   3.4761091262062483`*^9}, {3.476110226418565*^9, 3.476110227231073*^9}, {
   3.476110600044496*^9, 3.476110602368554*^9}, 3.4761109965306787`*^9, 
   3.476113452029992*^9, {3.476114100567851*^9, 3.476114187007794*^9}, {
   3.47611430142743*^9, 3.476114304128113*^9}, {3.476121642319868*^9, 
   3.476121675306847*^9}, {3.4761220143333883`*^9, 3.476122060037277*^9}, {
   3.4761447996006393`*^9, 3.4761448346382732`*^9}, {3.476145175992147*^9, 
   3.4761451815100527`*^9}, 3.476185402756797*^9, {3.476185581284341*^9, 
   3.476185589451889*^9}, 3.4761966376038027`*^9, 3.4761967894912252`*^9, {
   3.476210429386447*^9, 3.476210434020817*^9}, 3.476211098935493*^9, {
   3.476211138135975*^9, 3.476211141958665*^9}, {3.4763659569687443`*^9, 
   3.476365978899395*^9}, 3.4763660615280333`*^9, {3.4763661438934393`*^9, 
   3.476366273051663*^9}, {3.4763663367016153`*^9, 3.476366368069922*^9}, {
   3.476366407202338*^9, 3.476366463178041*^9}, 3.4763664983677998`*^9, {
   3.476366944839669*^9, 3.476366966909127*^9}, {3.47636906963199*^9, 
   3.476369082370784*^9}, {3.4763691489642277`*^9, 3.476369151336062*^9}, {
   3.476369292761282*^9, 3.4763694008740788`*^9}, {3.476369442834669*^9, 
   3.476369470181513*^9}, 3.4763695009737387`*^9, {3.476369531406848*^9, 
   3.4763695386854687`*^9}, {3.476369603837468*^9, 3.476369620179778*^9}, {
   3.476369745858946*^9, 3.47636978937963*^9}, {3.4763710476460733`*^9, 
   3.476371109877808*^9}, {3.47638096148899*^9, 3.476380978055448*^9}, {
   3.476398400776684*^9, 3.47639840743296*^9}, {3.476398627718067*^9, 
   3.476398679770344*^9}, {3.476409173509157*^9, 3.476409180883336*^9}, {
   3.476409234657473*^9, 3.476409246015324*^9}, {3.476409304322565*^9, 
   3.476409305727536*^9}, {3.476457429231205*^9, 3.476457468984474*^9}, 
   3.476457534709152*^9, {3.476457604400165*^9, 3.476457637061607*^9}, {
   3.476458364549268*^9, 3.476458364826387*^9}, {3.476458399923841*^9, 
   3.4764585372118187`*^9}, 3.4764586414235907`*^9, {3.476494435693815*^9, 
   3.4764944367038937`*^9}, {3.476494795805993*^9, 3.476494845831613*^9}, {
   3.476494940312262*^9, 3.476494954828953*^9}, {3.476527260278055*^9, 
   3.476527277828783*^9}, {3.4765273245499277`*^9, 3.476527325580926*^9}, {
   3.476527376494852*^9, 3.476527471451088*^9}, {3.47652752795599*^9, 
   3.476527618608492*^9}, {3.4765276743070707`*^9, 3.4765277443511477`*^9}, {
   3.476527811256331*^9, 3.4765279086587677`*^9}, {3.476527950239513*^9, 
   3.47652797289771*^9}, {3.476528021180295*^9, 3.476528034933723*^9}, {
   3.476528123304459*^9, 3.476528124918633*^9}, 3.4765281593347797`*^9, {
   3.476528230136219*^9, 3.476528231453207*^9}, {3.476582185022448*^9, 
   3.476582187449844*^9}, {3.476582270011695*^9, 3.476582273937911*^9}, {
   3.476582461798917*^9, 3.476582472308679*^9}, {3.476612387392542*^9, 
   3.4766124325809793`*^9}, {3.47664145901128*^9, 3.476641493865787*^9}, {
   3.476641527138528*^9, 3.476641528803323*^9}, {3.497227452568782*^9, 
   3.49722748258984*^9}, {3.497227639286525*^9, 3.497227642178056*^9}, {
   3.497314289563693*^9, 3.497314300247407*^9}, {3.4973161564734297`*^9, 
   3.4973162246478567`*^9}, {3.497316272392581*^9, 3.4973162727285223`*^9}, {
   3.497316313450996*^9, 3.4973163828268843`*^9}, {3.4973175404090776`*^9, 
   3.4973176211413107`*^9}, {3.497317787153141*^9, 3.497317894625948*^9}, {
   3.497349867898911*^9, 3.497349881773623*^9}, 3.497365131284121*^9, {
   3.4973668472067347`*^9, 3.497366872696767*^9}, 3.497366920617692*^9, 
   3.4973672781945553`*^9, 3.497367338353608*^9, {3.497367601403747*^9, 
   3.497367614530047*^9}, 3.500751070432418*^9, {3.5011193178773403`*^9, 
   3.501119318826271*^9}, 3.501119761224312*^9, {3.5011199242814627`*^9, 
   3.501119969362002*^9}, {3.5011200839411383`*^9, 3.50112008823606*^9}, {
   3.5011202044833603`*^9, 3.501120212083962*^9}, {3.501158008848362*^9, 
   3.501158062514268*^9}, {3.50115811174193*^9, 3.501158236607304*^9}, {
   3.5011582745775223`*^9, 3.5011582830941973`*^9}, {3.501336475403908*^9, 
   3.501336476471827*^9}, {3.501343635266762*^9, 3.501343639474765*^9}, {
   3.5013437711866627`*^9, 3.501343779279169*^9}, 3.501343870522444*^9, {
   3.501348407203644*^9, 3.501348417513266*^9}, {3.501348511270318*^9, 
   3.501348514811728*^9}, {3.50134858518331*^9, 3.501348587988357*^9}, {
   3.5013488462863703`*^9, 3.50134885043552*^9}, {3.501348918903163*^9, 
   3.501348951898562*^9}, {3.501419133741438*^9, 3.501419176631116*^9}, {
   3.501444029447609*^9, 3.501444060618021*^9}, {3.501444115193963*^9, 
   3.5014441253928137`*^9}, {3.501444543518688*^9, 3.501444549192799*^9}, {
   3.501444659922431*^9, 3.501444734596438*^9}, {3.501445492805297*^9, 
   3.501445503741107*^9}, {3.5014455379431868`*^9, 3.501445651577888*^9}, 
   3.5014457271550407`*^9, 3.501445810930554*^9, {3.501446054516151*^9, 
   3.501446079318241*^9}, {3.5014490079757833`*^9, 3.501449008910886*^9}, {
   3.501449287098826*^9, 3.501449303786297*^9}, {3.5014499475028687`*^9, 
   3.50144995025161*^9}, {3.501450065181651*^9, 3.5014500688049793`*^9}, 
   3.501453017847331*^9, {3.501453079703404*^9, 3.5014531131775208`*^9}, {
   3.501453284527351*^9, 3.501453302148003*^9}, {3.501455554899455*^9, 
   3.50145562014149*^9}, {3.501464209859069*^9, 3.5014642398201857`*^9}, {
   3.5014676402056847`*^9, 3.501467672783102*^9}, {3.501777153485264*^9, 
   3.5017771935533133`*^9}, {3.501777791032349*^9, 3.501777799596127*^9}, {
   3.501777844343069*^9, 3.501777885805113*^9}, {3.501778300627495*^9, 
   3.501778305252673*^9}, {3.501778352909421*^9, 3.501778406442727*^9}, {
   3.501778445642251*^9, 3.5017784870336943`*^9}, {3.50177935975873*^9, 
   3.501779391376915*^9}, {3.501779486395031*^9, 3.5017795066015577`*^9}, {
   3.50177958181645*^9, 3.501779669636499*^9}, {3.501779789700733*^9, 
   3.501779800603448*^9}, {3.5017798406193*^9, 3.501779862910471*^9}, {
   3.501784501700515*^9, 3.501784505507679*^9}, {3.501784598165188*^9, 
   3.501784604368773*^9}, {3.501784916451499*^9, 3.501784960637738*^9}, {
   3.501785257226625*^9, 3.501785260885962*^9}, {3.50178541411646*^9, 
   3.501785477669379*^9}, 3.501786152273367*^9, 3.501786503721446*^9, {
   3.501786557846867*^9, 3.5017865826448*^9}, {3.512169397278523*^9, 
   3.512169445606512*^9}, {3.51217148437716*^9, 3.5121715078804607`*^9}, {
   3.6232441806261997`*^9, 3.62324418703036*^9}, {3.623244281346847*^9, 
   3.623244317140826*^9}, {3.623244455426198*^9, 3.623244587668618*^9}, {
   3.623244751407819*^9, 3.623244765525942*^9}, 3.6232448126774483`*^9, {
   3.623244910747307*^9, 3.623244972837925*^9}, {3.6232490108026533`*^9, 
   3.623249012991907*^9}, 3.6232577824616756`*^9, {3.623261330058443*^9, 
   3.623261339476244*^9}, {3.623262710323921*^9, 3.6232627493589478`*^9}, {
   3.6232627960178633`*^9, 3.623262821395109*^9}, {3.623263581855582*^9, 
   3.6232635991338053`*^9}, {3.623263641892476*^9, 3.623263642339182*^9}, {
   3.6232637003306*^9, 3.623263715714334*^9}, {3.623263794751793*^9, 
   3.623263804312509*^9}, {3.623264100376541*^9, 3.623264124332076*^9}, {
   3.623264173000024*^9, 3.623264257732629*^9}, 3.623264308467029*^9, {
   3.623264478199965*^9, 3.623264506855627*^9}, {3.623265139815689*^9, 
   3.623265148048449*^9}, {3.623273429062684*^9, 3.623273502382209*^9}, {
   3.6232735612916327`*^9, 3.6232735880668173`*^9}, {3.623273618618025*^9, 
   3.623273644579258*^9}, {3.623273764154895*^9, 3.623273828880546*^9}, {
   3.623274175938034*^9, 3.62327420206602*^9}, {3.623283934784854*^9, 
   3.623283936437642*^9}, 3.6232841388644953`*^9, 3.623284236967937*^9, {
   3.623285077877684*^9, 3.623285084401083*^9}, {3.623289893254157*^9, 
   3.623289897089925*^9}, {3.6232899284465027`*^9, 3.6232900171301403`*^9}, {
   3.623290079367676*^9, 3.623290100255698*^9}, {3.623290280724842*^9, 
   3.623290293974546*^9}, {3.623290459117778*^9, 3.623290501795014*^9}, {
   3.623291741138598*^9, 3.623291773009853*^9}, 3.623292276455986*^9, {
   3.6232925364355373`*^9, 3.6232925387339783`*^9}, 3.623292748667307*^9, 
   3.623293178528529*^9, {3.6232935291136723`*^9, 3.623293582444255*^9}, {
   3.623293627170208*^9, 3.623293722674391*^9}, 3.62329375673987*^9, {
   3.6232940253390408`*^9, 3.6232940306864653`*^9}, {3.62329411150406*^9, 
   3.623294155509177*^9}, {3.623294192102703*^9, 3.623294308358594*^9}, {
   3.623294343325498*^9, 3.623294385007304*^9}, 3.623294458550758*^9, {
   3.623294498139852*^9, 3.6232945051265097`*^9}, {3.6232945636613083`*^9, 
   3.623294565269031*^9}, {3.623294645821898*^9, 3.623294653057164*^9}, {
   3.623294747660412*^9, 3.623294748027844*^9}, 3.6232947935171833`*^9, {
   3.623294971146078*^9, 3.6232951163070498`*^9}, {3.6233218266875153`*^9, 
   3.6233218630695457`*^9}, {3.623321904347659*^9, 3.623321906099712*^9}, {
   3.623321945120222*^9, 3.623322004505938*^9}, {3.6233220504920397`*^9, 
   3.623322078702382*^9}, 3.623322224659233*^9, {3.623322295187747*^9, 
   3.623322310564253*^9}, {3.623322368730411*^9, 3.6233223842040358`*^9}, {
   3.6233224618473177`*^9, 3.6233225044059677`*^9}, {3.623322540856553*^9, 
   3.623322595578059*^9}, {3.623323063861298*^9, 3.623323088934001*^9}, 
   3.623323260917012*^9, {3.623323331796749*^9, 3.623323336450595*^9}, {
   3.623325704941272*^9, 3.6233257625859947`*^9}, {3.623326058412277*^9, 
   3.623326162520322*^9}, {3.623326199342607*^9, 3.623326250317484*^9}, {
   3.623326284225113*^9, 3.623326314836625*^9}, {3.6233263589046164`*^9, 
   3.6233263851623707`*^9}, {3.6233264548577623`*^9, 
   3.6233264717583857`*^9}, {3.623326565483532*^9, 3.623326605632455*^9}, {
   3.62333037941164*^9, 3.623330388127738*^9}, {3.6233773375736856`*^9, 
   3.6233773438600883`*^9}, {3.6234149003998547`*^9, 
   3.6234149054861193`*^9}, {3.62341572828802*^9, 3.6234157320697403`*^9}, {
   3.6234159702853527`*^9, 3.623415984238901*^9}, {3.6234162428926773`*^9, 
   3.623416260977552*^9}, {3.623416362423044*^9, 3.6234163672320957`*^9}, {
   3.6234166005702143`*^9, 3.6234166712168837`*^9}, {3.623416991973666*^9, 
   3.623417005645853*^9}, {3.6234170901741858`*^9, 3.623417131321607*^9}, {
   3.6234172453524113`*^9, 3.6234172896014442`*^9}, {3.623417432115884*^9, 
   3.623417454144607*^9}, 3.623431727632196*^9, {3.623629611400147*^9, 
   3.62362962640695*^9}, 3.623630850882885*^9, {3.623630961633844*^9, 
   3.623630983020175*^9}, {3.6236310247646923`*^9, 3.623631042497603*^9}, 
   3.623631660443214*^9, 3.6236317373572617`*^9, 3.623632092665855*^9, {
   3.6236332944371653`*^9, 3.623633297485626*^9}, {3.62363372027892*^9, 
   3.623633723935454*^9}, {3.623636536295403*^9, 3.623636560561884*^9}, {
   3.623636700425235*^9, 3.623636748642009*^9}, {3.6236373801255083`*^9, 
   3.62363738121589*^9}, {3.62363744607347*^9, 3.623637460409314*^9}, {
   3.623637510662517*^9, 3.62363755254554*^9}, 3.623637647422139*^9, 
   3.623637742483135*^9, {3.623637810510915*^9, 3.623637876361651*^9}, {
   3.623637925218536*^9, 3.6236379298589497`*^9}, {3.623637971165843*^9, 
   3.623638000176567*^9}, {3.6236381328646717`*^9, 3.623638146148625*^9}, 
   3.623638330856331*^9, {3.623638444194165*^9, 3.623638456023365*^9}, 
   3.623638562021315*^9, 3.623638654149753*^9, {3.62366312620481*^9, 
   3.6236631364057503`*^9}, {3.623679220977949*^9, 3.623679240350965*^9}, {
   3.6236792747206917`*^9, 3.623679277033072*^9}, {3.623679473604064*^9, 
   3.62367947741404*^9}, {3.6237092421708937`*^9, 3.623709249607275*^9}, {
   3.6237116169196177`*^9, 3.623711621473509*^9}, 3.623713833315723*^9},
 CellLabel->
  "In[249]:=",ExpressionUUID->"c4f1f428-9b85-4857-ae16-7a32586bfe29"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "DrawCircuit", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"TextOffsetScale", "\[Rule]", "1"}], ",", 
     RowBox[{"TextOffset", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"DefaultTextOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}]}], ",", 
     RowBox[{"ExtraTextArgumentsList", "\[Rule]", "None"}], ",", 
     RowBox[{"DefaultDiagonalTextOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"BaseElementDirectives", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ResistorFlipped", "\[Rule]", "False"}], ",", 
     RowBox[{"ResistorTurnNumber", "\[Rule]", "6"}], ",", 
     RowBox[{"ResistorDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"WrapperFunction", "\[Rule]", "Identity"}], ",", 
     RowBox[{"WireDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"NodeDirectives", "\[Rule]", 
      RowBox[{"AbsolutePointSize", "[", "3", "]"}]}], ",", 
     RowBox[{"NodeReplacementRules", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"DCVoltageDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"DCVoltageNegativeTerminalDirectives", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"AbsoluteThickness", "[", "3", "]"}], "}"}]}], ",", 
     RowBox[{"DCVoltageNegativeTerminalScale", "\[Rule]", 
      RowBox[{"1", "/", "3"}]}], ",", 
     RowBox[{"DCVoltageFlipped", "\[Rule]", "False"}], ",", 
     RowBox[{"DCVoltageShowPolarity", "\[Rule]", "False"}], ",", 
     RowBox[{"DCVoltagePolarityOffset", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "/", "8"}], ",", 
        RowBox[{"1", "/", "8"}]}], "}"}]}], ",", 
     RowBox[{"DCVoltagePolarityStyle", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"DCVoltageWidth", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}], ",", 
     RowBox[{"DCVoltageGap", "\[Rule]", 
      RowBox[{"1", "/", "8"}]}], ",", 
     RowBox[{"DCVoltageNumberCells", "\[Rule]", "1"}], ",", 
     RowBox[{"CapacitorGap", "\[Rule]", 
      RowBox[{"1", "/", "8"}]}], ",", 
     RowBox[{"CapacitorWidth", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}], ",", 
     RowBox[{"CapacitorDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"InductorFlipped", "\[Rule]", "False"}], ",", 
     RowBox[{"InductorTurnNumber", "\[Rule]", "3"}], ",", 
     RowBox[{"InductorDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"InductorTurnSegments", "\[Rule]", "12"}], ",", 
     RowBox[{"InductorTurnTightness", "\[Rule]", ".5"}], ",", 
     RowBox[{"CurrentArrowScale", "\[Rule]", "1"}], ",", 
     RowBox[{"CurrentArrowFlipped", "\[Rule]", "False"}], ",", 
     RowBox[{"CurrentArrowDirectives", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"GrayLevel", "[", ".25", "]"}], "}"}]}], ",", 
     RowBox[{"CurrentArrowType", "\[Rule]", "\"\<Simple Line\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"InlinePolygonalArrowLength", "\[Rule]", ".25"}], ",", 
     RowBox[{"OffsetArrowLength", "\[Rule]", ".5"}], ",", 
     RowBox[{"OffsetArrowOffset", "\[Rule]", ".5"}], ",", 
     RowBox[{"DiodeSize", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}], ",", 
     RowBox[{"DiodeFlipped", "\[Rule]", "False"}], ",", 
     RowBox[{"DiodeFilled", "\[Rule]", "False"}], ",", 
     RowBox[{"DiodeWidthRatio", "\[Rule]", 
      RowBox[{"2", "/", 
       SqrtBox["3"]}]}], ",", 
     RowBox[{"DiodeBarDirectives", "\[Rule]", 
      RowBox[{"AbsoluteThickness", "[", "2", "]"}]}], ",", 
     RowBox[{"DiodeDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"ACVoltageRadius", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}], ",", 
     RowBox[{"ACVoltageDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"ACVoltageImageRatio", "\[Rule]", ".7"}], ",", 
     RowBox[{"DCCurrentRadius", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}], ",", 
     RowBox[{"DCCurrentDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"DCCurrentFlipped", "\[Rule]", "False"}], ",", 
     RowBox[{"DCCurrentArrowBaseDirectives", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"AbsoluteThickness", "[", "3", "]"}], "}"}]}], ",", 
     RowBox[{"DCCurrentArrowDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"DCCurrentImageRatio", "\[Rule]", ".6"}], ",", 
     RowBox[{"DCCurrentArrowTipLengthRatio", "\[Rule]", ".4"}], ",", 
     RowBox[{"DCCurrentArrowTipWidthRatio", "\[Rule]", ".3"}], ",", 
     RowBox[{"InlineMeterRadius", "\[Rule]", 
      RowBox[{"1", "/", "4"}]}], ",", 
     RowBox[{"InlineMeterDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"GroundScale", "\[Rule]", "1"}], ",", 
     RowBox[{"GroundHeightRatio", "\[Rule]", ".4"}], ",", 
     RowBox[{"GroundLineNumber", "\[Rule]", "3"}], ",", 
     RowBox[{"GroundMinWidthRatio", "\[Rule]", ".4"}], ",", 
     RowBox[{"GroundHeightRatio", "\[Rule]", ".4"}], ",", 
     RowBox[{"GroundOffsetRatio", "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{"GroundDirectives", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"AbsoluteThickness", "[", "2", "]"}], "}"}]}], ",", 
     RowBox[{"GroundOffsetDirectives", "\[Rule]", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"GroundOrientation", "\[Rule]", "\"\<Down\>\""}], ",", 
     RowBox[{"CircuitSwitchSize", "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{"CircuitSwitchPosition", "\[Rule]", "\"\<Open\>\""}], ",", 
     RowBox[{"CircuitSwitchOpenAngle", "\[Rule]", 
      RowBox[{"25", "\[Degree]"}]}], ",", 
     RowBox[{
     "CircuitSwitchOpenSense", "\[Rule]", "\"\<Counterclockwise\>\""}], ",", 
     RowBox[{"CircuitSwitchDirectives", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"AbsolutePointSize", "[", "5", "]"}], "}"}]}]}], "}"}]}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, {3.500640210299344*^9, 
   3.500640273073348*^9}, {3.5006403846863413`*^9, 3.500640387247176*^9}, {
   3.5006404294229937`*^9, 3.500640431684566*^9}, 3.50064055566514*^9, {
   3.500641303660849*^9, 3.5006413188209887`*^9}, {3.500643310369066*^9, 
   3.500643348678563*^9}, {3.500645038428664*^9, 3.500645046175591*^9}, {
   3.5006459027517147`*^9, 3.500645904736649*^9}, {3.5006459848623247`*^9, 
   3.5006459857614326`*^9}, {3.5006496902228117`*^9, 
   3.5006497244219837`*^9}, {3.5006498469220467`*^9, 3.500649847484447*^9}, {
   3.5006567151548777`*^9, 3.500656716965151*^9}, {3.5006567494544687`*^9, 
   3.500656777828803*^9}, {3.500657066409069*^9, 3.500657075289962*^9}, {
   3.500657228615872*^9, 3.500657230503626*^9}, {3.500674939322956*^9, 
   3.500674942044857*^9}, {3.5007247840741367`*^9, 3.500724795399164*^9}, 
   3.500729169401967*^9, {3.500740752076419*^9, 3.50074076193579*^9}, 
   3.500741085103944*^9, 3.500752750606551*^9, {3.5007527855691547`*^9, 
   3.500752828195346*^9}, {3.5007648660974073`*^9, 3.500764922208921*^9}, {
   3.500764953220833*^9, 3.5007649581837378`*^9}, {3.5007650192140713`*^9, 
   3.50076503989005*^9}, 3.50076774527079*^9, {3.500768668911211*^9, 
   3.500768682194709*^9}, {3.500768714708105*^9, 3.5007687162825813`*^9}, {
   3.5008099910588903`*^9, 3.500809993158086*^9}, {3.5008106404973907`*^9, 
   3.500810645070812*^9}, 3.500855647045957*^9, 3.5008556842722197`*^9, 
   3.5008557451314774`*^9, 3.5008558488190947`*^9, {3.50086354356669*^9, 
   3.5008636669806967`*^9}, {3.5009837523868732`*^9, 
   3.5009838013254347`*^9}, {3.500983874725778*^9, 3.5009839366609917`*^9}, {
   3.5010795643949327`*^9, 3.501079572515855*^9}, {3.50116568743641*^9, 
   3.501165731940667*^9}, {3.501168132356374*^9, 3.501168162568946*^9}, {
   3.5011776461316843`*^9, 3.501177778159816*^9}, {3.5012011263699093`*^9, 
   3.501201127054716*^9}, 3.501201399541965*^9, {3.501204907408413*^9, 
   3.501204918375101*^9}, {3.501205900806834*^9, 3.5012059229566174`*^9}, {
   3.501206215355494*^9, 3.501206215850369*^9}, {3.501206556739503*^9, 
   3.501206559920042*^9}, 3.501206658458921*^9, {3.501237765119556*^9, 
   3.501237781521098*^9}, {3.5012383047600517`*^9, 3.5012383073795443`*^9}, {
   3.501241858427194*^9, 3.501241907501482*^9}, {3.501251847389675*^9, 
   3.50125184804762*^9}, {3.501252312091064*^9, 3.501252320626355*^9}, 
   3.501259684252473*^9, 3.501259728186861*^9, {3.5012626708277817`*^9, 
   3.501262671566169*^9}, {3.501277409443018*^9, 3.5012774196046953`*^9}, 
   3.501339317074256*^9, {3.501343105874631*^9, 3.501343115177387*^9}, 
   3.501419732556107*^9, 3.501457289699842*^9, {3.5848841659480877`*^9, 
   3.5848841978094883`*^9}, {3.5848842487573967`*^9, 3.584884258737507*^9}, {
   3.584885867280691*^9, 3.584885875411796*^9}, 3.584886863279183*^9, 
   3.58488712800329*^9, {3.584887219014351*^9, 3.584887255293097*^9}, {
   3.584887453701083*^9, 3.584887459619952*^9}, {3.584887622328361*^9, 
   3.5848876225984488`*^9}, {3.5848976202858267`*^9, 3.5848976266445217`*^9}, 
   3.585048090465919*^9, {3.585048521510333*^9, 3.5850485628187313`*^9}, {
   3.5850490163990707`*^9, 3.585049019345468*^9}, 3.585049060003635*^9, 
   3.585049116039486*^9, {3.623432609103022*^9, 3.623432623789978*^9}, {
   3.6234329532040873`*^9, 3.623432972485935*^9}, {3.6237067242966623`*^9, 
   3.6237067251294127`*^9}, 3.6237107779453583`*^9, {3.623713880100775*^9, 
   3.623713901126885*^9}, {3.6237185436992826`*^9, 3.623718547821301*^9}, 
   3.810040233686595*^9, {3.810048475893879*^9, 3.8100484967353973`*^9}, 
   3.8100486310121193`*^9, 3.810048833538823*^9, {3.813276210224043*^9, 
   3.813276210960807*^9}, {3.813277122640571*^9, 3.8132771229262743`*^9}, {
   3.813277743689032*^9, 3.813277764759514*^9}},
 CellLabel->
  "In[252]:=",ExpressionUUID->"44459c2a-16b7-4a72-80ce-ab4e691bd345"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DrawCircuit", "[", 
    RowBox[{"nodePositionList_List", ",", "connectionList_List", ",", 
     RowBox[{"extraElementList_List", ":", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"Or", "[", 
      RowBox[{
       RowBox[{"And", "@@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"pair", "\[Function]", 
            RowBox[{"MatchQ", "[", 
             RowBox[{"pair", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"_", "?", "NumericQ"}], ",", 
                RowBox[{"_", "?", "NumericQ"}]}], "}"}]}], "]"}]}], ")"}], "/@",
           "nodePositionList"}], ")"}]}], ",", 
       RowBox[{"And", "@@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"labelAndPair", "\[Function]", 
            RowBox[{"MatchQ", "[", 
             RowBox[{"labelAndPair", ",", 
              RowBox[{"{", 
               RowBox[{"_", ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"_", "?", "NumericQ"}], ",", 
                  RowBox[{"_", "?", "NumericQ"}]}], "}"}]}], "}"}]}], "]"}]}],
            ")"}], "/@", "nodePositionList"}], ")"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"DrawCircuit", "[", 
      RowBox[{
       RowBox[{"Association", "@@", 
        RowBox[{"Rule", "@@@", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"MatrixQ", "[", "nodePositionList", "]"}], ",", 
           RowBox[{"MapIndexed", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                ",", "#1"}], "}"}], "&"}], ",", "nodePositionList"}], "]"}], 
           ",", "nodePositionList"}], "]"}]}]}], ",", "connectionList", ",", 
       "extraElementList", ",", "opts"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"DrawCircuit", "::", "nodes"}], ",", "nodePositionList"}], 
       "]"}], ";", "Null"}]}], "]"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106302454693*^9}, {3.476106416559104*^9, 3.476106460235757*^9}, {
   3.476106581199346*^9, 3.476106634588523*^9}, {3.476107305994638*^9, 
   3.476107317380512*^9}, {3.476107760958149*^9, 3.476107778795526*^9}, {
   3.476107900121354*^9, 3.476107937996397*^9}, {3.476108071920807*^9, 
   3.4761080887319193`*^9}, {3.476108164418932*^9, 3.476108201306342*^9}, {
   3.476108692243926*^9, 3.476108768395046*^9}, {3.476109124682055*^9, 
   3.4761091262062483`*^9}, {3.476110226418565*^9, 3.476110227231073*^9}, {
   3.476110600044496*^9, 3.476110602368554*^9}, 3.4761109965306787`*^9, 
   3.476113452029992*^9, {3.476114100567851*^9, 3.476114187007794*^9}, {
   3.47611430142743*^9, 3.476114304128113*^9}, {3.476121642319868*^9, 
   3.476121675306847*^9}, {3.4761220143333883`*^9, 3.476122060037277*^9}, {
   3.4761447996006393`*^9, 3.4761448346382732`*^9}, {3.476145175992147*^9, 
   3.4761451815100527`*^9}, 3.476185402756797*^9, {3.476185581284341*^9, 
   3.476185589451889*^9}, 3.4761966376038027`*^9, 3.4761967894912252`*^9, {
   3.476210429386447*^9, 3.476210434020817*^9}, 3.476211098935493*^9, {
   3.476211138135975*^9, 3.476211141958665*^9}, {3.4763659569687443`*^9, 
   3.476365978899395*^9}, 3.4763660615280333`*^9, {3.4763661438934393`*^9, 
   3.476366273051663*^9}, {3.4763663367016153`*^9, 3.476366368069922*^9}, {
   3.476366407202338*^9, 3.476366463178041*^9}, 3.4763664983677998`*^9, {
   3.476366944839669*^9, 3.476366966909127*^9}, {3.47636906963199*^9, 
   3.476369082370784*^9}, {3.4763691489642277`*^9, 3.476369151336062*^9}, {
   3.476369292761282*^9, 3.4763694008740788`*^9}, {3.476369442834669*^9, 
   3.476369470181513*^9}, 3.4763695009737387`*^9, {3.476369531406848*^9, 
   3.4763695386854687`*^9}, {3.476369603837468*^9, 3.476369620179778*^9}, {
   3.476369745858946*^9, 3.47636978937963*^9}, {3.4763710476460733`*^9, 
   3.476371109877808*^9}, {3.47638096148899*^9, 3.476380978055448*^9}, {
   3.476398400776684*^9, 3.47639840743296*^9}, {3.476398627718067*^9, 
   3.476398679770344*^9}, {3.476409173509157*^9, 3.476409180883336*^9}, {
   3.476409234657473*^9, 3.476409246015324*^9}, {3.476409304322565*^9, 
   3.476409305727536*^9}, {3.476457429231205*^9, 3.476457468984474*^9}, 
   3.476457534709152*^9, {3.476457604400165*^9, 3.476457637061607*^9}, {
   3.476458364549268*^9, 3.476458364826387*^9}, {3.476458399923841*^9, 
   3.4764585372118187`*^9}, 3.4764586414235907`*^9, {3.476494435693815*^9, 
   3.4764944367038937`*^9}, {3.476494795805993*^9, 3.476494845831613*^9}, {
   3.476494940312262*^9, 3.476494954828953*^9}, {3.476527260278055*^9, 
   3.476527277828783*^9}, {3.4765273245499277`*^9, 3.476527325580926*^9}, {
   3.476527376494852*^9, 3.476527471451088*^9}, {3.47652752795599*^9, 
   3.476527618608492*^9}, {3.4765276743070707`*^9, 3.4765277443511477`*^9}, {
   3.476527811256331*^9, 3.4765279086587677`*^9}, {3.476527950239513*^9, 
   3.47652797289771*^9}, {3.476528021180295*^9, 3.476528034933723*^9}, {
   3.476528123304459*^9, 3.476528124918633*^9}, 3.4765281593347797`*^9, {
   3.476528230136219*^9, 3.476528231453207*^9}, {3.476582185022448*^9, 
   3.476582187449844*^9}, {3.476582270011695*^9, 3.476582273937911*^9}, {
   3.476582461798917*^9, 3.476582472308679*^9}, {3.476612387392542*^9, 
   3.4766124325809793`*^9}, {3.47664145901128*^9, 3.476641493865787*^9}, {
   3.476641527138528*^9, 3.476641528803323*^9}, {3.497227452568782*^9, 
   3.49722748258984*^9}, {3.497227639286525*^9, 3.497227642178056*^9}, {
   3.497314289563693*^9, 3.497314300247407*^9}, {3.4973161564734297`*^9, 
   3.4973162246478567`*^9}, {3.497316272392581*^9, 3.4973162727285223`*^9}, {
   3.497316313450996*^9, 3.4973163828268843`*^9}, {3.4973175404090776`*^9, 
   3.4973176211413107`*^9}, {3.497317787153141*^9, 3.497317894625948*^9}, {
   3.497349867898911*^9, 3.497349881773623*^9}, 3.497365131284121*^9, {
   3.4973668472067347`*^9, 3.497366872696767*^9}, 3.497366920617692*^9, 
   3.4973672781945553`*^9, 3.497367338353608*^9, {3.497367601403747*^9, 
   3.497367614530047*^9}, 3.500751070432418*^9, {3.5011193178773403`*^9, 
   3.501119318826271*^9}, 3.501119761224312*^9, {3.5011199242814627`*^9, 
   3.501119969362002*^9}, {3.5011200839411383`*^9, 3.50112008823606*^9}, {
   3.5011202044833603`*^9, 3.501120212083962*^9}, {3.501158008848362*^9, 
   3.501158062514268*^9}, {3.50115811174193*^9, 3.501158236607304*^9}, {
   3.5011582745775223`*^9, 3.5011582830941973`*^9}, {3.501336475403908*^9, 
   3.501336476471827*^9}, {3.501343635266762*^9, 3.501343639474765*^9}, {
   3.5013437711866627`*^9, 3.501343779279169*^9}, 3.501343870522444*^9, {
   3.501348407203644*^9, 3.501348417513266*^9}, {3.501348511270318*^9, 
   3.501348514811728*^9}, {3.50134858518331*^9, 3.501348587988357*^9}, {
   3.5013488462863703`*^9, 3.50134885043552*^9}, {3.501348918903163*^9, 
   3.501348951898562*^9}, {3.501419133741438*^9, 3.501419176631116*^9}, {
   3.501444029447609*^9, 3.501444060618021*^9}, {3.501444115193963*^9, 
   3.5014441253928137`*^9}, {3.501444543518688*^9, 3.501444549192799*^9}, {
   3.501444659922431*^9, 3.501444734596438*^9}, {3.501445492805297*^9, 
   3.501445503741107*^9}, {3.5014455379431868`*^9, 3.501445651577888*^9}, 
   3.5014457271550407`*^9, 3.501445810930554*^9, {3.501446054516151*^9, 
   3.501446079318241*^9}, {3.5014490079757833`*^9, 3.501449008910886*^9}, {
   3.501449287098826*^9, 3.501449303786297*^9}, {3.5014499475028687`*^9, 
   3.50144995025161*^9}, {3.501450065181651*^9, 3.5014500688049793`*^9}, 
   3.501453017847331*^9, {3.501453079703404*^9, 3.5014531131775208`*^9}, {
   3.501453284527351*^9, 3.501453302148003*^9}, {3.501455554899455*^9, 
   3.50145562014149*^9}, {3.501464209859069*^9, 3.5014642398201857`*^9}, {
   3.5014676402056847`*^9, 3.501467672783102*^9}, {3.501777153485264*^9, 
   3.5017771935533133`*^9}, {3.501777791032349*^9, 3.501777799596127*^9}, {
   3.501777844343069*^9, 3.501777885805113*^9}, {3.501778300627495*^9, 
   3.501778305252673*^9}, {3.501778352909421*^9, 3.501778406442727*^9}, {
   3.501778445642251*^9, 3.5017784870336943`*^9}, {3.50177935975873*^9, 
   3.501779391376915*^9}, {3.501779486395031*^9, 3.5017795066015577`*^9}, {
   3.50177958181645*^9, 3.501779669636499*^9}, {3.501779789700733*^9, 
   3.501779800603448*^9}, {3.5017798406193*^9, 3.501779862910471*^9}, {
   3.501784501700515*^9, 3.501784505507679*^9}, {3.501784598165188*^9, 
   3.501784604368773*^9}, {3.501784916451499*^9, 3.501784960637738*^9}, {
   3.501785257226625*^9, 3.501785260885962*^9}, {3.50178541411646*^9, 
   3.501785477669379*^9}, 3.501786152273367*^9, 3.501786503721446*^9, {
   3.501786557846867*^9, 3.5017865826448*^9}, {3.512169397278523*^9, 
   3.512169445606512*^9}, {3.51217148437716*^9, 3.5121715078804607`*^9}, {
   3.6232441806261997`*^9, 3.62324418703036*^9}, {3.623244281346847*^9, 
   3.623244317140826*^9}, {3.623244455426198*^9, 3.623244587668618*^9}, {
   3.623244751407819*^9, 3.623244765525942*^9}, 3.6232448126774483`*^9, {
   3.623244910747307*^9, 3.623244972837925*^9}, {3.6232490108026533`*^9, 
   3.623249012991907*^9}, 3.6232577824616756`*^9, {3.623261330058443*^9, 
   3.623261339476244*^9}, {3.623262710323921*^9, 3.6232627493589478`*^9}, {
   3.6232627960178633`*^9, 3.623262821395109*^9}, {3.623263581855582*^9, 
   3.6232635991338053`*^9}, {3.623263641892476*^9, 3.623263642339182*^9}, {
   3.6232637003306*^9, 3.623263715714334*^9}, {3.623263794751793*^9, 
   3.623263804312509*^9}, {3.623264100376541*^9, 3.623264124332076*^9}, {
   3.623264173000024*^9, 3.623264257732629*^9}, 3.623264308467029*^9, {
   3.623264478199965*^9, 3.623264506855627*^9}, {3.623265139815689*^9, 
   3.623265148048449*^9}, {3.623273429062684*^9, 3.623273502382209*^9}, {
   3.6232735612916327`*^9, 3.6232735880668173`*^9}, {3.623273618618025*^9, 
   3.623273644579258*^9}, {3.623273764154895*^9, 3.623273828880546*^9}, {
   3.623274175938034*^9, 3.62327420206602*^9}, {3.623283934784854*^9, 
   3.623283936437642*^9}, 3.6232841388644953`*^9, 3.623284236967937*^9, {
   3.623285077877684*^9, 3.623285084401083*^9}, {3.623289893254157*^9, 
   3.623289897089925*^9}, {3.6232899284465027`*^9, 3.6232900171301403`*^9}, {
   3.623290079367676*^9, 3.623290100255698*^9}, {3.623290280724842*^9, 
   3.623290293974546*^9}, {3.623290459117778*^9, 3.623290501795014*^9}, {
   3.623291741138598*^9, 3.623291773009853*^9}, 3.623292276455986*^9, {
   3.6232925364355373`*^9, 3.6232925387339783`*^9}, 3.623292748667307*^9, 
   3.623293178528529*^9, {3.6232935291136723`*^9, 3.623293582444255*^9}, {
   3.623293627170208*^9, 3.623293722674391*^9}, 3.62329375673987*^9, {
   3.6232940253390408`*^9, 3.6232940306864653`*^9}, {3.62329411150406*^9, 
   3.623294155509177*^9}, {3.623294192102703*^9, 3.623294308358594*^9}, {
   3.623294343325498*^9, 3.623294385007304*^9}, 3.623294458550758*^9, {
   3.623294498139852*^9, 3.6232945051265097`*^9}, {3.6232945636613083`*^9, 
   3.623294565269031*^9}, {3.623294645821898*^9, 3.623294653057164*^9}, {
   3.623294747660412*^9, 3.623294748027844*^9}, 3.6232947935171833`*^9, {
   3.623294971146078*^9, 3.6232951163070498`*^9}, {3.6233218266875153`*^9, 
   3.6233218630695457`*^9}, {3.623321904347659*^9, 3.623321906099712*^9}, {
   3.623321945120222*^9, 3.623322004505938*^9}, {3.6233220504920397`*^9, 
   3.623322078702382*^9}, 3.623322224659233*^9, {3.623322295187747*^9, 
   3.623322310564253*^9}, {3.623322368730411*^9, 3.6233223842040358`*^9}, {
   3.6233224618473177`*^9, 3.6233225044059677`*^9}, {3.623322540856553*^9, 
   3.623322595578059*^9}, {3.623323063861298*^9, 3.623323088934001*^9}, 
   3.623323260917012*^9, {3.623323331796749*^9, 3.623323336450595*^9}, {
   3.623325704941272*^9, 3.6233257625859947`*^9}, {3.623326058412277*^9, 
   3.623326162520322*^9}, {3.623326199342607*^9, 3.623326250317484*^9}, {
   3.623326284225113*^9, 3.623326314836625*^9}, {3.6233263589046164`*^9, 
   3.6233263851623707`*^9}, {3.6233264548577623`*^9, 
   3.6233264717583857`*^9}, {3.623326565483532*^9, 3.623326605632455*^9}, {
   3.62333037941164*^9, 3.623330388127738*^9}, {3.6233773375736856`*^9, 
   3.6233773438600883`*^9}, {3.6234149003998547`*^9, 
   3.6234149054861193`*^9}, {3.62341572828802*^9, 3.6234157320697403`*^9}, {
   3.6234159702853527`*^9, 3.623415984238901*^9}, {3.6234162428926773`*^9, 
   3.623416260977552*^9}, {3.623416362423044*^9, 3.6234163672320957`*^9}, {
   3.6234166005702143`*^9, 3.6234166712168837`*^9}, {3.623416991973666*^9, 
   3.623417005645853*^9}, {3.6234170901741858`*^9, 3.623417131321607*^9}, {
   3.6234172453524113`*^9, 3.6234172896014442`*^9}, {3.623417432115884*^9, 
   3.623417454144607*^9}, 3.623431727632196*^9, {3.623629611400147*^9, 
   3.62362962640695*^9}, 3.623630850882885*^9, {3.623630961633844*^9, 
   3.623630983020175*^9}, {3.6236310247646923`*^9, 3.623631042497603*^9}, 
   3.623631660443214*^9, 3.6236317373572617`*^9, 3.623632092665855*^9, {
   3.6236332944371653`*^9, 3.623633297485626*^9}, {3.62363372027892*^9, 
   3.623633723935454*^9}, {3.623636536295403*^9, 3.623636560561884*^9}, {
   3.623636700425235*^9, 3.623636748642009*^9}, {3.6236373801255083`*^9, 
   3.62363738121589*^9}, {3.62363744607347*^9, 3.623637460409314*^9}, {
   3.623637510662517*^9, 3.62363755254554*^9}, 3.623637647422139*^9, 
   3.623637742483135*^9, {3.623637810510915*^9, 3.623637876361651*^9}, {
   3.623637925218536*^9, 3.6236379298589497`*^9}, {3.623637971165843*^9, 
   3.623638000176567*^9}, {3.6236381328646717`*^9, 3.623638146148625*^9}, 
   3.623638330856331*^9, {3.623638444194165*^9, 3.623638456023365*^9}, 
   3.623638562021315*^9, 3.623638654149753*^9, {3.62366312620481*^9, 
   3.6236631364057503`*^9}, {3.623679220977949*^9, 3.623679240350965*^9}, {
   3.6236792747206917`*^9, 3.623679277033072*^9}, {3.623679473604064*^9, 
   3.62367947741404*^9}, {3.6237092421708937`*^9, 3.623709249607275*^9}, {
   3.6237116169196177`*^9, 3.623711621473509*^9}, {3.623713833315723*^9, 
   3.623713860026208*^9}},
 CellLabel->
  "In[253]:=",ExpressionUUID->"4c603516-8ac3-44f5-b913-22e1272530e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DrawCircuit", "[", 
   RowBox[{"xyTemp_Association", ",", "connectionList_List", ",", 
    RowBox[{"extraElementList_List", ":", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ScaleFactor", ",", "tempSF", ",", 
      RowBox[{"xy", "=", "xyTemp"}], ",", "offsetNodeLabel"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"\[Not]", 
       RowBox[{"And", "[", 
        RowBox[{
         RowBox[{"And", "@@", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"assocRule", "\[Function]", 
              RowBox[{"MatchQ", "[", 
               RowBox[{"assocRule", ",", 
                RowBox[{"_", "->", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"_", "?", "NumericQ"}], ",", 
                   RowBox[{"_", "?", "NumericQ"}]}], "}"}]}]}], "]"}]}], 
             ")"}], "/@", 
            RowBox[{"Normal", "[", "xy", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"Head", "[", "xy", "]"}], "===", "Association"}]}], "]"}]}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"DrawCircuit", "::", "nodes"}], ",", "xy"}], "]"}], ";", 
       "Null"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Do", "[", 
        RowBox[{
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"nodeList", "=", 
              RowBox[{"Keys", "[", "xy", "]"}]}], ",", 
             RowBox[{"nodePair", "=", "\[IndentingNewLine]", 
              RowBox[{"Switch", "[", 
               RowBox[{"conn", ",", "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"_", ",", "_"}], "}"}], ",", "_"}], "}"}], ",", 
                RowBox[{"First", "[", "conn", "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"OffsetPoints", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"_", ",", "_"}], "}"}], ",", 
                    StyleBox["__",
                    FontSize->10]}], "]"}], ",", "_"}], "}"}], ",", 
                RowBox[{"conn", "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
                "\[IndentingNewLine]", "_", ",", 
                RowBox[{
                 RowBox[{"Message", "[", 
                  RowBox[{
                   RowBox[{"DrawCircuit", "::", "connection"}], ",", "conn"}],
                   "]"}], ";", 
                 RowBox[{"{", "}"}]}]}], "]"}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"\[Not]", 
              RowBox[{"SubsetQ", "[", 
               RowBox[{"nodeList", ",", "nodePair"}], "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Message", "[", 
              RowBox[{
               RowBox[{"DrawCircuit", "::", "nodematch"}], ",", "nodePair"}], 
              "]"}]}], "]"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"conn", ",", "connectionList"}], "}"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"GraphicsLayering", "[", "\[IndentingNewLine]", 
        RowBox[{"With", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"modifiedConnectionList", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                 "//", "ToList"}]}], "}"}], "&"}], "/@", 
             RowBox[{"(", 
              RowBox[{"With", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"OffsetPointsRule", "=", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"before___", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"OffsetPoints", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"a_", ",", "b_"}], "}"}], ",", "\[Lambda]_", ",", 
                    "OS_", ",", 
                    RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], 
                    "]"}], ",", "blah_"}], "}"}], ",", "after___"}], "}"}], 
                   "\[RuleDelayed]", 
                   RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"wireDirs", "=", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"ov", "=", 
                    RowBox[{"OptionValue", "[", 
                    RowBox[{"OffsetPoints", ",", "WireDirectives"}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{"MatrixQ", "[", "ov", "]"}], ",", "ov", ",", 
                    RowBox[{"{", 
                    RowBox[{"ov", ",", "ov"}], "}"}]}], "]"}]}], "]"}]}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{"uPerp", "=", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"u", "=", 
                    RowBox[{"Normalize", "[", 
                    RowBox[{
                    RowBox[{"xy", "[", "b", "]"}], "-", 
                    RowBox[{"xy", "[", "a", "]"}]}], "]"}]}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{
                    "u", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], ",", 
                    RowBox[{
                    "u", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "}"}], "/", "tempSF"}]}], 
                    "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{"With", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"r1", "=", 
                    RowBox[{
                    RowBox[{"xy", "[", "a", "]"}], "+", 
                    RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"xy", "[", "b", "]"}], "-", 
                    RowBox[{"xy", "[", "a", "]"}]}], ")"}]}], "+", 
                    RowBox[{"uPerp", " ", "OS"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"r2", "=", 
                    RowBox[{
                    RowBox[{"xy", "[", "b", "]"}], "+", 
                    RowBox[{"\[Lambda]", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"xy", "[", "a", "]"}], "-", 
                    RowBox[{"xy", "[", "b", "]"}]}], ")"}]}], "+", 
                    RowBox[{"uPerp", " ", "OS"}]}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"label1", "=", 
                    RowBox[{"offsetNodeLabel", "[", 
                    RowBox[{
                    RowBox[{"Length", "[", "xy", "]"}], "+", "1"}], "]"}]}], 
                    ",", 
                    RowBox[{"label2", "=", 
                    RowBox[{"offsetNodeLabel", "[", 
                    RowBox[{
                    RowBox[{"Length", "[", "xy", "]"}], "+", "2"}], "]"}]}]}],
                     "}"}], ",", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"AssociateTo", "[", 
                    RowBox[{"xy", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"label1", "\[Rule]", "r1"}], ",", 
                    RowBox[{"label2", "\[Rule]", "r2"}]}], "}"}]}], "]"}], 
                    ";", "\[IndentingNewLine]", 
                    RowBox[{"{", 
                    RowBox[{"before", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"a", ",", "label1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"WireDirectives", "\[Rule]", 
                    RowBox[{
                    "wireDirs", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}]}], "]"}], "}"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"label1", ",", "label2"}], "}"}], ",", 
                    RowBox[{"Join", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"WireDirectives", "\[Rule]", 
                    RowBox[{
                    "wireDirs", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}]}], "]"}], "}"}], ",", 
                    RowBox[{"blah", "//", "ToList"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"WireDirectives", "\[Rule]", 
                    RowBox[{
                    "wireDirs", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}]}], "]"}], "}"}]}], "]"}]}], 
                    "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"label2", ",", "b"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"0", ",", 
                    RowBox[{"WireDirectives", "\[Rule]", 
                    RowBox[{
                    "wireDirs", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}]}], "]"}], "}"}]}], "}"}], ",",
                     "after"}], "}"}]}]}], "]"}]}], "]"}]}]}], "}"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"connectionList", "//.", "OffsetPointsRule"}]}], 
               "]"}], ")"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"LinePolygonMappingRules", "=", "\[IndentingNewLine]", 
              RowBox[{"f", "\[Function]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Line", "[", "y_List", "]"}], "\[RuleDelayed]", 
                  RowBox[{"Line", "[", 
                   RowBox[{"f", "/@", "y"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Point", "[", "r_List", "]"}], "\[RuleDelayed]", 
                  RowBox[{"Point", "[", 
                   RowBox[{"f", "[", "r", "]"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Circle", "[", 
                   RowBox[{"x_List", ",", "R_", ",", "z___"}], "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{"Circle", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "x", "]"}], ",", 
                    RowBox[{"Norm", "[", 
                    RowBox[{
                    RowBox[{"f", "[", 
                    RowBox[{"{", 
                    RowBox[{"R", ",", "0"}], "}"}], "]"}], "-", 
                    RowBox[{"f", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "]"}], ",", 
                    "z"}], "]"}]}], ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Arrow", "[", "y_List", "]"}], "\[RuleDelayed]", 
                  RowBox[{"Arrow", "[", 
                   RowBox[{"f", "/@", "y"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Polygon", "[", "y_List", "]"}], "\[RuleDelayed]", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"f", "/@", "y"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Text", "[", 
                   RowBox[{"str_", ",", "x_", ",", "ext___"}], "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{"Text", "[", 
                   RowBox[{"str", ",", 
                    RowBox[{"f", "[", "x", "]"}], ",", "ext"}], "]"}]}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Rectangle", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x1_", ",", "y1_"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x2_", ",", "y2_"}], "}"}]}], "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"f", "/@", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x1", ",", "y1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x2", ",", "y1"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x2", ",", "y2"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"x1", ",", "y2"}], "}"}]}], "}"}]}], "]"}]}], ",",
                  "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"GraphicsComplex", "[", 
                   RowBox[{"y_List", ",", "unchanged___"}], "]"}], 
                  "\[RuleDelayed]", 
                  RowBox[{"GraphicsComplex", "[", 
                   RowBox[{
                    RowBox[{"f", "/@", "y"}], ",", "unchanged"}], "]"}]}], 
                 ",", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"SinePeriod", "[", 
                   RowBox[{"r0_List", ",", "T_"}], "]"}], "\[RuleDelayed]", 
                  RowBox[{"SinePeriod", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "r0", "]"}], ",", 
                    RowBox[{"Norm", "[", 
                    RowBox[{
                    RowBox[{"f", "[", 
                    RowBox[{"{", 
                    RowBox[{"T", ",", "0"}], "}"}], "]"}], "-", 
                    RowBox[{"f", "[", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "]"}]}], 
                   "]"}]}]}], "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"ScaleFactor", "=", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"modifiedConnectionList", "===", 
                 RowBox[{"{", "}"}]}], ",", "1", ",", 
                RowBox[{"Max", "@@", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Plus", "@@", 
                    RowBox[{"Size", "/@", 
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Length", "[", 
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}], "-", 
                    RowBox[{"Count", "[", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{"Wire", "[", "___", "]"}]}], "]"}]}], ")"}], "/", 
                    "2"}]}], ")"}], "/", 
                    RowBox[{"Norm", "[", 
                    RowBox[{"Subtract", "@@", 
                    RowBox[{"xy", "/@", 
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}]}], "]"}]}], "&"}], ")"}], "/@",
                     "modifiedConnectionList"}], "/.", 
                   RowBox[{"tempSF", "\[Rule]", "1"}]}], ")"}]}]}], "]"}]}], 
             ";", "\n", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"r", "=", 
                    RowBox[{"xy", "/@", 
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"ElementList", "=", 
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "/.", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"f_", "[", "exprs__", "]"}], "/;", 
                    RowBox[{"f", "=!=", "List"}]}], "\[RuleDelayed]", 
                    RowBox[{"f", "[", 
                    RowBox[{"exprs", ",", "opts"}], "]"}]}]}]}]}], "}"}], ",",
                     "\[IndentingNewLine]", 
                    RowBox[{"With", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"ShiftRight", "=", 
                    RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"ShiftBy", ",", "Elem"}], "}"}], ",", 
                    RowBox[{
                    RowBox[{"Draw", "[", "Elem", "]"}], "/.", 
                    RowBox[{"LinePolygonMappingRules", "[", 
                    RowBox[{
                    RowBox[{"#1", "+", 
                    RowBox[{"{", 
                    RowBox[{"ShiftBy", ",", "0"}], "}"}]}], "&"}], "]"}]}]}], 
                    "]"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"\[Gamma]", "=", 
                    RowBox[{
                    RowBox[{"Norm", "[", 
                    RowBox[{
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "-", 
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}], " ", 
                    "ScaleFactor"}]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"NumberOfElements", "=", 
                    RowBox[{
                    RowBox[{"Length", "[", "ElementList", "]"}], "-", 
                    RowBox[{"Count", "[", 
                    RowBox[{"ElementList", ",", 
                    RowBox[{"Wire", "[", "___", "]"}]}], "]"}]}]}]}], "}"}], 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"With", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"AlignElements", "=", 
                    RowBox[{"Function", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"SpacerWidth", ",", "EL"}], "}"}], ",", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"SpacedElementList", "=", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Flatten", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    "#", "\[LeftDoubleBracket]", "0", 
                    "\[RightDoubleBracket]"}], "===", "Wire"}], ",", 
                    RowBox[{"{", "#", "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Wire", "[", "SpacerWidth", "]"}], ",", "#"}], 
                    "}"}]}], "]"}], "&"}], ")"}], "/@", 
                    RowBox[{"Append", "[", 
                    RowBox[{"EL", ",", 
                    RowBox[{"Wire", "[", "SpacerWidth", "]"}]}], "]"}]}], "/.",
                     "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"CurrentArrow", "[", "x___", "]"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"With", "[", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"s", "=", 
                    RowBox[{
                    RowBox[{"Size", "[", 
                    RowBox[{"CurrentArrow", "[", "x", "]"}], "]"}], "/", 
                    "2"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Wire", "[", "s", "]"}], ",", 
                    RowBox[{"CurrentArrow", "[", "x", "]"}], ",", 
                    RowBox[{"Wire", "[", "s", "]"}]}], "}"}]}], "]"}]}]}], 
                    "]"}], "//.", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x___", ",", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"a_", ",", "u___"}], "]"}], ",", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"b_", ",", "v___"}], "]"}], ",", "y___"}], "}"}], 
                    "\[RuleDelayed]", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{"Wire", "[", 
                    RowBox[{
                    RowBox[{"a", "+", "b"}], ",", "u", ",", "v"}], "]"}], ",",
                     "y"}], "}"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"Wire", "[", "x___", "]"}], "\[RuleDelayed]", 
                    RowBox[{"Wire", "[", 
                    RowBox[{"x", ",", "opts"}], "]"}]}]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"ShiftRight", "@@@", "\[IndentingNewLine]", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"Transpose", "[", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"FoldList", "[", 
                    RowBox[{"Plus", ",", "0", ",", 
                    RowBox[{"Size", "/@", 
                    RowBox[{"Delete", "[", 
                    RowBox[{"SpacedElementList", ",", 
                    RowBox[{"-", "1"}]}], "]"}]}]}], "]"}], ",", 
                    "\[IndentingNewLine]", "SpacedElementList"}], "}"}], 
                    "]"}], "//.", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x___", ",", 
                    RowBox[{"{", 
                    RowBox[{"u1_", ",", 
                    RowBox[{"f_", "[", "v1___", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"u2_", ",", 
                    RowBox[{"Wire", "[", "v2___", "]"}]}], "}"}], ",", 
                    "y___"}], "}"}], "/;", 
                    RowBox[{"f", "=!=", "Wire"}]}], "\[RuleDelayed]", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", 
                    RowBox[{"{", 
                    RowBox[{"u2", ",", 
                    RowBox[{"Wire", "[", "v2", "]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"u1", ",", 
                    RowBox[{"f", "[", "v1", "]"}]}], "}"}], ",", "y"}], 
                    "}"}]}]}], ")"}]}]}], "]"}]}], "]"}]}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{"\[Alpha]", "=", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "-", 
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], ")"}], 
                    "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                    "\[Gamma]"]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"\[Beta]", "=", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "-", 
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], ")"}], 
                    "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                    "\[Gamma]"]}], ",", "\[IndentingNewLine]", 
                    RowBox[{"SpacerWidth", "=", 
                    FractionBox[
                    RowBox[{"\[Gamma]", "-", 
                    RowBox[{"Plus", "@@", 
                    RowBox[{"Size", "/@", "ElementList"}]}]}], 
                    RowBox[{"1", "+", "NumberOfElements"}]]}]}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"AlignElements", "[", 
                    RowBox[{"SpacerWidth", ",", "ElementList"}], "]"}], "/.", 
                    RowBox[{"LinePolygonMappingRules", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"\[Alpha]", ",", 
                    RowBox[{"-", "\[Beta]"}]}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Beta]", ",", "\[Alpha]"}], "}"}]}], "}"}], ".",
                     "#1"}], "+", 
                    RowBox[{
                    "r", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "&"}], "]"}]}]}], "]"}]}], 
                    "]"}]}], "]"}], "&"}], ")"}], "/@", 
                  "modifiedConnectionList"}], "/.", "SineReplacementRule"}], "/.", 
                RowBox[{"tempSF", "\[Rule]", "ScaleFactor"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"nodeSingleElementList", "\[Function]", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"Draw", "/@", 
                    RowBox[{"ToList", "[", 
                    RowBox[{
                    "nodeSingleElementList", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}], "]"}]}], ")"}], "/.", 
                   RowBox[{"LinePolygonMappingRules", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"#", "/", "ScaleFactor"}], "+", 
                    RowBox[{"xy", "[", 
                    RowBox[{
                    "nodeSingleElementList", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "]"}]}], "&"}], "]"}]}]}], 
                 ")"}], "/@", "extraElementList"}]}], "\[IndentingNewLine]", 
              "}"}]}]}], "]"}]}], "]"}], "]"}]}]}], "]"}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106302454693*^9}, {3.476106416559104*^9, 3.476106460235757*^9}, {
   3.476106581199346*^9, 3.476106634588523*^9}, {3.476107305994638*^9, 
   3.476107317380512*^9}, {3.476107760958149*^9, 3.476107778795526*^9}, {
   3.476107900121354*^9, 3.476107937996397*^9}, {3.476108071920807*^9, 
   3.4761080887319193`*^9}, {3.476108164418932*^9, 3.476108201306342*^9}, {
   3.476108692243926*^9, 3.476108768395046*^9}, {3.476109124682055*^9, 
   3.4761091262062483`*^9}, {3.476110226418565*^9, 3.476110227231073*^9}, {
   3.476110600044496*^9, 3.476110602368554*^9}, 3.4761109965306787`*^9, 
   3.476113452029992*^9, {3.476114100567851*^9, 3.476114187007794*^9}, {
   3.47611430142743*^9, 3.476114304128113*^9}, {3.476121642319868*^9, 
   3.476121675306847*^9}, {3.4761220143333883`*^9, 3.476122060037277*^9}, {
   3.4761447996006393`*^9, 3.4761448346382732`*^9}, {3.476145175992147*^9, 
   3.4761451815100527`*^9}, 3.476185402756797*^9, {3.476185581284341*^9, 
   3.476185589451889*^9}, 3.4761966376038027`*^9, 3.4761967894912252`*^9, {
   3.476210429386447*^9, 3.476210434020817*^9}, 3.476211098935493*^9, {
   3.476211138135975*^9, 3.476211141958665*^9}, {3.4763659569687443`*^9, 
   3.476365978899395*^9}, 3.4763660615280333`*^9, {3.4763661438934393`*^9, 
   3.476366273051663*^9}, {3.4763663367016153`*^9, 3.476366368069922*^9}, {
   3.476366407202338*^9, 3.476366463178041*^9}, 3.4763664983677998`*^9, {
   3.476366944839669*^9, 3.476366966909127*^9}, {3.47636906963199*^9, 
   3.476369082370784*^9}, {3.4763691489642277`*^9, 3.476369151336062*^9}, {
   3.476369292761282*^9, 3.4763694008740788`*^9}, {3.476369442834669*^9, 
   3.476369470181513*^9}, 3.4763695009737387`*^9, {3.476369531406848*^9, 
   3.4763695386854687`*^9}, {3.476369603837468*^9, 3.476369620179778*^9}, {
   3.476369745858946*^9, 3.47636978937963*^9}, {3.4763710476460733`*^9, 
   3.476371109877808*^9}, {3.47638096148899*^9, 3.476380978055448*^9}, {
   3.476398400776684*^9, 3.47639840743296*^9}, {3.476398627718067*^9, 
   3.476398679770344*^9}, {3.476409173509157*^9, 3.476409180883336*^9}, {
   3.476409234657473*^9, 3.476409246015324*^9}, {3.476409304322565*^9, 
   3.476409305727536*^9}, {3.476457429231205*^9, 3.476457468984474*^9}, 
   3.476457534709152*^9, {3.476457604400165*^9, 3.476457637061607*^9}, {
   3.476458364549268*^9, 3.476458364826387*^9}, {3.476458399923841*^9, 
   3.4764585372118187`*^9}, 3.4764586414235907`*^9, {3.476494435693815*^9, 
   3.4764944367038937`*^9}, {3.476494795805993*^9, 3.476494845831613*^9}, {
   3.476494940312262*^9, 3.476494954828953*^9}, {3.476527260278055*^9, 
   3.476527277828783*^9}, {3.4765273245499277`*^9, 3.476527325580926*^9}, {
   3.476527376494852*^9, 3.476527471451088*^9}, {3.47652752795599*^9, 
   3.476527618608492*^9}, {3.4765276743070707`*^9, 3.4765277443511477`*^9}, {
   3.476527811256331*^9, 3.4765279086587677`*^9}, {3.476527950239513*^9, 
   3.47652797289771*^9}, {3.476528021180295*^9, 3.476528034933723*^9}, {
   3.476528123304459*^9, 3.476528124918633*^9}, 3.4765281593347797`*^9, {
   3.476528230136219*^9, 3.476528231453207*^9}, {3.476582185022448*^9, 
   3.476582187449844*^9}, {3.476582270011695*^9, 3.476582273937911*^9}, {
   3.476582461798917*^9, 3.476582472308679*^9}, {3.476612387392542*^9, 
   3.4766124325809793`*^9}, {3.47664145901128*^9, 3.476641493865787*^9}, {
   3.476641527138528*^9, 3.476641528803323*^9}, {3.497227452568782*^9, 
   3.49722748258984*^9}, {3.497227639286525*^9, 3.497227642178056*^9}, {
   3.497314289563693*^9, 3.497314300247407*^9}, {3.4973161564734297`*^9, 
   3.4973162246478567`*^9}, {3.497316272392581*^9, 3.4973162727285223`*^9}, {
   3.497316313450996*^9, 3.4973163828268843`*^9}, {3.4973175404090776`*^9, 
   3.4973176211413107`*^9}, {3.497317787153141*^9, 3.497317894625948*^9}, {
   3.497349867898911*^9, 3.497349881773623*^9}, 3.497365131284121*^9, {
   3.4973668472067347`*^9, 3.497366872696767*^9}, 3.497366920617692*^9, 
   3.4973672781945553`*^9, 3.497367338353608*^9, {3.497367601403747*^9, 
   3.497367614530047*^9}, 3.500751070432418*^9, {3.5011193178773403`*^9, 
   3.501119318826271*^9}, 3.501119761224312*^9, {3.5011199242814627`*^9, 
   3.501119969362002*^9}, {3.5011200839411383`*^9, 3.50112008823606*^9}, {
   3.5011202044833603`*^9, 3.501120212083962*^9}, {3.501158008848362*^9, 
   3.501158062514268*^9}, {3.50115811174193*^9, 3.501158236607304*^9}, {
   3.5011582745775223`*^9, 3.5011582830941973`*^9}, {3.501336475403908*^9, 
   3.501336476471827*^9}, {3.501343635266762*^9, 3.501343639474765*^9}, {
   3.5013437711866627`*^9, 3.501343779279169*^9}, 3.501343870522444*^9, {
   3.501348407203644*^9, 3.501348417513266*^9}, {3.501348511270318*^9, 
   3.501348514811728*^9}, {3.50134858518331*^9, 3.501348587988357*^9}, {
   3.5013488462863703`*^9, 3.50134885043552*^9}, {3.501348918903163*^9, 
   3.501348951898562*^9}, {3.501419133741438*^9, 3.501419176631116*^9}, {
   3.501444029447609*^9, 3.501444060618021*^9}, {3.501444115193963*^9, 
   3.5014441253928137`*^9}, {3.501444543518688*^9, 3.501444549192799*^9}, {
   3.501444659922431*^9, 3.501444734596438*^9}, {3.501445492805297*^9, 
   3.501445503741107*^9}, {3.5014455379431868`*^9, 3.501445651577888*^9}, 
   3.5014457271550407`*^9, 3.501445810930554*^9, {3.501446054516151*^9, 
   3.501446079318241*^9}, {3.5014490079757833`*^9, 3.501449008910886*^9}, {
   3.501449287098826*^9, 3.501449303786297*^9}, {3.5014499475028687`*^9, 
   3.50144995025161*^9}, {3.501450065181651*^9, 3.5014500688049793`*^9}, 
   3.501453017847331*^9, {3.501453079703404*^9, 3.5014531131775208`*^9}, {
   3.501453284527351*^9, 3.501453302148003*^9}, {3.501455554899455*^9, 
   3.50145562014149*^9}, {3.501464209859069*^9, 3.5014642398201857`*^9}, {
   3.5014676402056847`*^9, 3.501467672783102*^9}, {3.501777153485264*^9, 
   3.5017771935533133`*^9}, {3.501777791032349*^9, 3.501777799596127*^9}, {
   3.501777844343069*^9, 3.501777885805113*^9}, {3.501778300627495*^9, 
   3.501778305252673*^9}, {3.501778352909421*^9, 3.501778406442727*^9}, {
   3.501778445642251*^9, 3.5017784870336943`*^9}, {3.50177935975873*^9, 
   3.501779391376915*^9}, {3.501779486395031*^9, 3.5017795066015577`*^9}, {
   3.50177958181645*^9, 3.501779669636499*^9}, {3.501779789700733*^9, 
   3.501779800603448*^9}, {3.5017798406193*^9, 3.501779862910471*^9}, {
   3.501784501700515*^9, 3.501784505507679*^9}, {3.501784598165188*^9, 
   3.501784604368773*^9}, {3.501784916451499*^9, 3.501784960637738*^9}, {
   3.501785257226625*^9, 3.501785260885962*^9}, {3.50178541411646*^9, 
   3.501785477669379*^9}, 3.501786152273367*^9, 3.501786503721446*^9, {
   3.501786557846867*^9, 3.5017865826448*^9}, {3.512169397278523*^9, 
   3.512169445606512*^9}, {3.51217148437716*^9, 3.5121715078804607`*^9}, {
   3.6232441806261997`*^9, 3.62324418703036*^9}, {3.623244281346847*^9, 
   3.623244317140826*^9}, {3.623244455426198*^9, 3.623244587668618*^9}, {
   3.623244751407819*^9, 3.623244765525942*^9}, 3.6232448126774483`*^9, {
   3.623244910747307*^9, 3.623244972837925*^9}, {3.6232490108026533`*^9, 
   3.623249012991907*^9}, 3.6232577824616756`*^9, {3.623261330058443*^9, 
   3.623261339476244*^9}, {3.623262710323921*^9, 3.6232627493589478`*^9}, {
   3.6232627960178633`*^9, 3.623262821395109*^9}, {3.623263581855582*^9, 
   3.6232635991338053`*^9}, {3.623263641892476*^9, 3.623263642339182*^9}, {
   3.6232637003306*^9, 3.623263715714334*^9}, {3.623263794751793*^9, 
   3.623263804312509*^9}, {3.623264100376541*^9, 3.623264124332076*^9}, {
   3.623264173000024*^9, 3.623264257732629*^9}, 3.623264308467029*^9, {
   3.623264478199965*^9, 3.623264506855627*^9}, {3.623265139815689*^9, 
   3.623265148048449*^9}, {3.623273429062684*^9, 3.623273502382209*^9}, {
   3.6232735612916327`*^9, 3.6232735880668173`*^9}, {3.623273618618025*^9, 
   3.623273644579258*^9}, {3.623273764154895*^9, 3.623273828880546*^9}, {
   3.623274175938034*^9, 3.62327420206602*^9}, {3.623283934784854*^9, 
   3.623283936437642*^9}, 3.6232841388644953`*^9, 3.623284236967937*^9, {
   3.623285077877684*^9, 3.623285084401083*^9}, {3.623289893254157*^9, 
   3.623289897089925*^9}, {3.6232899284465027`*^9, 3.6232900171301403`*^9}, {
   3.623290079367676*^9, 3.623290100255698*^9}, {3.623290280724842*^9, 
   3.623290293974546*^9}, {3.623290459117778*^9, 3.623290501795014*^9}, {
   3.623291741138598*^9, 3.623291773009853*^9}, 3.623292276455986*^9, {
   3.6232925364355373`*^9, 3.6232925387339783`*^9}, 3.623292748667307*^9, 
   3.623293178528529*^9, {3.6232935291136723`*^9, 3.623293582444255*^9}, {
   3.623293627170208*^9, 3.623293722674391*^9}, 3.62329375673987*^9, {
   3.6232940253390408`*^9, 3.6232940306864653`*^9}, {3.62329411150406*^9, 
   3.623294155509177*^9}, {3.623294192102703*^9, 3.623294308358594*^9}, {
   3.623294343325498*^9, 3.623294385007304*^9}, 3.623294458550758*^9, {
   3.623294498139852*^9, 3.6232945051265097`*^9}, {3.6232945636613083`*^9, 
   3.623294565269031*^9}, {3.623294645821898*^9, 3.623294653057164*^9}, {
   3.623294747660412*^9, 3.623294748027844*^9}, 3.6232947935171833`*^9, {
   3.623294971146078*^9, 3.6232951163070498`*^9}, {3.6233218266875153`*^9, 
   3.6233218630695457`*^9}, {3.623321904347659*^9, 3.623321906099712*^9}, {
   3.623321945120222*^9, 3.623322004505938*^9}, {3.6233220504920397`*^9, 
   3.623322078702382*^9}, 3.623322224659233*^9, {3.623322295187747*^9, 
   3.623322310564253*^9}, {3.623322368730411*^9, 3.6233223842040358`*^9}, {
   3.6233224618473177`*^9, 3.6233225044059677`*^9}, {3.623322540856553*^9, 
   3.623322595578059*^9}, {3.623323063861298*^9, 3.623323088934001*^9}, 
   3.623323260917012*^9, {3.623323331796749*^9, 3.623323336450595*^9}, {
   3.623325704941272*^9, 3.6233257625859947`*^9}, {3.623326058412277*^9, 
   3.623326162520322*^9}, {3.623326199342607*^9, 3.623326250317484*^9}, {
   3.623326284225113*^9, 3.623326314836625*^9}, {3.6233263589046164`*^9, 
   3.6233263851623707`*^9}, {3.6233264548577623`*^9, 
   3.6233264717583857`*^9}, {3.623326565483532*^9, 3.623326605632455*^9}, {
   3.62333037941164*^9, 3.623330388127738*^9}, {3.6233773375736856`*^9, 
   3.6233773438600883`*^9}, {3.6234149003998547`*^9, 
   3.6234149054861193`*^9}, {3.62341572828802*^9, 3.6234157320697403`*^9}, {
   3.6234159702853527`*^9, 3.623415984238901*^9}, {3.6234162428926773`*^9, 
   3.623416260977552*^9}, {3.623416362423044*^9, 3.6234163672320957`*^9}, {
   3.6234166005702143`*^9, 3.6234166712168837`*^9}, {3.623416991973666*^9, 
   3.623417005645853*^9}, {3.6234170901741858`*^9, 3.623417131321607*^9}, {
   3.6234172453524113`*^9, 3.6234172896014442`*^9}, {3.623417432115884*^9, 
   3.623417454144607*^9}, 3.623431727632196*^9, {3.623629611400147*^9, 
   3.62362962640695*^9}, 3.623630850882885*^9, {3.623630961633844*^9, 
   3.623630983020175*^9}, {3.6236310247646923`*^9, 3.623631042497603*^9}, 
   3.623631660443214*^9, 3.6236317373572617`*^9, 3.623632092665855*^9, {
   3.6236332944371653`*^9, 3.623633297485626*^9}, {3.62363372027892*^9, 
   3.623633723935454*^9}, {3.623636536295403*^9, 3.623636560561884*^9}, {
   3.623636700425235*^9, 3.623636748642009*^9}, {3.6236373801255083`*^9, 
   3.62363738121589*^9}, {3.62363744607347*^9, 3.623637460409314*^9}, {
   3.623637510662517*^9, 3.62363755254554*^9}, 3.623637647422139*^9, 
   3.623637742483135*^9, {3.623637810510915*^9, 3.623637876361651*^9}, {
   3.623637925218536*^9, 3.6236379298589497`*^9}, {3.623637971165843*^9, 
   3.623638000176567*^9}, {3.6236381328646717`*^9, 3.623638146148625*^9}, 
   3.623638330856331*^9, {3.623638444194165*^9, 3.623638456023365*^9}, 
   3.623638562021315*^9, 3.623638654149753*^9, {3.62366312620481*^9, 
   3.6236631364057503`*^9}, {3.623679220977949*^9, 3.623679240350965*^9}, {
   3.6236792747206917`*^9, 3.623679277033072*^9}, {3.623679473604064*^9, 
   3.62367947741404*^9}, {3.6237092421708937`*^9, 3.623709249607275*^9}, {
   3.6237116169196177`*^9, 3.623711621473509*^9}, {3.623713833315723*^9, 
   3.623713860026208*^9}, 3.623715205859688*^9, 3.6237155400912046`*^9, {
   3.6237157920267344`*^9, 3.623715842753686*^9}, {3.813277540617111*^9, 
   3.813277546775956*^9}, 3.81327760446173*^9},
 CellLabel->
  "In[254]:=",ExpressionUUID->"f40b903f-9267-4463-8b2f-f7bc9bf66ff0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ToList", "=", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Head", "[", "#", "]"}], "===", "List"}], ",", "#", ",", 
      RowBox[{"{", "#", "}"}]}], "]"}], "&"}]}], ";"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.500861382220685*^9, 3.5008613993894463`*^9}, {
   3.500861447526806*^9, 3.500861450376808*^9}, {3.500861484403572*^9, 
   3.500861487278851*^9}, {3.500861522091323*^9, 3.500861525876072*^9}, {
   3.500861561564207*^9, 3.500861607002664*^9}, {3.5008616617670803`*^9, 
   3.50086170981633*^9}, {3.500863690517602*^9, 3.500863736044923*^9}, {
   3.500863868731873*^9, 3.5008639044170437`*^9}, 3.5009975630589733`*^9},
 CellLabel->
  "In[255]:=",ExpressionUUID->"0741f790-8e69-4b0b-8479-428ebf9d2a39"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GraphicsLayering", "[", "expr_", "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"belowLayers", "=", 
       RowBox[{"Cases", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"GraphicsLayer", "[", 
          RowBox[{
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"NumericQ", "[", "#", "]"}], "\[And]", 
               RowBox[{"#", "\[LessEqual]", "0"}]}], "&"}], ")"}]}], ",", 
           "_"}], "]"}], ",", "\[Infinity]"}], "]"}]}], ",", 
      RowBox[{"aboveLayers", "=", 
       RowBox[{"Cases", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"GraphicsLayer", "[", 
          RowBox[{
           RowBox[{"_", "?", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"NumericQ", "[", "#", "]"}], "\[And]", 
               RowBox[{"#", ">", "0"}]}], "&"}], ")"}]}], ",", "_"}], "]"}], 
         ",", "\[Infinity]"}], "]"}]}], ",", 
      RowBox[{"middleLayer", "=", 
       RowBox[{"DeleteCases", "[", 
        RowBox[{"expr", ",", 
         RowBox[{"GraphicsLayer", "[", 
          RowBox[{
           RowBox[{"_", "?", "NumericQ"}], ",", "_"}], "]"}], ",", 
         "\[Infinity]"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"sortGL", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"#1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
          "<", 
         RowBox[{
         "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}]}], 
        "&"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{"belowLayers", ",", "sortGL"}], "]"}], ",", "middleLayer", 
       ",", 
       RowBox[{"Sort", "[", 
        RowBox[{"aboveLayers", ",", "sortGL"}], "]"}]}], "}"}], "/.", 
     RowBox[{
      RowBox[{"GraphicsLayer", "[", 
       RowBox[{"_", ",", "stuff_"}], "]"}], "\[RuleDelayed]", " ", 
      "stuff"}]}]}], "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106302454693*^9}, {3.476106416559104*^9, 3.476106460235757*^9}, {
   3.476106581199346*^9, 3.476106634588523*^9}, {3.476107305994638*^9, 
   3.476107317380512*^9}, {3.476107760958149*^9, 3.476107778795526*^9}, {
   3.476107900121354*^9, 3.476107937996397*^9}, {3.476108071920807*^9, 
   3.4761080887319193`*^9}, {3.476108164418932*^9, 3.476108201306342*^9}, {
   3.476108692243926*^9, 3.476108768395046*^9}, {3.476109124682055*^9, 
   3.4761091262062483`*^9}, {3.476110226418565*^9, 3.476110227231073*^9}, {
   3.476110600044496*^9, 3.476110602368554*^9}, 3.4761109965306787`*^9, 
   3.476113452029992*^9, {3.476114100567851*^9, 3.476114187007794*^9}, {
   3.47611430142743*^9, 3.476114304128113*^9}, {3.476121642319868*^9, 
   3.476121675306847*^9}, {3.4761220143333883`*^9, 3.476122060037277*^9}, {
   3.4761447996006393`*^9, 3.4761448346382732`*^9}, {3.476145175992147*^9, 
   3.4761451815100527`*^9}, 3.476185402756797*^9, {3.476185581284341*^9, 
   3.476185589451889*^9}, 3.4761966376038027`*^9, 3.4761967894912252`*^9, {
   3.476210429386447*^9, 3.476210434020817*^9}, 3.476211098935493*^9, {
   3.476211138135975*^9, 3.476211141958665*^9}, {3.4763659569687443`*^9, 
   3.476365978899395*^9}, 3.4763660615280333`*^9, {3.4763661438934393`*^9, 
   3.476366273051663*^9}, {3.4763663367016153`*^9, 3.476366368069922*^9}, {
   3.476366407202338*^9, 3.476366463178041*^9}, 3.4763664983677998`*^9, {
   3.476366944839669*^9, 3.476366966909127*^9}, {3.47636906963199*^9, 
   3.476369082370784*^9}, {3.4763691489642277`*^9, 3.476369151336062*^9}, {
   3.476369292761282*^9, 3.4763694008740788`*^9}, {3.476369442834669*^9, 
   3.476369470181513*^9}, 3.4763695009737387`*^9, {3.476369531406848*^9, 
   3.4763695386854687`*^9}, {3.476369603837468*^9, 3.476369620179778*^9}, {
   3.476369745858946*^9, 3.47636978937963*^9}, {3.4763710476460733`*^9, 
   3.476371109877808*^9}, {3.47638096148899*^9, 3.476380978055448*^9}, {
   3.476398400776684*^9, 3.47639840743296*^9}, {3.476398627718067*^9, 
   3.476398679770344*^9}, {3.476409173509157*^9, 3.476409180883336*^9}, {
   3.476409234657473*^9, 3.476409246015324*^9}, {3.476409304322565*^9, 
   3.476409305727536*^9}, {3.476457429231205*^9, 3.476457468984474*^9}, 
   3.476457534709152*^9, {3.476457604400165*^9, 3.476457637061607*^9}, {
   3.476458364549268*^9, 3.476458364826387*^9}, {3.476458399923841*^9, 
   3.4764585372118187`*^9}, 3.4764586414235907`*^9, {3.476494435693815*^9, 
   3.4764944367038937`*^9}, {3.476494795805993*^9, 3.476494845831613*^9}, {
   3.476494940312262*^9, 3.476494954828953*^9}, {3.476527260278055*^9, 
   3.476527277828783*^9}, {3.4765273245499277`*^9, 3.476527325580926*^9}, {
   3.476527376494852*^9, 3.476527471451088*^9}, {3.47652752795599*^9, 
   3.476527618608492*^9}, {3.4765276743070707`*^9, 3.4765277443511477`*^9}, {
   3.476527811256331*^9, 3.4765279086587677`*^9}, {3.476527950239513*^9, 
   3.47652797289771*^9}, {3.476528021180295*^9, 3.476528034933723*^9}, {
   3.476528123304459*^9, 3.476528124918633*^9}, 3.4765281593347797`*^9, {
   3.476528230136219*^9, 3.476528231453207*^9}, {3.476582185022448*^9, 
   3.476582187449844*^9}, {3.476582270011695*^9, 3.476582273937911*^9}, {
   3.476582461798917*^9, 3.476582472308679*^9}, {3.476612387392542*^9, 
   3.4766124325809793`*^9}, {3.47664145901128*^9, 3.476641493865787*^9}, {
   3.476641527138528*^9, 3.476641528803323*^9}, {3.497227452568782*^9, 
   3.49722748258984*^9}, {3.497227639286525*^9, 3.497227642178056*^9}, {
   3.497314289563693*^9, 3.497314300247407*^9}, {3.4973161564734297`*^9, 
   3.4973162246478567`*^9}, {3.497316272392581*^9, 3.4973162727285223`*^9}, {
   3.497316313450996*^9, 3.4973163828268843`*^9}, {3.4973175404090776`*^9, 
   3.4973176211413107`*^9}, {3.497317787153141*^9, 3.497317894625948*^9}, {
   3.497349867898911*^9, 3.497349921313739*^9}, {3.497349964552272*^9, 
   3.497349969671652*^9}, {3.4973500100648203`*^9, 3.497350070532588*^9}, {
   3.4973501009718847`*^9, 3.497350274183133*^9}, {3.4973503370775423`*^9, 
   3.497350365524782*^9}, 3.49736385981549*^9, {3.497363911064766*^9, 
   3.497363924751402*^9}, {3.497363993453837*^9, 3.4973640297269697`*^9}, {
   3.497364080878986*^9, 3.497364249131962*^9}},
 CellLabel->
  "In[256]:=",ExpressionUUID->"46b4194b-fc61-4812-89db-1071af0eee69"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "UnderShadeWrapper", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"GraphicsLayer", "\[Rule]", 
     RowBox[{"-", "1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UnderShadeWrapper", "[", 
    RowBox[{"dirs_", ",", 
     RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], "[", "expr_", "]"}], ":=", 
  RowBox[{"expr", "/.", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Line", "[", "x_", "]"}], "\[RuleDelayed]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Line", "[", "x", "]"}], ",", 
       RowBox[{"GraphicsLayer", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", "GraphicsLayer", "]"}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Head", "[", "dirs", "]"}], "===", "List"}], ",", "dirs",
             ",", 
            RowBox[{"{", "dirs", "}"}]}], "]"}], "~", "Join", "~", 
          RowBox[{"{", 
           RowBox[{"Line", "[", "x", "]"}], "}"}]}]}], "]"}]}], "}"}]}], 
    ")"}]}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.497443923162856*^9, 3.4974439549942093`*^9}, {
   3.49744437224179*^9, 3.497444440946773*^9}, {3.497444477093293*^9, 
   3.4974444787677517`*^9}, {3.497444764611095*^9, 3.497444766729195*^9}, {
   3.497445131187653*^9, 3.4974451318939333`*^9}, {3.497445181678639*^9, 
   3.497445231984823*^9}, {3.497445276430973*^9, 3.497445397866549*^9}, {
   3.4974455623707848`*^9, 3.497445565360857*^9}, {3.497445620759047*^9, 
   3.497445624413591*^9}, 3.5005144493546457`*^9, {3.5005214878529577`*^9, 
   3.5005214986028557`*^9}, 3.500521545225803*^9, {3.5005513935149193`*^9, 
   3.500551420805691*^9}, {3.500553801907793*^9, 3.500553810469396*^9}, {
   3.500656880076523*^9, 3.500656937774864*^9}, 3.500657352577973*^9},
 CellLabel->
  "In[257]:=",ExpressionUUID->"20110727-c57a-4248-bf05-54a0bef7ab28"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "UnderRectangleWrapper", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"GraphicsLayer", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"OverLength", "\[Rule]", "0"}], ",", 
     RowBox[{"OverWidth", "\[Rule]", "0"}]}], "}"}]}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"UnderRectangleWrapper", "[", 
     RowBox[{"dirs_", ",", 
      RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], "[", "expr_", "]"}], ":=", 
   RowBox[{"expr", "/.", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Line", "[", "x_", "]"}], "\[RuleDelayed]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Line", "[", "x", "]"}], ",", 
        RowBox[{"GraphicsLayer", "[", 
         RowBox[{
          RowBox[{"OptionValue", "[", "GraphicsLayer", "]"}], ",", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Head", "[", "dirs", "]"}], "===", "List"}], ",", 
             "dirs", ",", 
             RowBox[{"{", "dirs", "}"}]}], "]"}], "~", "Join", "~", 
           RowBox[{"With", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x0", "=", 
                RowBox[{"x", "\[LeftDoubleBracket]", 
                 RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}]}], ",", 
               RowBox[{"x1", "=", 
                RowBox[{"x", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", "1"}], "\[RightDoubleBracket]"}]}],
                ",", 
               RowBox[{"w", "=", 
                RowBox[{"Max", "[", 
                 RowBox[{"Last", "/@", "x"}], "]"}]}]}], "}"}], ",", 
             RowBox[{"With", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"width", "=", 
                 RowBox[{"w", "+", 
                  RowBox[{"OptionValue", "[", "OverWidth", "]"}]}]}], "}"}], 
               ",", 
               RowBox[{"{", 
                RowBox[{"Rectangle", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x0", "-", 
                    RowBox[{"OptionValue", "[", "OverLength", "]"}]}], ",", 
                    RowBox[{"-", "width"}]}], "}"}], ",", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x1", "+", 
                    RowBox[{"OptionValue", "[", "OverLength", "]"}]}], ",", 
                    "width"}], "}"}]}], "]"}], "}"}]}], "]"}]}], "]"}]}]}], 
         "]"}]}], "}"}]}], ")"}]}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.5005135803383417`*^9, 3.50051359366166*^9}, {
   3.500514274101239*^9, 3.5005142760990753`*^9}, 3.500514362165971*^9, {
   3.500515488755834*^9, 3.500515695532559*^9}, {3.500515730707601*^9, 
   3.500515790610778*^9}, {3.500516423395658*^9, 3.500516442524493*^9}, {
   3.500516912455236*^9, 3.500516967319515*^9}, {3.5005178380714684`*^9, 
   3.500517857160977*^9}, {3.500517947236026*^9, 3.500517993106851*^9}, {
   3.500519314636359*^9, 3.50051943673781*^9}, 3.500519483171617*^9, {
   3.500519517382613*^9, 3.5005195212778893`*^9}, {3.500519853109914*^9, 
   3.5005198598220167`*^9}, {3.500520228180921*^9, 3.500520292833934*^9}, {
   3.500520364857953*^9, 3.5005203781101933`*^9}, {3.500657886444757*^9, 
   3.5006579141930113`*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"0efd2716-bd22-40d9-b430-f515e7894378"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Size", "[", 
   RowBox[{"CircuitSwitch", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
  RowBox[{"OptionValue", "[", 
   RowBox[{"CircuitSwitch", ",", "CircuitSwitchSize"}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"CircuitSwitch", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"L", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"CircuitSwitch", ",", "CircuitSwitchSize"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Theta]", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"OptionValue", "[", 
           RowBox[{"CircuitSwitch", ",", "CircuitSwitchPosition"}], "]"}], 
          "===", "\"\<Open\>\""}], ",", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"CircuitSwitch", ",", "CircuitSwitchOpenSense"}], "]"}],
              "===", "\"\<Counterclockwise\>\""}], ",", "1", ",", 
            RowBox[{"-", "1"}]}], "]"}], "\[Times]", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"CircuitSwitch", ",", "CircuitSwitchOpenAngle"}], "]"}]}], 
         ",", "\[IndentingNewLine]", "0"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"OptionValue", "[", 
        RowBox[{"CircuitSwitch", ",", "BaseElementDirectives"}], "]"}], "//", 
       "ToList"}], ",", 
      RowBox[{
       RowBox[{"OptionValue", "[", 
        RowBox[{"CircuitSwitch", ",", "CircuitSwitchDirectives"}], "]"}], "//",
        "ToList"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Line", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}], ",", 
           RowBox[{"L", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Cos", "[", "\[Theta]", "]"}], ",", 
              RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}]}], "}"}], 
         "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], "]"}], ",", 
        RowBox[{"Point", "[", 
         RowBox[{"{", 
          RowBox[{"L", ",", "0"}], "}"}], "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.813273617089204*^9, 3.813273630345758*^9}, {
   3.813273667392716*^9, 3.813273728294713*^9}, {3.8132738430609426`*^9, 
   3.813273877499722*^9}, {3.8132743966445303`*^9, 3.813274507863325*^9}, {
   3.813274544574942*^9, 3.8132745792920427`*^9}, {3.813274615886256*^9, 
   3.813274667901658*^9}, {3.813274727553187*^9, 3.8132748059044456`*^9}, {
   3.81327488141378*^9, 3.8132749533672323`*^9}, 3.813275478010503*^9, {
   3.81327561872204*^9, 3.81327564346389*^9}, {3.813275864218045*^9, 
   3.8132759060128736`*^9}, 3.813275942144383*^9, {3.8132759778883953`*^9, 
   3.813276042273889*^9}, {3.813276119037304*^9, 3.8132761563406076`*^9}, {
   3.813277151044483*^9, 3.813277177960429*^9}, {3.813277309120941*^9, 
   3.813277311825457*^9}, {3.813277796892523*^9, 3.813277826339786*^9}},
 CellLabel->
  "In[260]:=",ExpressionUUID->"83eed3b9-c985-4dfa-bd35-68e1432959ca"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Resistor", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"Resistor", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Resistor", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"OptionValue", "[", 
     RowBox[{"Resistor", ",", "ResistorTurnNumber"}], "]"}], "/", "8"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Resistor", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Resistor", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "Automatic", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Resistor", ",", "DefaultTextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Resistor", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"OptionValue", "[", 
            RowBox[{"Resistor", ",", "TextOffset"}], "]"}]}], "}"}]}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"TD", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Resistor", ",", "TextOffsetScale"}], "]"}], "/", "4"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"s", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Resistor", ",", "ResistorFlipped"}], "]"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"+", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Resistor", ",", "ResistorTurnNumber"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Resistor", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"_", "?", "MatrixQ"}], "[", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Resistor", ",", "ExtraTextArgumentsList"}], "]"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Resistor", ",", "ExtraTextArgumentsList"}], "]"}], "}"}], 
         ",", "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Resistor", ",", "ExtraTextArgumentsList"}], "]"}], 
          "}"}]}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Resistor", ",", "BaseElementDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Resistor", ",", "ResistorDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}], "}"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{
              FractionBox[
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                  RowBox[{"2", " ", "i"}], "-", "1"}], ",", 
                 RowBox[{
                  RowBox[{"-", "s"}], " ", 
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"-", "1"}], ")"}], "i"]}]}], "}"}], "16"], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "n"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n", "/", "8"}], ",", "0"}], "}"}], "}"}]}], "]"}], 
          "]"}], "//", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Resistor", ",", "WrapperFunction"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"str", "===", "\"\<\>\""}], ",", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"Text", "@@", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"str", ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"n", "/", "16"}], ",", "0"}], "}"}], "+", 
                RowBox[{"TD", " ", "TO"}]}]}], "}"}], ",", "extraTextList"}], 
            "]"}]}]}], "]"}], "}"}]}], "]"}], "}"}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500643713191193*^9, 3.500643727314247*^9}, {3.500657119955515*^9, 
   3.500657124374199*^9}, {3.50065715924436*^9, 3.50065719678445*^9}, {
   3.500719479903471*^9, 3.5007195027893543`*^9}, {3.5007545927984324`*^9, 
   3.50075461238065*^9}, {3.50075465369384*^9, 3.500754662255159*^9}, {
   3.5009838344573917`*^9, 3.500983851589716*^9}, {3.500997524645561*^9, 
   3.500997546937904*^9}, {3.500997803484309*^9, 3.500997804994014*^9}, 
   3.501457289947125*^9, {3.623789242635127*^9, 3.623789254900188*^9}, {
   3.623789638021915*^9, 3.6237896402035227`*^9}, {3.623789812804627*^9, 
   3.623789813402132*^9}, {3.6237905161295643`*^9, 3.623790608663458*^9}},
 CellLabel->
  "In[262]:=",ExpressionUUID->"c71facfb-b3b5-4ea3-a80d-14a9db985191"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Diode", "[", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}], "]"}], "]"}], ":=", 
   RowBox[{"OptionValue", "[", 
    RowBox[{"Diode", ",", "DiodeSize"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Diode", "[", 
    RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}], "]"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x1", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Diode", ",", "DiodeFlipped"}], "]"}], ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Diode", ",", "DiodeSize"}], "]"}], ",", "0"}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"x2", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Diode", ",", "DiodeFlipped"}], "]"}], ",", "0", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Diode", ",", "DiodeSize"}], "]"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"a", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Diode", ",", "DiodeSize"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"W", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Diode", ",", "DiodeWidthRatio"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Diode", ",", "BaseElementDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Diode", ",", "DiodeDirectives"}], "]"}], "//", "ToList"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"OptionValue", "[", 
               RowBox[{"Diode", ",", "DiodeBarDirectives"}], "]"}], "//", 
              "ToList"}], ",", 
             RowBox[{"{", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"x2", ",", 
                   RowBox[{"a", " ", 
                    RowBox[{"W", "/", "2"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x2", ",", 
                   RowBox[{
                    RowBox[{"-", "a"}], " ", 
                    RowBox[{"W", "/", "2"}]}]}], "}"}]}], "}"}], "]"}], 
              "}"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{"OptionValue", "[", 
                RowBox[{"Diode", ",", "DiodeFilled"}], "]"}], ",", "Polygon", 
               ",", "Line"}], "]"}], "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"x2", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x1", ",", 
                 RowBox[{"a", " ", 
                  RowBox[{"W", "/", "2"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x1", ",", 
                 RowBox[{
                  RowBox[{"-", "a"}], " ", 
                  RowBox[{"W", "/", "2"}]}]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x2", ",", "0"}], "}"}]}], "}"}], "]"}], "}"}]}], 
          "}"}], "//", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Diode", ",", "WrapperFunction"}], "]"}]}], "}"}]}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500640703136688*^9, 3.5006407081116962`*^9}, {3.5006407582209167`*^9, 
   3.5006407882584352`*^9}, {3.500640960362268*^9, 3.500641044635232*^9}, {
   3.500641113531413*^9, 3.5006411210597878`*^9}, 3.50064115801035*^9, {
   3.5006452786297913`*^9, 3.5006453752368937`*^9}, 3.500645411399068*^9, {
   3.500645453411326*^9, 3.5006454958121223`*^9}, {3.5006456566467953`*^9, 
   3.500645661565691*^9}, {3.500645922366374*^9, 3.50064597217878*^9}, {
   3.500649779301754*^9, 3.5006497979736834`*^9}, {3.500649870827145*^9, 
   3.500649914316717*^9}, {3.500650008428466*^9, 3.500650014624345*^9}, {
   3.500650171943426*^9, 3.50065021826175*^9}, {3.500650300351005*^9, 
   3.500650373979693*^9}, {3.50065042094166*^9, 3.500650424553226*^9}, {
   3.500650471520393*^9, 3.500650493199032*^9}, {3.500650537090392*^9, 
   3.500650578128009*^9}, {3.500650706512969*^9, 3.500650726311035*^9}, {
   3.500650756974347*^9, 3.500650838520691*^9}, {3.500723916357279*^9, 
   3.5007239220239058`*^9}, 3.500723971629901*^9, {3.5007240212345057`*^9, 
   3.500724087079462*^9}, {3.500724129514888*^9, 3.5007241310049143`*^9}, {
   3.500724169606378*^9, 3.500724175856267*^9}, {3.5007245953315783`*^9, 
   3.500724598492942*^9}, 3.50072472724014*^9, {3.5008204562455893`*^9, 
   3.500820459328968*^9}, {3.500983968771069*^9, 3.500983978089324*^9}, {
   3.500997731834711*^9, 3.500997791222969*^9}, 3.5012052614558697`*^9, {
   3.501205341734877*^9, 3.5012053772082577`*^9}, 3.50120542544862*^9, {
   3.50120545935662*^9, 3.501205486230792*^9}, {3.501205556252038*^9, 
   3.5012055875859327`*^9}, {3.501206724038213*^9, 3.501206725910425*^9}, {
   3.5012068361323957`*^9, 3.501206905033782*^9}, {3.501206937620882*^9, 
   3.501206988131181*^9}, {3.5012070595684357`*^9, 3.501207091540125*^9}, {
   3.5012106447906637`*^9, 3.501210677202327*^9}, {3.5012374917674007`*^9, 
   3.501237582014676*^9}, {3.501237644397325*^9, 3.5012376534060783`*^9}, {
   3.50123768441138*^9, 3.5012376856879663`*^9}, {3.5012377316392183`*^9, 
   3.5012377384198637`*^9}, {3.501237800898922*^9, 3.5012378859208717`*^9}, {
   3.5012379513131104`*^9, 3.501238032141226*^9}, {3.501238163194811*^9, 
   3.5012381944918537`*^9}, {3.5012382600121517`*^9, 3.501238264127575*^9}, {
   3.501238799939885*^9, 3.5012388088531113`*^9}, {3.501238858929017*^9, 
   3.501238915290332*^9}, {3.501238994200769*^9, 3.501239004842064*^9}, {
   3.5012419400008698`*^9, 3.501241984815505*^9}, 3.50124202995257*^9, {
   3.501242060373601*^9, 3.501242070987171*^9}, {3.501242141229719*^9, 
   3.5012421633408213`*^9}, {3.501242210526033*^9, 3.501242239720799*^9}, {
   3.501242319620472*^9, 3.5012423912349443`*^9}, {3.501242437603759*^9, 
   3.501242495861433*^9}, {3.5012425317073*^9, 3.501242592884933*^9}, {
   3.5012426306156807`*^9, 3.501242667578734*^9}, {3.501243497292838*^9, 
   3.50124353133911*^9}, {3.501243585691154*^9, 3.5012435933751907`*^9}, {
   3.5012479248369503`*^9, 3.501247925162999*^9}, {3.501248819421567*^9, 
   3.501248836193519*^9}, {3.501249378130898*^9, 3.5012493843915453`*^9}, {
   3.5012494181057873`*^9, 3.501249559301181*^9}, {3.5012495997650557`*^9, 
   3.5012496138862457`*^9}, {3.5012511953769693`*^9, 3.501251196612733*^9}, {
   3.501251237712933*^9, 3.501251274336039*^9}, {3.50125132691621*^9, 
   3.5012513787193336`*^9}, {3.501251410982683*^9, 3.501251428468092*^9}, {
   3.501251892081395*^9, 3.501251920743882*^9}, {3.5012519535007668`*^9, 
   3.5012519587111063`*^9}, {3.50125202986681*^9, 3.5012520789451647`*^9}, {
   3.501252137363474*^9, 3.5012521594542837`*^9}, {3.501252241091761*^9, 
   3.5012522955503263`*^9}, 3.501457290125925*^9},
 CellLabel->
  "In[265]:=",ExpressionUUID->"0fa1b9af-c2af-4a31-87f0-c478399c0048"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DCVoltage", "[", 
   RowBox[{"opts", ":", 
    RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
  RowBox[{"DCVoltage", "[", 
   RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"DCVoltage", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"OptionValue", "[", 
     RowBox[{"DCVoltage", ",", "DCVoltageGap"}], "]"}], "\[Times]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"DCVoltage", ",", "DCVoltageNumberCells"}], "]"}]}], "-", 
      "1"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"DCVoltage", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"s", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCVoltage", ",", "DCVoltageFlipped"}], "]"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"+", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"a", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"DCVoltage", ",", "DCVoltageGap"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"DCVoltage", ",", "DCVoltageNumberCells"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"negScale", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"DCVoltage", ",", "DCVoltageNegativeTerminalScale"}], "]"}]}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"W", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"DCVoltage", ",", "DCVoltageWidth"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCVoltage", ",", "BaseElementDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCVoltage", ",", "DCVoltageDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"OptionValue", "[", 
                 RowBox[{
                 "DCVoltage", ",", "DCVoltageNegativeTerminalDirectives"}], 
                 "]"}], "//", "ToList"}], ",", 
               RowBox[{"{", 
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"1", "-", "s"}], "2"], " ", "a"}], "+", 
                    RowBox[{"2", " ", "i", " ", "a"}]}], ",", 
                    RowBox[{"negScale", " ", "W"}]}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"1", "-", "s"}], "2"], " ", "a"}], "+", 
                    RowBox[{"2", " ", "i", " ", "a"}]}], ",", 
                    RowBox[{
                    RowBox[{"-", "negScale"}], " ", "W"}]}], "}"}]}], "}"}], 
                 "]"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Line", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"1", "+", "s"}], "2"], " ", "a"}], "+", 
                    RowBox[{"2", " ", "i", " ", "a"}]}], ",", "W"}], "}"}], 
                 ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"1", "+", "s"}], "2"], " ", "a"}], "+", 
                    RowBox[{"2", " ", "i", " ", "a"}]}], ",", 
                   RowBox[{"-", "W"}]}], "}"}]}], "}"}], "]"}], "}"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], "//", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCVoltage", ",", "WrapperFunction"}], "]"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCVoltage", ",", "DCVoltageShowPolarity"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"positions", "=", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "1"}], ",", "1"}], "}"}], 
                 RowBox[{"OptionValue", "[", 
                  RowBox[{"DCVoltage", ",", "DCVoltagePolarityOffset"}], 
                  "]"}]}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"1", ",", "1"}], "}"}], 
                  RowBox[{"OptionValue", "[", 
                   RowBox[{"DCVoltage", ",", "DCVoltagePolarityOffset"}], 
                   "]"}]}], "+", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "n"}], "-", "1"}], ")"}], " ", "a"}], 
                   ",", "0"}], "}"}]}]}], "}"}], "//", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"OptionValue", "[", 
                 RowBox[{"DCVoltage", ",", "DCVoltageFlipped"}], "]"}], ",", 
                "Identity", ",", "Reverse"}], "]"}]}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Style", "@@", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"Text", "[", 
                   RowBox[{"\"\<+\>\"", ",", 
                    RowBox[{
                    "positions", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", 
                  RowBox[{"Text", "[", 
                   RowBox[{"\"\<-\>\"", ",", 
                    RowBox[{
                    "positions", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}]}], "}"}], "}"}], ",", 
               RowBox[{
                RowBox[{"OptionValue", "[", 
                 RowBox[{"DCVoltage", ",", "DCVoltagePolarityStyle"}], "]"}], 
                "//", "ToList"}]}], "}"}]}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TO", "=", 
            RowBox[{"With", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"defaultTO", "=", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"OptionValue", "[", 
                   RowBox[{"DCVoltage", ",", "DCVoltageShowPolarity"}], "]"}],
                   ",", 
                  RowBox[{"1.5", 
                   RowBox[{"OptionValue", "[", 
                    RowBox[{"DCVoltage", ",", "DefaultTextOffset"}], "]"}]}], 
                  ",", 
                  RowBox[{"MapAt", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"s", " ", "#"}], "&"}], ",", 
                    RowBox[{"OptionValue", "[", 
                    RowBox[{"DCVoltage", ",", "DefaultDiagonalTextOffset"}], 
                    "]"}], ",", "1"}], "]"}]}], "]"}]}], "}"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Switch", "[", 
               RowBox[{
                RowBox[{"OptionValue", "[", 
                 RowBox[{"DCVoltage", ",", "TextOffset"}], "]"}], ",", 
                "\[IndentingNewLine]", "Automatic", ",", "defaultTO", ",", 
                "\[IndentingNewLine]", "_List", ",", 
                RowBox[{"OptionValue", "[", 
                 RowBox[{"DCVoltage", ",", "TextOffset"}], "]"}], ",", 
                "\[IndentingNewLine]", "_", ",", 
                RowBox[{
                 RowBox[{"OptionValue", "[", 
                  RowBox[{"DCVoltage", ",", "TextOffset"}], "]"}], " ", 
                 "defaultTO"}]}], "]"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"TD", "=", 
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"DCVoltage", ",", "TextOffsetScale"}], "]"}], "/", 
             "4"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"extraTextList", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{
              RowBox[{"OptionValue", "[", 
               RowBox[{"DCVoltage", ",", "ExtraTextArgumentsList"}], "]"}], 
              ",", "\[IndentingNewLine]", "None", ",", 
              RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"_", "?", "MatrixQ"}], "[", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"DCVoltage", ",", "ExtraTextArgumentsList"}], "]"}], 
               "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"DCVoltage", ",", "ExtraTextArgumentsList"}], "]"}], 
               "}"}], ",", "\[IndentingNewLine]", "_", ",", 
              RowBox[{"{", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"DCVoltage", ",", "ExtraTextArgumentsList"}], "]"}], 
               "}"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"str", "===", "\"\<\>\""}], ",", 
           RowBox[{"{", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Text", "@@", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"str", ",", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"n", "-", 
                    RowBox[{"1", "/", "2"}]}], ")"}], " ", "a"}], ",", "0"}], 
                   "}"}], "+", 
                  RowBox[{"TD", " ", "TO"}]}]}], "}"}], ",", 
               "extraTextList"}], "]"}]}], "}"}]}], "]"}]}], "]"}]}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500640703136688*^9, 3.5006407081116962`*^9}, {3.5006407582209167`*^9, 
   3.5006407882584352`*^9}, {3.500640960362268*^9, 3.500641044635232*^9}, {
   3.500641113531413*^9, 3.5006411210597878`*^9}, 3.50064115801035*^9, {
   3.5006452786297913`*^9, 3.5006453752368937`*^9}, 3.500645411399068*^9, {
   3.500645453411326*^9, 3.5006454958121223`*^9}, {3.5006456566467953`*^9, 
   3.500645661565691*^9}, {3.500645922366374*^9, 3.50064597217878*^9}, {
   3.500649779301754*^9, 3.5006497979736834`*^9}, {3.500649870827145*^9, 
   3.500649914316717*^9}, {3.500650008428466*^9, 3.500650014624345*^9}, {
   3.500650171943426*^9, 3.50065021826175*^9}, {3.500650300351005*^9, 
   3.500650373979693*^9}, {3.50065042094166*^9, 3.500650424553226*^9}, {
   3.500650471520393*^9, 3.500650493199032*^9}, {3.500650537090392*^9, 
   3.500650578128009*^9}, {3.500650706512969*^9, 3.500650726311035*^9}, {
   3.500650756974347*^9, 3.500650838520691*^9}, {3.500723916357279*^9, 
   3.5007239220239058`*^9}, 3.500723971629901*^9, {3.5007240212345057`*^9, 
   3.500724087079462*^9}, {3.500724129514888*^9, 3.5007241310049143`*^9}, {
   3.500724169606378*^9, 3.500724175856267*^9}, {3.5007245953315783`*^9, 
   3.500724598492942*^9}, 3.50072472724014*^9, {3.5008204562455893`*^9, 
   3.500820459328968*^9}, {3.500983968771069*^9, 3.500983978089324*^9}, {
   3.500997731834711*^9, 3.500997791222969*^9}, 3.5012052614558697`*^9, {
   3.501205341734877*^9, 3.5012053772082577`*^9}, 3.50120542544862*^9, {
   3.50120545935662*^9, 3.501205486230792*^9}, {3.501205556252038*^9, 
   3.5012055875859327`*^9}, {3.501206724038213*^9, 3.501206725910425*^9}, {
   3.5012068361323957`*^9, 3.501206905033782*^9}, {3.501206937620882*^9, 
   3.501206988131181*^9}, {3.5012070595684357`*^9, 3.501207091540125*^9}, {
   3.5012106447906637`*^9, 3.501210677202327*^9}, {3.5012374917674007`*^9, 
   3.501237582014676*^9}, {3.501237644397325*^9, 3.5012376534060783`*^9}, {
   3.50123768441138*^9, 3.5012376856879663`*^9}, {3.5012377316392183`*^9, 
   3.5012377384198637`*^9}, {3.501237800898922*^9, 3.5012378859208717`*^9}, {
   3.5012379513131104`*^9, 3.501238032141226*^9}, {3.501238163194811*^9, 
   3.5012381944918537`*^9}, {3.5012382600121517`*^9, 3.501238264127575*^9}, {
   3.501238799939885*^9, 3.5012388088531113`*^9}, {3.501238858929017*^9, 
   3.501238915290332*^9}, {3.501238994200769*^9, 3.501239004842064*^9}, {
   3.5012419400008698`*^9, 3.501241984815505*^9}, 3.50124202995257*^9, {
   3.501242060373601*^9, 3.501242070987171*^9}, {3.501242141229719*^9, 
   3.5012421633408213`*^9}, {3.501242210526033*^9, 3.501242239720799*^9}, {
   3.501242319620472*^9, 3.5012423912349443`*^9}, {3.501242437603759*^9, 
   3.501242495861433*^9}, {3.5012425317073*^9, 3.501242592884933*^9}, {
   3.5012426306156807`*^9, 3.501242667578734*^9}, {3.501243497292838*^9, 
   3.50124353133911*^9}, {3.501243585691154*^9, 3.5012435933751907`*^9}, {
   3.5012479248369503`*^9, 3.501247925162999*^9}, 3.501457290315154*^9, {
   3.623790894144746*^9, 3.623790964417911*^9}},
 CellLabel->
  "In[267]:=",ExpressionUUID->"df8271b4-76d4-4d6e-a2d9-d263223f6a73"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Capacitor", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"Capacitor", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Capacitor", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{"OptionValue", "[", 
    RowBox[{"Capacitor", ",", "CapacitorGap"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Capacitor", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Capacitor", ",", "CapacitorGap"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"W", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Capacitor", ",", "CapacitorWidth"}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Capacitor", ",", "BaseElementDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Capacitor", ",", "CapacitorDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", "W"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", 
               RowBox[{"-", "W"}]}], "}"}]}], "}"}], "]"}], ",", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"a", ",", "W"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"a", ",", 
               RowBox[{"-", "W"}]}], "}"}]}], "}"}], "]"}]}], "}"}], "//", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"Capacitor", ",", "WrapperFunction"}], "]"}]}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TO", "=", 
            RowBox[{"With", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"defaultTO", "=", 
                RowBox[{"OptionValue", "[", 
                 RowBox[{"Capacitor", ",", "DefaultDiagonalTextOffset"}], 
                 "]"}]}], "}"}], ",", 
              RowBox[{"Switch", "[", 
               RowBox[{
                RowBox[{"OptionValue", "[", 
                 RowBox[{"Capacitor", ",", "TextOffset"}], "]"}], ",", 
                "\[IndentingNewLine]", "Automatic", ",", "defaultTO", ",", 
                "\[IndentingNewLine]", "_List", ",", 
                RowBox[{"OptionValue", "[", 
                 RowBox[{"Capacitor", ",", "TextOffset"}], "]"}], ",", 
                "\[IndentingNewLine]", "_", ",", 
                RowBox[{
                 RowBox[{"OptionValue", "[", 
                  RowBox[{"Capacitor", ",", "TextOffset"}], "]"}], " ", 
                 "defaultTO"}]}], "]"}]}], "]"}]}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"TD", "=", 
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"Capacitor", ",", "TextOffsetScale"}], "]"}], "/", 
             "4"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"extraTextList", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{
              RowBox[{"OptionValue", "[", 
               RowBox[{"Capacitor", ",", "ExtraTextArgumentsList"}], "]"}], 
              ",", "\[IndentingNewLine]", "None", ",", 
              RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"_", "?", "MatrixQ"}], "[", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"Capacitor", ",", "ExtraTextArgumentsList"}], "]"}], 
               "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"Capacitor", ",", "ExtraTextArgumentsList"}], "]"}], 
               "}"}], ",", "\[IndentingNewLine]", "_", ",", 
              RowBox[{"{", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"Capacitor", ",", "ExtraTextArgumentsList"}], "]"}], 
               "}"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"str", "===", "\"\<\>\""}], ",", 
           RowBox[{"{", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Text", "@@", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"str", ",", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"a", "/", "2"}], ",", "0"}], "}"}], "+", 
                  RowBox[{"TD", " ", "TO"}]}]}], "}"}], ",", 
               "extraTextList"}], "]"}]}], "}"}]}], "]"}]}], "]"}]}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500640703136688*^9, 3.5006407081116962`*^9}, {3.5006407582209167`*^9, 
   3.5006407882584352`*^9}, {3.500640960362268*^9, 3.500641044635232*^9}, {
   3.500641113531413*^9, 3.5006411210597878`*^9}, 3.50064115801035*^9, {
   3.5006452786297913`*^9, 3.5006453752368937`*^9}, 3.500645411399068*^9, {
   3.500645453411326*^9, 3.5006454958121223`*^9}, {3.5006456566467953`*^9, 
   3.500645661565691*^9}, {3.500645922366374*^9, 3.50064597217878*^9}, {
   3.500649779301754*^9, 3.5006497979736834`*^9}, {3.500649870827145*^9, 
   3.500649914316717*^9}, {3.500650008428466*^9, 3.500650014624345*^9}, {
   3.500650171943426*^9, 3.50065021826175*^9}, {3.500650300351005*^9, 
   3.500650373979693*^9}, {3.50065042094166*^9, 3.500650424553226*^9}, {
   3.500650471520393*^9, 3.500650493199032*^9}, {3.500650537090392*^9, 
   3.500650578128009*^9}, {3.500650706512969*^9, 3.500650726311035*^9}, {
   3.500650756974347*^9, 3.500650838520691*^9}, {3.500723916357279*^9, 
   3.5007239220239058`*^9}, 3.500723971629901*^9, {3.5007240212345057`*^9, 
   3.500724087079462*^9}, {3.500724129514888*^9, 3.5007241310049143`*^9}, {
   3.500724169606378*^9, 3.500724175856267*^9}, {3.5007245953315783`*^9, 
   3.500724598492942*^9}, 3.50072472724014*^9, 3.5007522463473597`*^9, {
   3.500752312319449*^9, 3.500752451329389*^9}, {3.5007524848049793`*^9, 
   3.5007526148433523`*^9}, {3.500752960844462*^9, 3.500752967853277*^9}, {
   3.500808980816018*^9, 3.500808987588846*^9}, {3.500986072459168*^9, 
   3.5009860740217037`*^9}, {3.5009877436290083`*^9, 3.500987750811761*^9}, 
   3.500987927327096*^9, {3.500997850874299*^9, 3.5009978778836517`*^9}, 
   3.501457290488874*^9, {3.509806128670454*^9, 3.509806131868367*^9}, {
   3.623791084740254*^9, 3.623791123795307*^9}},
 CellLabel->
  "In[270]:=",ExpressionUUID->"9fa60e29-e794-41db-b3e2-a7968afbd218"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Inductor", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"Inductor", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Inductor", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1.25", "-", 
         RowBox[{".5", " ", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Inductor", ",", "InductorTurnTightness"}], "]"}]}]}], 
        ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Inductor", ",", "InductorTurnNumber"}], "]"}]}], "+", 
         "1"}], ")"}]}], "+", "2"}], ")"}], "/", "11"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Inductor", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Inductor", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "Automatic", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Inductor", ",", "DefaultTextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Inductor", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"OptionValue", "[", 
            RowBox[{"Inductor", ",", "TextOffset"}], "]"}]}], "}"}]}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"TD", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Inductor", ",", "TextOffsetScale"}], "]"}], "/", "4"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"s", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Inductor", ",", "InductorFlipped"}], "]"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"+", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"n", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Inductor", ",", "InductorTurnNumber"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"p", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Inductor", ",", "InductorTurnSegments"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"tightness", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"Inductor", ",", "InductorTurnTightness"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Inductor", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"_", "?", "MatrixQ"}], "[", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Inductor", ",", "ExtraTextArgumentsList"}], "]"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Inductor", ",", "ExtraTextArgumentsList"}], "]"}], "}"}], 
         ",", "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Inductor", ",", "ExtraTextArgumentsList"}], "]"}], 
          "}"}]}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Inductor", ",", "BaseElementDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Inductor", ",", "InductorDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             FractionBox["1", "11"], 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1.25", "-", 
                   RowBox[{".5", " ", "tightness"}]}], ")"}], " ", "t"}], "+",
                 "1", "-", 
                RowBox[{"Cos", "[", 
                 RowBox[{"t", " ", "\[Pi]"}], "]"}]}], ",", 
               RowBox[{"s", " ", 
                RowBox[{"Sin", "[", 
                 RowBox[{"t", " ", "\[Pi]"}], "]"}]}]}], "}"}]}], ",", 
            RowBox[{"{", 
             RowBox[{"t", ",", "0", ",", 
              RowBox[{
               RowBox[{"2", " ", "n"}], "+", "1"}], ",", 
              FractionBox["1", "p"]}], "}"}]}], "]"}], "]"}], "//", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Inductor", ",", "WrapperFunction"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"str", "===", "\"\<\>\""}], ",", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"Text", "@@", 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"str", ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1.25", "-", 
                    RowBox[{".5", " ", "tightness"}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "n"}], "+", "1"}], ")"}]}], "+", "2"}], 
                    ")"}], "/", "22"}], ",", "0"}], "}"}], "+", 
                RowBox[{"TD", " ", "TO"}]}]}], "}"}], ",", "extraTextList"}], 
            "]"}]}]}], "]"}], "}"}]}], "]"}], "}"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500643713191193*^9, 3.500643727314247*^9}, {3.500657119955515*^9, 
   3.500657124374199*^9}, {3.50065715924436*^9, 3.50065719678445*^9}, {
   3.500719479903471*^9, 3.5007195027893543`*^9}, {3.5007545927984324`*^9, 
   3.50075461238065*^9}, {3.50075465369384*^9, 3.500754662255159*^9}, {
   3.500764657369061*^9, 3.500764728744422*^9}, {3.5007656172434597`*^9, 
   3.500765677072062*^9}, {3.5007657615140877`*^9, 3.500765796554839*^9}, {
   3.500765915284171*^9, 3.500765935138419*^9}, 3.5007659723582363`*^9, 
   3.500766262466302*^9, {3.500766547769134*^9, 3.500766578275725*^9}, {
   3.500766769496731*^9, 3.50076679518889*^9}, {3.50076771636374*^9, 
   3.500767728806382*^9}, {3.500767771920876*^9, 3.5007677721071453`*^9}, {
   3.5007680255117826`*^9, 3.500768059627055*^9}, 3.500768140400876*^9, {
   3.500768231674397*^9, 3.500768233629825*^9}, {3.500768615097711*^9, 
   3.5007686344646893`*^9}, {3.500768740590376*^9, 3.500768742345151*^9}, {
   3.500768773291898*^9, 3.50076879369875*^9}, {3.500768902723394*^9, 
   3.500768918324017*^9}, {3.5007689534921494`*^9, 3.5007690107241497`*^9}, {
   3.5007691567416983`*^9, 3.5007691704501657`*^9}, {3.500769280840404*^9, 
   3.500769306139537*^9}, {3.500769921016704*^9, 3.5007699215179873`*^9}, 
   3.500774798624291*^9, {3.5009877696920156`*^9, 3.50098777790211*^9}, {
   3.500997911765929*^9, 3.500997927863719*^9}, 3.50145729066685*^9, {
   3.6237911374191303`*^9, 3.623791145904812*^9}, {3.6237912831241302`*^9, 
   3.623791286820072*^9}},
 CellLabel->
  "In[273]:=",ExpressionUUID->"dccf99cb-f76e-4032-826e-1a74e804887d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"CurrentArrow", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"CurrentArrow", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"CurrentArrow", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], 
   "=", 
   RowBox[{"Switch", "[", 
    RowBox[{
     RowBox[{"OptionValue", "[", "CurrentArrowType", "]"}], ",", 
     "\[IndentingNewLine]", "\"\<Inline Polygon\>\"", ",", 
     RowBox[{"OptionValue", "[", "InlinePolygonalArrowLength", "]"}], ",", 
     "\[IndentingNewLine]", "\"\<Offset Arrow\>\"", ",", 
     RowBox[{"OptionValue", "[", "OffsetArrowLength", "]"}], ",", "_", ",", 
     "0"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"CurrentArrow", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"W", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"CurrentArrow", ",", "CurrentArrowScale"}], "]"}], "/", 
        "2"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"s", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"CurrentArrow", ",", "CurrentArrowFlipped"}], "]"}], ",", 
         RowBox[{"-", "1"}], ",", 
         RowBox[{"+", "1"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"extraOS", "=", 
       RowBox[{
        RowBox[{"1", "/", "4"}], " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"CurrentArrow", ",", "CurrentArrowType"}], "]"}], 
             "===", "\"\<Offset Arrow\>\""}], ",", "\[IndentingNewLine]", 
            RowBox[{"OptionValue", "[", 
             RowBox[{"CurrentArrow", ",", "OffsetArrowOffset"}], "]"}], ",", 
            "0"}], "]"}]}], "}"}]}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"CurrentArrow", ",", "BaseElementDirectives"}], "]"}], "//", 
        "ToList"}], ",", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"CurrentArrow", ",", "CurrentArrowDirectives"}], "]"}], "//",
         "ToList"}], ",", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"CurrentArrow", ",", "CurrentArrowType"}], "]"}], ",", 
         "\[IndentingNewLine]", "\"\<Simple Line\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "8"]}], " ", "s", " ", "W"}], ",", 
               FractionBox["W", "8"]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox["1", "8"], " ", "s", " ", "W"}], ",", "0"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "8"]}], " ", "s", " ", "W"}], ",", 
               RowBox[{"-", 
                FractionBox["W", "8"]}]}], "}"}]}], "}"}], "]"}], "}"}], ",", 
         "\[IndentingNewLine]", "\"\<Simple Polygon\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"Polygon", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "8"]}], " ", "s", " ", "W"}], ",", 
               FractionBox["W", "8"]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox["1", "8"], " ", "s", " ", "W"}], ",", "0"}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", "8"]}], " ", "s", " ", "W"}], ",", 
               RowBox[{"-", 
                FractionBox["W", "8"]}]}], "}"}]}], "}"}], "]"}], "}"}], ",", 
         "\[IndentingNewLine]", "\"\<Inline Polygon\>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"With", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"length", "=", 
              RowBox[{"OptionValue", "[", 
               RowBox[{"CurrentArrow", ",", "InlinePolygonalArrowLength"}], 
               "]"}]}], ",", 
             RowBox[{"wRatio", "=", 
              RowBox[{"2", "/", "3"}]}], ",", 
             RowBox[{"arrowWidthRatio", "=", "1"}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Polygon", "[", "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"s", " ", "length", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "2"}], ",", 
                  RowBox[{
                   RowBox[{"-", "wRatio"}], "/", "2"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"s", " ", "length", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "arrowWidthRatio"}], ")"}], "/", "2"}], 
                  " ", ",", 
                  RowBox[{
                   RowBox[{"-", "wRatio"}], "/", "2"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"s", " ", "length", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "arrowWidthRatio"}], ")"}], "/", "2"}], 
                  " ", ",", 
                  RowBox[{
                   RowBox[{"-", "arrowWidthRatio"}], "/", "2"}]}], "}"}]}], 
               ",", "\[IndentingNewLine]", 
               RowBox[{"s", " ", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"length", "/", "2"}], ",", "0"}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"s", " ", "length", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "arrowWidthRatio"}], ")"}], "/", "2"}], 
                  " ", ",", 
                  RowBox[{"arrowWidthRatio", "/", "2"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"s", " ", "length", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "-", "arrowWidthRatio"}], ")"}], "/", "2"}], 
                  " ", ",", 
                  RowBox[{"wRatio", "/", "2"}]}], "}"}]}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{"s", " ", "length", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "1"}], "/", "2"}], ",", 
                  RowBox[{"wRatio", "/", "2"}]}], "}"}]}]}], "}"}], "]"}], 
            "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
         "\"\<Offset Arrow\>\"", ",", 
         RowBox[{"{", 
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"L", "=", 
              RowBox[{"OptionValue", "[", 
               RowBox[{"CurrentArrow", ",", "OffsetArrowLength"}], "]"}]}], 
             "}"}], ",", 
            RowBox[{"Arrow", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "s"}], " ", 
                   RowBox[{"L", "/", "2"}]}], ",", "0"}], "}"}], "+", 
                "extraOS"}], ",", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"s", " ", 
                   RowBox[{"L", "/", "2"}]}], ",", "0"}], "}"}], "+", 
                "extraOS"}]}], "}"}], "]"}]}], "]"}], "}"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"TO", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{
              RowBox[{"OptionValue", "[", 
               RowBox[{"CurrentArrow", ",", "TextOffset"}], "]"}], ",", 
              "\[IndentingNewLine]", "Automatic", ",", 
              RowBox[{"OptionValue", "[", 
               RowBox[{"CurrentArrow", ",", "DefaultTextOffset"}], "]"}], ",",
               "\[IndentingNewLine]", "_List", ",", 
              RowBox[{"OptionValue", "[", 
               RowBox[{"CurrentArrow", ",", "TextOffset"}], "]"}], ",", 
              "\[IndentingNewLine]", "_", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"OptionValue", "[", 
                 RowBox[{"CurrentArrow", ",", "TextOffset"}], "]"}]}], 
               "}"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"TD", "=", 
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"CurrentArrow", ",", "TextOffsetScale"}], "]"}], "/", 
             "4"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{"extraTextList", "=", 
            RowBox[{"Switch", "[", 
             RowBox[{
              RowBox[{"OptionValue", "[", 
               RowBox[{"CurrentArrow", ",", "ExtraTextArgumentsList"}], "]"}],
               ",", "\[IndentingNewLine]", "None", ",", 
              RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"_", "?", "MatrixQ"}], "[", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"CurrentArrow", ",", "ExtraTextArgumentsList"}], 
                "]"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"CurrentArrow", ",", "ExtraTextArgumentsList"}], 
                "]"}], "}"}], ",", "\[IndentingNewLine]", "_", ",", 
              RowBox[{"{", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"CurrentArrow", ",", "ExtraTextArgumentsList"}], 
                "]"}], "}"}]}], "]"}]}]}], "}"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"str", "===", "\"\<\>\""}], ",", 
           RowBox[{"{", "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"Text", "@@", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"str", ",", 
                 RowBox[{
                  RowBox[{"TD", " ", "TO"}], "+", "extraOS"}]}], "}"}], ",", 
               "extraTextList"}], "]"}]}], "}"}]}], "]"}]}], "]"}]}], "]"}], 
     "}"}]}], "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500640703136688*^9, 3.5006407081116962`*^9}, {3.5006407582209167`*^9, 
   3.5006407882584352`*^9}, {3.500640960362268*^9, 3.500641044635232*^9}, {
   3.500641113531413*^9, 3.5006411210597878`*^9}, 3.50064115801035*^9, {
   3.5006452786297913`*^9, 3.5006453752368937`*^9}, 3.500645411399068*^9, {
   3.500645453411326*^9, 3.5006454958121223`*^9}, {3.5006456566467953`*^9, 
   3.500645661565691*^9}, {3.500645922366374*^9, 3.50064597217878*^9}, {
   3.500649779301754*^9, 3.5006497979736834`*^9}, {3.500649870827145*^9, 
   3.500649914316717*^9}, {3.500650008428466*^9, 3.500650014624345*^9}, {
   3.500650171943426*^9, 3.50065021826175*^9}, {3.500650300351005*^9, 
   3.500650373979693*^9}, {3.50065042094166*^9, 3.500650424553226*^9}, {
   3.500650471520393*^9, 3.500650493199032*^9}, {3.500650537090392*^9, 
   3.500650578128009*^9}, {3.500650706512969*^9, 3.500650726311035*^9}, {
   3.500650756974347*^9, 3.500650838520691*^9}, {3.500723916357279*^9, 
   3.5007239220239058`*^9}, 3.500723971629901*^9, {3.5007240212345057`*^9, 
   3.500724087079462*^9}, {3.500724129514888*^9, 3.5007241310049143`*^9}, {
   3.500724169606378*^9, 3.500724175856267*^9}, {3.5007245953315783`*^9, 
   3.500724598492942*^9}, 3.50072472724014*^9, 3.5007522463473597`*^9, {
   3.500752312319449*^9, 3.500752451329389*^9}, {3.5007524848049793`*^9, 
   3.5007526148433523`*^9}, {3.500752960844462*^9, 3.500752967853277*^9}, {
   3.50077547544827*^9, 3.50077555445686*^9}, {3.500809004282744*^9, 
   3.500809019206952*^9}, {3.50080907518124*^9, 3.50080908519512*^9}, {
   3.5008091551577044`*^9, 3.5008091837080173`*^9}, {3.5008095102812357`*^9, 
   3.500809518816917*^9}, {3.500809642154704*^9, 3.500809670143591*^9}, {
   3.5008097600045547`*^9, 3.500809769116611*^9}, 3.5008105901299334`*^9, 
   3.500810677052433*^9, {3.5008114131434*^9, 3.5008114340778093`*^9}, {
   3.500816170191675*^9, 3.500816171139683*^9}, {3.5009877942105207`*^9, 
   3.50098781401232*^9}, {3.500998000123981*^9, 3.500998021139852*^9}, {
   3.501079390948497*^9, 3.501079469315453*^9}, {3.501165616316246*^9, 
   3.50116567016144*^9}, 3.5011657670925922`*^9, {3.501166039071253*^9, 
   3.501166054820744*^9}, {3.5011660941977882`*^9, 3.5011661899127617`*^9}, {
   3.501166807119604*^9, 3.501166808439405*^9}, {3.5011668781634398`*^9, 
   3.5011668830345097`*^9}, {3.501167825796743*^9, 3.5011679415724373`*^9}, {
   3.5011779677152452`*^9, 3.501178010306046*^9}, {3.5011903546805*^9, 
   3.501190394011549*^9}, {3.501190663832367*^9, 3.501190725701549*^9}, {
   3.5011907745326633`*^9, 3.501190780156953*^9}, {3.501190837003625*^9, 
   3.501190948955323*^9}, {3.5011910347706213`*^9, 3.501191042554832*^9}, {
   3.5011911137111893`*^9, 3.5011911657759047`*^9}, 3.5011912043068933`*^9, {
   3.501191384702833*^9, 3.5011913926807413`*^9}, {3.501192681192501*^9, 
   3.501192741310093*^9}, {3.501192773563843*^9, 3.501192806137034*^9}, {
   3.501192858143498*^9, 3.501192880319964*^9}, {3.5011929119580917`*^9, 
   3.501192989078227*^9}, {3.501193035579371*^9, 3.501193036410047*^9}, {
   3.501193161525825*^9, 3.5011931953154087`*^9}, {3.501193238032709*^9, 
   3.501193241838271*^9}, {3.501193272033909*^9, 3.501193302081985*^9}, {
   3.5011935863718853`*^9, 3.501193600691564*^9}, 3.501193675293662*^9, {
   3.5011971343627*^9, 3.5011971530322638`*^9}, {3.501197369714643*^9, 
   3.501197558467473*^9}, {3.501200946263167*^9, 3.501201065321597*^9}, {
   3.501201305134678*^9, 3.501201307258833*^9}, {3.501201339934854*^9, 
   3.501201357751053*^9}, {3.501201559526112*^9, 3.501201560156043*^9}, {
   3.50120167640177*^9, 3.501201708833942*^9}, {3.501201745623715*^9, 
   3.501201754902279*^9}, {3.501201811625504*^9, 3.501201813333776*^9}, {
   3.5012019202485533`*^9, 3.501201939748238*^9}, {3.501202002019452*^9, 
   3.501202062120941*^9}, {3.501202433708992*^9, 3.5012024796198072`*^9}, 
   3.501457290850073*^9, {3.6237911518166523`*^9, 3.623791161817717*^9}, {
   3.623791268301861*^9, 3.6237912723498774`*^9}},
 CellLabel->
  "In[276]:=",ExpressionUUID->"a688782f-78d2-4f16-9e8b-5fb96fc95758"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ACVoltage", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"ACVoltage", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"ACVoltage", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{"2", " ", 
    RowBox[{"OptionValue", "[", 
     RowBox[{"ACVoltage", ",", "ACVoltageRadius"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"SineReplacementRule", "=", 
   RowBox[{
    RowBox[{"SinePeriod", "[", 
     RowBox[{"r0_List", ",", "T_"}], "]"}], "\[RuleDelayed]", 
    RowBox[{"With", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"A", "=", 
        RowBox[{".35", " ", "T"}]}], "}"}], ",", 
      RowBox[{"Line", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"r0", "+", 
          RowBox[{"{", 
           RowBox[{"t", ",", 
            RowBox[{
             RowBox[{"-", "A"}], " ", 
             RowBox[{"Sin", "[", 
              RowBox[{
               FractionBox[
                RowBox[{"2", " ", "\[Pi]"}], "T"], "t"}], "]"}]}]}], "}"}]}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{
            RowBox[{"-", "T"}], "/", "2"}], ",", 
           RowBox[{"T", "/", "2"}], ",", 
           RowBox[{"T", "/", "20"}]}], "}"}]}], "]"}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"ACVoltage", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"ACVoltage", ",", "ACVoltageRadius"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"T", "=", 
       RowBox[{"2", " ", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"ACVoltage", ",", "ACVoltageImageRatio"}], "]"}], " ", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"ACVoltage", ",", "ACVoltageRadius"}], "]"}]}]}], ",", 
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"ACVoltage", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "Automatic", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"ACVoltage", ",", "DefaultTextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"ACVoltage", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"OptionValue", "[", 
            RowBox[{"ACVoltage", ",", "TextOffset"}], "]"}]}], "}"}]}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"TD", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"ACVoltage", ",", "TextOffsetScale"}], "]"}], "/", "8"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"ACVoltage", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"_", "?", "MatrixQ"}], "[", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"ACVoltage", ",", "ExtraTextArgumentsList"}], "]"}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"ACVoltage", ",", "ExtraTextArgumentsList"}], "]"}], "}"}],
          ",", "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"ACVoltage", ",", "ExtraTextArgumentsList"}], "]"}], 
          "}"}]}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"ACVoltage", ",", "BaseElementDirectives"}], "]"}], "//", 
         "ToList"}], ",", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"ACVoltage", ",", "ACVoltageDirectives"}], "]"}], "//", 
         "ToList"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"R", ",", "0"}], "}"}], ",", "R"}], "]"}], ",", 
          RowBox[{"SinePeriod", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"R", ",", "0"}], "}"}], ",", "T"}], "]"}]}], "}"}]}], 
       "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"str", "===", "\"\<\>\""}], ",", 
         RowBox[{"{", "}"}], ",", 
         RowBox[{"Text", "@@", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"str", ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"R", ",", "0"}], "}"}], "+", 
               RowBox[{"TD", " ", "TO"}], "+", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                 "TO", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  "]"}], " ", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "R"}], "}"}]}]}]}], "}"}], ",", 
            "extraTextList"}], "]"}]}]}], "]"}], "}"}]}], "}"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500643713191193*^9, 3.500643727314247*^9}, {3.500657119955515*^9, 
   3.500657124374199*^9}, {3.50065715924436*^9, 3.50065719678445*^9}, {
   3.500719479903471*^9, 3.5007195027893543`*^9}, {3.5007545927984324`*^9, 
   3.50075461238065*^9}, {3.50075465369384*^9, 3.500754662255159*^9}, {
   3.5009838344573917`*^9, 3.500983851589716*^9}, {3.500997524645561*^9, 
   3.500997546937904*^9}, {3.500997803484309*^9, 3.500997804994014*^9}, {
   3.50126142038507*^9, 3.501261512327283*^9}, {3.5012615729268017`*^9, 
   3.5012615806493797`*^9}, {3.5012622211647053`*^9, 3.501262237558372*^9}, {
   3.5012622720869503`*^9, 3.501262290354177*^9}, {3.501262328849802*^9, 
   3.5012623802986593`*^9}, {3.5012624548406982`*^9, 3.501262485678684*^9}, {
   3.5012625287017384`*^9, 3.501262529637919*^9}, {3.5012625652674522`*^9, 
   3.5012626463160353`*^9}, {3.501264242080875*^9, 3.50126427801676*^9}, {
   3.501277054184112*^9, 3.5012770763273478`*^9}, {3.50127729672932*^9, 
   3.501277382016697*^9}, {3.501277693389759*^9, 3.501277725826048*^9}, {
   3.501281961510553*^9, 3.501281963194569*^9}, {3.501281995657846*^9, 
   3.501281997233572*^9}, {3.501335729540319*^9, 3.5013357675614147`*^9}, {
   3.5013357983116493`*^9, 3.501335892650057*^9}, {3.50133623203017*^9, 
   3.501336249879727*^9}, {3.501336281530416*^9, 3.501336305169012*^9}, {
   3.501336527557317*^9, 3.501336531593772*^9}, {3.501337411032672*^9, 
   3.5013374274074087`*^9}, {3.5013381820964622`*^9, 
   3.5013382047337093`*^9}, {3.50133836043672*^9, 3.5013383618847637`*^9}, {
   3.501338406623918*^9, 3.501338428297943*^9}, {3.501338996626094*^9, 
   3.50133901083494*^9}, {3.501339058362309*^9, 3.501339071706531*^9}, {
   3.501341694416312*^9, 3.501341734351367*^9}, {3.501341963873021*^9, 
   3.5013419642902412`*^9}, 3.5013420030269203`*^9, {3.501345782226775*^9, 
   3.501345782792307*^9}, {3.501419010008972*^9, 3.501419033230175*^9}, {
   3.501419077730846*^9, 3.501419118429433*^9}, {3.5014196304078493`*^9, 
   3.501419630819089*^9}, 3.501457291025931*^9, {3.623791171888644*^9, 
   3.6237911792323*^9}, {3.6237912539403267`*^9, 3.623791257052074*^9}},
 CellLabel->
  "In[279]:=",ExpressionUUID->"6e0748cc-069a-4eaf-adf3-0ac24de5d7a3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DCCurrent", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"DCCurrent", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"DCCurrent", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{"2", " ", 
    RowBox[{"OptionValue", "[", 
     RowBox[{"DCCurrent", ",", "DCCurrentRadius"}], "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"DCCurrent", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"DCCurrent", ",", "DCCurrentRadius"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"sgn", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "DCCurrentFlipped"}], "]"}], ",", 
         RowBox[{"-", "1"}], ",", "1"}], "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"tipL", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "DCCurrentArrowTipLengthRatio"}], "]"}], 
        " ", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "DCCurrentRadius"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"tipW", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "DCCurrentArrowTipWidthRatio"}], "]"}], 
        " ", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "DCCurrentRadius"}], "]"}]}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"AL", "=", 
       RowBox[{"2", "  ", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "DCCurrentImageRatio"}], "]"}], " ", 
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "DCCurrentRadius"}], "]"}]}]}], ",", 
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "Automatic", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "DefaultTextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"OptionValue", "[", 
            RowBox[{"DCCurrent", ",", "TextOffset"}], "]"}]}], "}"}]}], 
        "]"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"TD", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"DCCurrent", ",", "TextOffsetScale"}], "]"}], "/", "8"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"_", "?", "MatrixQ"}], "[", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"DCCurrent", ",", "ExtraTextArgumentsList"}], "]"}], "]"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"DCCurrent", ",", "ExtraTextArgumentsList"}], "]"}], "}"}],
          ",", "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"DCCurrent", ",", "ExtraTextArgumentsList"}], "]"}], 
          "}"}]}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "BaseElementDirectives"}], "]"}], "//", 
         "ToList"}], ",", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"DCCurrent", ",", "DCCurrentDirectives"}], "]"}], "//", 
         "ToList"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Circle", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"R", ",", "0"}], "}"}], ",", "R"}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"DCCurrent", ",", "DCCurrentArrowDirectives"}], "]"}], "//",
              "ToList"}], ",", 
            RowBox[{
             RowBox[{"OptionValue", "[", 
              RowBox[{"DCCurrent", ",", "DCCurrentArrowDirectives"}], "]"}], "//",
              "ToList"}], ",", 
            RowBox[{"With", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"tail", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"R", "-", 
                    RowBox[{"sgn", " ", 
                    RowBox[{"AL", "/", "2"}]}]}], ",", "0"}], "}"}]}], ",", 
                RowBox[{"tip", "=", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"R", "+", 
                    RowBox[{"sgn", " ", 
                    RowBox[{"AL", "/", "2"}]}]}], ",", "0"}], "}"}]}], ",", 
                RowBox[{"\[CapitalDelta]x", "=", 
                 RowBox[{
                  RowBox[{"-", "sgn"}], " ", "tipL"}]}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{"tail", ",", "tip"}], "}"}], "]"}], ",", 
                RowBox[{"Line", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"tip", "+", 
                    RowBox[{"{", 
                    RowBox[{"\[CapitalDelta]x", ",", "tipW"}], "}"}]}], ",", 
                   "tip", ",", 
                   RowBox[{"tip", "+", 
                    RowBox[{"{", 
                    RowBox[{"\[CapitalDelta]x", ",", 
                    RowBox[{"-", "tipW"}]}], "}"}]}]}], "}"}], "]"}]}], 
               "}"}]}], "]"}]}], "]"}]}], "}"}]}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"str", "===", "\"\<\>\""}], ",", 
         RowBox[{"{", "}"}], ",", 
         RowBox[{"Text", "@@", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"str", ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"R", ",", "0"}], "}"}], "+", 
               RowBox[{"TD", " ", "TO"}], "+", 
               RowBox[{
                RowBox[{"Sign", "[", 
                 RowBox[{
                 "TO", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
                  "]"}], " ", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "R"}], "}"}]}]}]}], "}"}], ",", 
            "extraTextList"}], "]"}]}]}], "]"}], "}"}]}], "}"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500643713191193*^9, 3.500643727314247*^9}, {3.500657119955515*^9, 
   3.500657124374199*^9}, {3.50065715924436*^9, 3.50065719678445*^9}, {
   3.500719479903471*^9, 3.5007195027893543`*^9}, {3.5007545927984324`*^9, 
   3.50075461238065*^9}, {3.50075465369384*^9, 3.500754662255159*^9}, {
   3.5009838344573917`*^9, 3.500983851589716*^9}, {3.500997524645561*^9, 
   3.500997546937904*^9}, {3.500997803484309*^9, 3.500997804994014*^9}, {
   3.50126142038507*^9, 3.501261512327283*^9}, {3.5012615729268017`*^9, 
   3.5012615806493797`*^9}, {3.5012622211647053`*^9, 3.501262237558372*^9}, {
   3.5012622720869503`*^9, 3.501262290354177*^9}, {3.501262328849802*^9, 
   3.5012623802986593`*^9}, {3.5012624548406982`*^9, 3.501262485678684*^9}, {
   3.5012625287017384`*^9, 3.501262529637919*^9}, {3.5012625652674522`*^9, 
   3.5012626463160353`*^9}, {3.501264242080875*^9, 3.50126427801676*^9}, {
   3.501277054184112*^9, 3.5012770763273478`*^9}, {3.50127729672932*^9, 
   3.501277382016697*^9}, {3.501277693389759*^9, 3.501277725826048*^9}, {
   3.501281961510553*^9, 3.501281963194569*^9}, {3.501281995657846*^9, 
   3.501281997233572*^9}, {3.501335729540319*^9, 3.5013357675614147`*^9}, {
   3.5013357983116493`*^9, 3.501335892650057*^9}, {3.50133623203017*^9, 
   3.501336249879727*^9}, {3.501336281530416*^9, 3.501336305169012*^9}, {
   3.501336527557317*^9, 3.501336531593772*^9}, {3.501337411032672*^9, 
   3.5013374274074087`*^9}, {3.5013381820964622`*^9, 
   3.5013382047337093`*^9}, {3.50133836043672*^9, 3.5013383618847637`*^9}, {
   3.501338406623918*^9, 3.501338428297943*^9}, {3.501338996626094*^9, 
   3.50133901083494*^9}, {3.501339058362309*^9, 3.501339071706531*^9}, {
   3.501341694416312*^9, 3.501341734351367*^9}, {3.501341963873021*^9, 
   3.5013419642902412`*^9}, 3.5013420030269203`*^9, {3.501345782226775*^9, 
   3.501345782792307*^9}, {3.501419010008972*^9, 3.501419033230175*^9}, {
   3.501419077730846*^9, 3.501419118429433*^9}, {3.5014196304078493`*^9, 
   3.501419630819089*^9}, 3.501457291025931*^9, {3.584883848257278*^9, 
   3.584883998312426*^9}, {3.584885198703899*^9, 3.584885260585709*^9}, 
   3.58488537180752*^9, {3.584885442681584*^9, 3.584885466173808*^9}, 
   3.584885907844654*^9, {3.584885964715431*^9, 3.584885999477921*^9}, {
   3.5848869276969213`*^9, 3.584886928392851*^9}, {3.584886998434527*^9, 
   3.584887004038422*^9}, {3.584887079933609*^9, 3.584887114075049*^9}, {
   3.584887360712306*^9, 3.584887369503151*^9}, {3.584887411921245*^9, 
   3.584887413152837*^9}, {3.5848968570475817`*^9, 3.584896873650296*^9}, {
   3.58489759428264*^9, 3.584897598287624*^9}, {3.585048107282277*^9, 
   3.585048108809554*^9}, {3.585048226892692*^9, 3.5850482617675858`*^9}, {
   3.5850483236419973`*^9, 3.585048354105856*^9}, {3.585048402855854*^9, 
   3.5850484826753387`*^9}, {3.585048640830452*^9, 3.585048707079011*^9}, {
   3.585048744822304*^9, 3.585048776195286*^9}, {3.585048811659829*^9, 
   3.585048930461471*^9}, {3.623791186695649*^9, 3.623791190952777*^9}, {
   3.623791240300872*^9, 3.623791244036614*^9}},
 CellLabel->
  "In[283]:=",ExpressionUUID->"511fbf59-606a-4dd6-aab7-44ce4061ffa7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"InlineMeter", "[", 
     RowBox[{"_", ",", 
      RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=", 
   RowBox[{"2", " ", 
    RowBox[{"OptionValue", "[", 
     RowBox[{"InlineMeter", ",", "InlineMeterRadius"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"InlineMeter", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"R", "=", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"InlineMeter", ",", "InlineMeterRadius"}], "]"}]}], ",", 
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"InlineMeter", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"InlineMeter", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"InlineMeter", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"_", "?", "MatrixQ"}], "[", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"InlineMeter", ",", "ExtraTextArgumentsList"}], "]"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"InlineMeter", ",", "ExtraTextArgumentsList"}], "]"}], 
          "}"}], ",", "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"InlineMeter", ",", "ExtraTextArgumentsList"}], "]"}], 
          "}"}]}], "]"}]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"InlineMeter", ",", "BaseElementDirectives"}], "]"}], "//", 
         "ToList"}], ",", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"InlineMeter", ",", "InlineMeterDirectives"}], "]"}], "//", 
         "ToList"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"Circle", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"R", ",", "0"}], "}"}], ",", "R"}], "]"}], "}"}]}], "]"}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"str", "===", "\"\<\>\""}], ",", 
         RowBox[{"{", "}"}], ",", 
         RowBox[{"Text", "@@", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"str", ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"R", ",", "0"}], "}"}], "+", "TO"}]}], "}"}], ",", 
            "extraTextList"}], "]"}]}]}], "]"}], "}"}]}], "}"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.476106265431602*^9}, {3.476106350488987*^9, 3.476106356370823*^9}, {
   3.476145105819887*^9, 3.4761451366935387`*^9}, {3.4761452122178307`*^9, 
   3.476145213680038*^9}, {3.476145284598528*^9, 3.476145305852442*^9}, {
   3.4761454868386507`*^9, 3.476145496003104*^9}, {3.47614589732745*^9, 
   3.476145912456259*^9}, 3.476145967163652*^9, {3.4761493647997713`*^9, 
   3.476149451794293*^9}, {3.4761494936562643`*^9, 3.476149498176038*^9}, {
   3.476149917522402*^9, 3.4761499200563927`*^9}, {3.47629334147375*^9, 
   3.4762933750880413`*^9}, {3.4762935126094627`*^9, 3.476293587493305*^9}, {
   3.476293666011874*^9, 3.476293669747254*^9}, {3.476358101981777*^9, 
   3.47635810541956*^9}, {3.4763581839134912`*^9, 3.476358243104556*^9}, {
   3.476358338348255*^9, 3.476358340900919*^9}, {3.476358372619032*^9, 
   3.476358447394248*^9}, {3.4763593298746567`*^9, 3.4763593350399513`*^9}, {
   3.47636323368902*^9, 3.476363276544792*^9}, {3.476363819954257*^9, 
   3.476363874042544*^9}, {3.476364061901134*^9, 3.4763640625774*^9}, {
   3.476364554265644*^9, 3.476364555574525*^9}, {3.476364609646782*^9, 
   3.476364610644822*^9}, {3.4763648603058777`*^9, 3.476364919133131*^9}, {
   3.476364996730071*^9, 3.4763650400876207`*^9}, {3.476376829950054*^9, 
   3.476376835338189*^9}, {3.47637827188894*^9, 3.4763782890420723`*^9}, {
   3.4763783508945923`*^9, 3.476378430294673*^9}, 3.47637854411017*^9, {
   3.476381296115612*^9, 3.476381319943941*^9}, {3.476459584736843*^9, 
   3.476459597811346*^9}, {3.476461766277244*^9, 3.476461810849435*^9}, {
   3.47646186886336*^9, 3.476461893414502*^9}, {3.476494495803976*^9, 
   3.476494501637371*^9}, {3.476580400209655*^9, 3.4765804028231373`*^9}, {
   3.476580712171854*^9, 3.476580726795747*^9}, {3.4765809734055853`*^9, 
   3.476581096777669*^9}, {3.4766142186163054`*^9, 3.476614278614653*^9}, {
   3.4766348162607317`*^9, 3.476634872878087*^9}, {3.476635042441646*^9, 
   3.4766350471173477`*^9}, {3.476635909854023*^9, 3.476635910504888*^9}, {
   3.476640179163885*^9, 3.476640262757473*^9}, 3.476641741247692*^9, 
   3.4766417713573217`*^9, {3.476705849598399*^9, 3.476705863369431*^9}, {
   3.4767059213098392`*^9, 3.476705937144906*^9}, {3.476784784631785*^9, 
   3.4767848691231117`*^9}, {3.476784961554618*^9, 3.476784972728201*^9}, {
   3.476785028477751*^9, 3.476785029426512*^9}, {3.476785060821062*^9, 
   3.476785141386537*^9}, {3.4767851959682817`*^9, 3.476785197201254*^9}, {
   3.476785230566751*^9, 3.476785270574827*^9}, {3.47678530521973*^9, 
   3.476785310324977*^9}, 3.476796517098181*^9, 3.4767966013095837`*^9, {
   3.476834673510233*^9, 3.476834674059546*^9}, {3.47683680964467*^9, 
   3.476836817564034*^9}, {3.48338306936169*^9, 3.483383099367302*^9}, {
   3.483383177468894*^9, 3.483383362415865*^9}, {3.48338341493648*^9, 
   3.483383422294755*^9}, {3.4833840089306602`*^9, 3.483384062819622*^9}, {
   3.483384179740383*^9, 3.483384211988596*^9}, {3.4833843079288054`*^9, 
   3.483384343704112*^9}, {3.483395286522684*^9, 3.4833952958023033`*^9}, {
   3.500553166611829*^9, 3.500553167554158*^9}, {3.500553213597383*^9, 
   3.500553220208241*^9}, 3.500600071133379*^9, 3.500600101808152*^9, {
   3.500643713191193*^9, 3.500643727314247*^9}, {3.500657119955515*^9, 
   3.500657124374199*^9}, {3.50065715924436*^9, 3.50065719678445*^9}, {
   3.500719479903471*^9, 3.5007195027893543`*^9}, {3.5007545927984324`*^9, 
   3.50075461238065*^9}, {3.50075465369384*^9, 3.500754662255159*^9}, {
   3.5009838344573917`*^9, 3.500983851589716*^9}, {3.500997524645561*^9, 
   3.500997546937904*^9}, {3.500997803484309*^9, 3.500997804994014*^9}, {
   3.50126142038507*^9, 3.501261512327283*^9}, {3.5012615729268017`*^9, 
   3.5012615806493797`*^9}, {3.5012622211647053`*^9, 3.501262237558372*^9}, {
   3.5012622720869503`*^9, 3.501262290354177*^9}, {3.501262328849802*^9, 
   3.5012623802986593`*^9}, {3.5012624548406982`*^9, 3.501262485678684*^9}, {
   3.5012625287017384`*^9, 3.501262529637919*^9}, {3.5012625652674522`*^9, 
   3.5012626463160353`*^9}, {3.501264242080875*^9, 3.50126427801676*^9}, {
   3.501277054184112*^9, 3.5012770763273478`*^9}, {3.50127729672932*^9, 
   3.501277382016697*^9}, {3.501277693389759*^9, 3.501277725826048*^9}, {
   3.501281961510553*^9, 3.501281963194569*^9}, {3.501281995657846*^9, 
   3.501281997233572*^9}, {3.501335729540319*^9, 3.5013357675614147`*^9}, {
   3.5013357983116493`*^9, 3.501335892650057*^9}, {3.50133623203017*^9, 
   3.501336249879727*^9}, {3.501336281530416*^9, 3.501336305169012*^9}, {
   3.501336527557317*^9, 3.501336531593772*^9}, {3.501337411032672*^9, 
   3.5013374274074087`*^9}, {3.5013381820964622`*^9, 
   3.5013382047337093`*^9}, {3.50133836043672*^9, 3.5013383618847637`*^9}, {
   3.501338406623918*^9, 3.501338428297943*^9}, {3.501338996626094*^9, 
   3.50133901083494*^9}, {3.501339058362309*^9, 3.501339071706531*^9}, {
   3.501341694416312*^9, 3.501341734351367*^9}, {3.501341963873021*^9, 
   3.5013419642902412`*^9}, 3.5013420030269203`*^9, {3.501342679300415*^9, 
   3.501342754179451*^9}, {3.501342860616055*^9, 3.5013429357121353`*^9}, {
   3.501342973387622*^9, 3.501343006129447*^9}, {3.501345575398169*^9, 
   3.501345590695402*^9}, 3.501457291196419*^9, 3.501466794508762*^9, {
   3.6237912007227097`*^9, 3.623791226562414*^9}},
 CellLabel->
  "In[286]:=",ExpressionUUID->"437e1340-61eb-4afc-aa6d-cb2d04f5bb9e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Wire", "[", 
     RowBox[{"x_", ",", "___"}], "]"}], "]"}], ":=", "x"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Wire", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "=", 
   RowBox[{"Wire", "[", 
    RowBox[{
     FractionBox["1", "2"], ",", "opts"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Wire", "[", 
    RowBox[{"x_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"L", "=", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0"}], "}"}]}], "}"}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"OptionValue", "[", 
      RowBox[{"Wire", ",", "WrapperFunction"}], "]"}], "[", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Wire", ",", "WireDirectives"}], "]"}], "//", "ToList"}], 
       ",", 
       RowBox[{"{", "L", "}"}]}], "]"}], "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.4761062825184507`*^9}, {3.476409107968302*^9, 3.476409110150185*^9}, 
   3.476580638576828*^9, {3.476581301627737*^9, 3.476581302954213*^9}, {
   3.4765813461869087`*^9, 3.4765813979524307`*^9}, {3.476581564502816*^9, 
   3.4765815698902273`*^9}, {3.4765816515587378`*^9, 3.476581695319311*^9}, {
   3.4766351276231623`*^9, 3.476635157879249*^9}, {3.4766352382785892`*^9, 
   3.476635314230381*^9}, {3.476635458146373*^9, 3.476635566047284*^9}, {
   3.47663559767447*^9, 3.476635648070559*^9}, {3.476635867784573*^9, 
   3.476635900405279*^9}, {3.476637187631547*^9, 3.476637202920348*^9}, {
   3.476705990144801*^9, 3.4767060229432507`*^9}, {3.4767060837440853`*^9, 
   3.4767060964962797`*^9}, {3.476706186880958*^9, 3.4767062806192493`*^9}, {
   3.476706363497068*^9, 3.4767064379198523`*^9}, {3.47670650106909*^9, 
   3.476706511479824*^9}, {3.4767065519445677`*^9, 3.476706595607278*^9}, 
   3.497222063511217*^9, {3.500553145872471*^9, 3.500553151730908*^9}, {
   3.500553605747304*^9, 3.500553607815424*^9}, {3.500600136097074*^9, 
   3.500600138031823*^9}, {3.500657425141347*^9, 3.500657459279995*^9}, {
   3.500997667605632*^9, 3.500997676602092*^9}, {3.6237907907198343`*^9, 
   3.623790808389333*^9}},
 CellLabel->
  "In[288]:=",ExpressionUUID->"c32d4ee4-b06b-4d87-8cb5-57e3969f03bb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Node", "[", "___", "]"}], "]"}], ":=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Node", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"Node", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Node", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Node", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "Automatic", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Node", ",", "DefaultTextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Node", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"-", 
            RowBox[{"OptionValue", "[", 
             RowBox[{"Node", ",", "TextOffset"}], "]"}]}]}], "}"}]}], "]"}]}],
       ",", "\[IndentingNewLine]", 
      RowBox[{"TD", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Node", ",", "TextOffsetScale"}], "]"}], "/", "4"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Node", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"_", "?", "MatrixQ"}], "[", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Node", ",", "ExtraTextArgumentsList"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Node", ",", "ExtraTextArgumentsList"}], "]"}], "}"}], ",",
          "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Node", ",", "ExtraTextArgumentsList"}], "]"}], "}"}]}], 
        "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Node", ",", "NodeDirectives"}], "]"}], "//", "ToList"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"0", ",", "0"}], "}"}], "]"}], "}"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"str", "===", "\"\<\>\""}], ",", 
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Text", "@@", 
            RowBox[{"Join", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"str", ",", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}], "+", 
                 RowBox[{"TD", " ", "TO"}]}]}], "}"}], ",", "extraTextList"}],
              "]"}]}], "}"}]}], "]"}]}], "]"}], "/.", 
      RowBox[{"OptionValue", "[", 
       RowBox[{"Node", ",", "NodeReplacementRules"}], "]"}]}], "}"}]}], 
   "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.387970635189911*^9, 3.387970650517666*^9}, {
   3.3879713740758333`*^9, 3.387971411717677*^9}, 3.387971480163763*^9, {
   3.441709377820739*^9, 3.44170943186257*^9}, {3.4417095044307003`*^9, 
   3.441709555406608*^9}, {3.441709587004773*^9, 3.441709599410021*^9}, {
   3.441709632186533*^9, 3.441709674580626*^9}, {3.4417097067734528`*^9, 
   3.441709707760992*^9}, {3.441709746213979*^9, 3.441709779679537*^9}, {
   3.4417098111021023`*^9, 3.441709890363329*^9}, {3.441710177492218*^9, 
   3.44171023851083*^9}, 3.441716107361368*^9, {3.442084817931039*^9, 
   3.442084837804591*^9}, {3.476105784753536*^9, 3.476105814589424*^9}, {
   3.476105869267066*^9, 3.476105884702991*^9}, {3.476105943510354*^9, 
   3.4761059786649227`*^9}, {3.476106090891273*^9, 3.476106180600909*^9}, {
   3.476106215289567*^9, 3.476106219950942*^9}, {3.4761062582077303`*^9, 
   3.4761062825184507`*^9}, {3.476409107968302*^9, 3.476409110150185*^9}, 
   3.476580638576828*^9, {3.476581301627737*^9, 3.476581302954213*^9}, {
   3.4765813461869087`*^9, 3.4765813979524307`*^9}, {3.476581564502816*^9, 
   3.4765815698902273`*^9}, {3.4765816515587378`*^9, 3.476581695319311*^9}, {
   3.4766351276231623`*^9, 3.476635157879249*^9}, {3.4766352382785892`*^9, 
   3.476635314230381*^9}, {3.476635458146373*^9, 3.476635566047284*^9}, {
   3.47663559767447*^9, 3.476635648070559*^9}, {3.476635867784573*^9, 
   3.476635900405279*^9}, {3.476637187631547*^9, 3.476637202920348*^9}, {
   3.4766402829387493`*^9, 3.4766403114388227`*^9}, {3.476640357205461*^9, 
   3.476640419050809*^9}, {3.476640549066039*^9, 3.476640561839031*^9}, {
   3.476640622237378*^9, 3.4766406285317373`*^9}, {3.476640685837366*^9, 
   3.4766407085562067`*^9}, 3.476640768177161*^9, {3.476640902607616*^9, 
   3.476640943745417*^9}, {3.476641265998081*^9, 3.476641303356337*^9}, {
   3.4767855275336933`*^9, 3.476785552294959*^9}, {3.4767856640976973`*^9, 
   3.47678567056996*^9}, {3.476796968645376*^9, 3.476796996726417*^9}, 
   3.476797027765362*^9, {3.4767970642438707`*^9, 3.4767970787875843`*^9}, {
   3.476797109707098*^9, 3.476797115217437*^9}, {3.4767971474332943`*^9, 
   3.4767971834574003`*^9}, {3.4768346283367157`*^9, 3.476834660602598*^9}, 
   3.500600253703249*^9, {3.500997634202529*^9, 3.500997645557989*^9}, {
   3.621862195424829*^9, 3.6218622122499104`*^9}, {3.623022888555496*^9, 
   3.623022950160565*^9}, {3.6230231270076923`*^9, 3.623023172516975*^9}, 
   3.623023403687327*^9, {3.623434131947998*^9, 3.62343415897805*^9}, 
   3.6234342751769133`*^9, 3.623434312882184*^9, {3.623792051266561*^9, 
   3.6237920895829372`*^9}},
 CellLabel->
  "In[291]:=",ExpressionUUID->"231d08ff-b1d8-4ae8-977a-0f863f6a516e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Size", "[", 
    RowBox[{"Ground", "[", "___", "]"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ground", "[", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], ":=", 
   RowBox[{"Ground", "[", 
    RowBox[{"\"\<\>\"", ",", "opts"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Draw", "[", 
   RowBox[{"Ground", "[", 
    RowBox[{"str_", ",", 
     RowBox[{"OptionsPattern", "[", "DrawCircuit", "]"}]}], "]"}], "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"W", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Ground", ",", "GroundScale"}], "]"}], "/", "2"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"TO", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Ground", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "Automatic", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Ground", ",", "DefaultTextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_List", ",", 
         RowBox[{"OptionValue", "[", 
          RowBox[{"Ground", ",", "TextOffset"}], "]"}], ",", 
         "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{"OptionValue", "[", 
            RowBox[{"Ground", ",", "TextOffset"}], "]"}]}], "}"}]}], "]"}]}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"TD", "=", 
       RowBox[{
        RowBox[{"OptionValue", "[", 
         RowBox[{"Ground", ",", "TextOffsetScale"}], "]"}], "/", "4"}]}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"extraTextList", "=", 
       RowBox[{"Switch", "[", 
        RowBox[{
         RowBox[{"OptionValue", "[", 
          RowBox[{"Ground", ",", "ExtraTextArgumentsList"}], "]"}], ",", 
         "\[IndentingNewLine]", "None", ",", 
         RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "_", ",", 
         RowBox[{"{", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"Ground", ",", "ExtraTextArgumentsList"}], "]"}], "}"}]}], 
        "]"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"With", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"yInterpolate", "=", 
         RowBox[{"\[Lambda]", "\[Function]", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"OptionValue", "[", 
                RowBox[{"Ground", ",", "GroundOffsetRatio"}], "]"}]}], " ", 
              "W"}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Lambda]"}], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"OptionValue", "[", 
                 RowBox[{"Ground", ",", "GroundOffsetRatio"}], "]"}]}], " ", 
               "W"}], "-", 
              RowBox[{
               RowBox[{"OptionValue", "[", 
                RowBox[{"Ground", ",", "GroundHeightRatio"}], "]"}], " ", 
               "W"}]}], ")"}]}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"wInterpolate", "=", 
         RowBox[{"\[Lambda]", "\[Function]", 
          RowBox[{
           RowBox[{"\[Lambda]", " ", "W"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "\[Lambda]"}], ")"}], 
            RowBox[{"OptionValue", "[", 
             RowBox[{"Ground", ",", "GroundMinWidthRatio"}], "]"}], " ", 
            "W"}]}]}]}]}], " ", "}"}], ",", 
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"downGround", "=", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"OptionValue", "[", 
                RowBox[{"Ground", ",", "GroundOffsetRatio"}], "]"}], "===", 
               "0"}], ",", 
              RowBox[{"{", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"Join", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"OptionValue", "[", 
                   RowBox[{"Ground", ",", "GroundOffsetDirectives"}], "]"}], "//",
                   "ToList"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"Line", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"W", " ", 
                    RowBox[{"OptionValue", "[", 
                    RowBox[{"Ground", ",", "GroundOffsetRatio"}], "]"}]}]}], 
                    "}"}]}]}], "}"}], "]"}], "}"}]}], "]"}], "}"}]}], "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"OptionValue", "[", 
                RowBox[{"Ground", ",", "BaseElementDirectives"}], "]"}], ",", 
               RowBox[{
                RowBox[{"OptionValue", "[", 
                 RowBox[{"Ground", ",", "GroundDirectives"}], "]"}], "//", 
                "ToList"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"Line", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"wInterpolate", "[", "\[Lambda]", "]"}]}], "/", 
                    "2"}], ",", 
                    RowBox[{"yInterpolate", "[", "\[Lambda]", "]"}]}], "}"}], 
                    ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"wInterpolate", "[", "\[Lambda]", "]"}], "/", 
                    "2"}], ",", 
                    RowBox[{"yInterpolate", "[", "\[Lambda]", "]"}]}], 
                    "}"}]}], "}"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"\[Lambda]", ",", "0", ",", "1", ",", 
                   FractionBox["1", 
                    RowBox[{
                    RowBox[{"OptionValue", "[", 
                    RowBox[{"Ground", ",", "GroundLineNumber"}], "]"}], "-", 
                    "1"}]]}], "}"}]}], "]"}]}], "]"}], "}"}]}], "]"}]}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"With", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\[Theta]", "=", 
              RowBox[{"OptionValue", "[", 
               RowBox[{"Ground", ",", "GroundOrientation"}], "]"}]}], "}"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"\[Theta]", "===", "\"\<Down\>\""}], ",", 
              "\[IndentingNewLine]", "downGround", ",", "\[IndentingNewLine]", 
              RowBox[{"With", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"A", "=", 
                  RowBox[{"RotationMatrix", "[", 
                   RowBox[{"Switch", "[", 
                    RowBox[{"\[Theta]", ",", "\"\<Right\>\"", ",", 
                    RowBox[{"\[Pi]", "/", "2"}], ",", "\"\<Up\>\"", ",", 
                    "\[Pi]", ",", "\"\<Left\>\"", ",", 
                    RowBox[{
                    RowBox[{"-", "\[Pi]"}], "/", "2"}], ",", "_", ",", 
                    RowBox[{"\[Theta]", "+", 
                    RowBox[{"\[Pi]", "/", "2"}]}]}], "]"}], "]"}]}], "}"}], 
                ",", 
                RowBox[{"downGround", "/.", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"Line", "[", 
                    RowBox[{"{", "r__", "}"}], "]"}], "\[RuleDelayed]", 
                   RowBox[{"Line", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"A", ".", "#"}], "&"}], "/@", 
                    RowBox[{"{", "r", "}"}]}], "]"}]}], ")"}]}]}], "]"}]}], 
             "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"str", "===", "\"\<\>\""}], ",", 
             RowBox[{"{", "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"Text", "@@", 
               RowBox[{"Join", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"str", ",", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"OptionValue", "[", 
                    RowBox[{"Ground", ",", "GroundOffsetRatio"}], "]"}]}], 
                    " ", "W"}], "-", 
                    RowBox[{
                    RowBox[{"OptionValue", "[", 
                    RowBox[{"Ground", ",", "GroundHeightRatio"}], "]"}], " ", 
                    "W"}]}], ")"}]}], "}"}], "+", 
                    RowBox[{
                    RowBox[{"-", "TD"}], " ", "TO"}]}]}], "}"}], ",", 
                 "extraTextList"}], "]"}]}], "}"}]}], "]"}], "}"}]}], "}"}]}],
        "\[IndentingNewLine]", "]"}]}], "]"}]}], "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.623684505858103*^9, 3.623684538596374*^9}, {
   3.623684663016014*^9, 3.623684738626626*^9}, {3.623684795274157*^9, 
   3.623684831456032*^9}, {3.623684873685375*^9, 3.623684951278337*^9}, {
   3.623685003491013*^9, 3.62368502235947*^9}, {3.6236850983528748`*^9, 
   3.6236851171397133`*^9}, {3.623685162825673*^9, 3.6236851746846523`*^9}, {
   3.623685205434758*^9, 3.623685234234899*^9}, 3.6236852916018467`*^9, {
   3.6236853246191673`*^9, 3.623685325347322*^9}, 3.6237066787681217`*^9, {
   3.623706814084893*^9, 3.623706822216679*^9}, {3.623706901128285*^9, 
   3.62370694137901*^9}, {3.623707235269721*^9, 3.623707241342078*^9}, {
   3.623707413340138*^9, 3.623707414810409*^9}, 3.623707834849559*^9, {
   3.623710376423098*^9, 3.623710378064146*^9}, 3.623710439465578*^9, {
   3.62371124348457*^9, 3.623711245851328*^9}, {3.623714011086316*^9, 
   3.6237141118706417`*^9}, {3.623714206231928*^9, 3.623714339196951*^9}, {
   3.623714373959323*^9, 3.623714681314602*^9}, {3.6237147132661037`*^9, 
   3.623714714919191*^9}, {3.623714853554451*^9, 3.6237148567944193`*^9}, 
   3.623717188950241*^9, {3.623717927119376*^9, 3.6237179295927477`*^9}, {
   3.6237181893629303`*^9, 3.6237182286215467`*^9}, {3.6237183119404907`*^9, 
   3.6237183765606003`*^9}, 3.623718744206182*^9, {3.623719745279771*^9, 
   3.623719755670257*^9}, {3.6237920171471243`*^9, 3.623792024386807*^9}, {
   3.623792185015231*^9, 3.623792200737542*^9}, {3.6237923268331003`*^9, 
   3.623792330744111*^9}, {3.623792906368121*^9, 3.623792915416411*^9}, {
   3.62379313427782*^9, 3.623793148660955*^9}, {3.6237934949505863`*^9, 
   3.623793530153948*^9}, {3.6237937410306177`*^9, 3.623793761505972*^9}, {
   3.623793794644146*^9, 3.6237937965317307`*^9}, 3.623793910788437*^9, 
   3.6237940536973543`*^9, 3.6237988677669163`*^9, 3.623799180157927*^9},
 CellLabel->
  "In[294]:=",ExpressionUUID->"7391ee7a-9ab2-45df-bc00-7ca938dcda8d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"End", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6218722503001957`*^9, 3.621872254737378*^9}},
 CellLabel->
  "In[297]:=",ExpressionUUID->"48dfd724-1060-4d0d-822c-83e8f9f4cd1c"],

Cell[BoxData["\<\"Circuit`Private`\"\>"], "Output",
 CellChangeTimes->{3.81327655390939*^9, 3.813276795002544*^9, 
  3.813277224937738*^9, 3.813277333843779*^9, 3.8132778453028593`*^9},
 CellLabel->
  "Out[297]=",ExpressionUUID->"a8279f58-fb38-49c0-9c63-b7f76a1e7218"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6218722583980627`*^9, 3.621872264907489*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"607b049a-2cb0-4572-b177-b3f7634c5640"]
},
AutoGeneratedPackage->Automatic,
WindowSize->{892, 709},
WindowMargins->{{Automatic, 420}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 9, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8143ce36-1703-434b-bc7e-66d30adb8693"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 307, 6, 57, "Input",ExpressionUUID->"1e443fd8-a20d-4c31-8983-0abfb52fa59a",
 InitializationCell->True],
Cell[877, 30, 296, 5, 42, "Output",ExpressionUUID->"f1010c7f-e8d8-461c-b698-023490da1c01"]
}, Open  ]],
Cell[1188, 38, 18557, 301, 2323, "Input",ExpressionUUID->"2aa654ed-2356-4d99-a71f-a6231d4d0991",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[19770, 343, 12522, 340, 3282, "Input",ExpressionUUID->"a6e80938-2861-4c5e-a712-639360719455",
 InitializationCell->True],
Cell[32295, 685, 305, 5, 42, "Output",ExpressionUUID->"e97e8280-42be-40c7-a0b1-e1ed4500542f"],
Cell[32603, 692, 391, 7, 42, "Output",ExpressionUUID->"8ad8db60-9104-40bf-a8c9-d79351d2715a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33031, 704, 445, 11, 110, "Input",ExpressionUUID->"38712928-3f06-4d03-b491-599a7ed5b535",
 InitializationCell->True],
Cell[33479, 717, 260, 4, 42, "Output",ExpressionUUID->"0a8eeb26-44f5-468d-a28c-0dede4a84bf0"],
Cell[33742, 723, 260, 4, 42, "Output",ExpressionUUID->"2e554868-9fed-4788-a552-07fa3838f566"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34039, 732, 250, 5, 57, "Input",ExpressionUUID->"affaa940-cf5d-4441-8db9-65f5d324642d",
 InitializationCell->True],
Cell[34292, 739, 269, 4, 42, "Output",ExpressionUUID->"4392c946-b87a-46a0-9e3a-b07a10476354"]
}, Open  ]],
Cell[34576, 746, 14123, 200, 164, "Input",ExpressionUUID->"c4f1f428-9b85-4857-ae16-7a32586bfe29",
 InitializationCell->True],
Cell[48702, 948, 13913, 239, 968, "Input",ExpressionUUID->"44459c2a-16b7-4a72-80ce-ab4e691bd345",
 InitializationCell->True],
Cell[62618, 1189, 15185, 239, 448, "Input",ExpressionUUID->"4c603516-8ac3-44f5-b913-22e1272530e6",
 InitializationCell->True],
Cell[77806, 1430, 41235, 816, 2800, "Input",ExpressionUUID->"f40b903f-9267-4463-8b2f-f7bc9bf66ff0",
 InitializationCell->True],
Cell[119044, 2248, 800, 17, 57, "Input",ExpressionUUID->"0741f790-8e69-4b0b-8479-428ebf9d2a39",
 InitializationCell->True],
Cell[119847, 2267, 7245, 129, 240, "Input",ExpressionUUID->"46b4194b-fc61-4812-89db-1071af0eee69",
 InitializationCell->True],
Cell[127095, 2398, 1926, 44, 162, "Input",ExpressionUUID->"20110727-c57a-4248-bf05-54a0bef7ab28",
 InitializationCell->True],
Cell[129024, 2444, 3475, 81, 292, "Input",ExpressionUUID->"0efd2716-bd22-40d9-b430-f515e7894378",
 InitializationCell->True],
Cell[132502, 2527, 3482, 84, 399, "Input",ExpressionUUID->"83eed3b9-c985-4dfa-bd35-68e1432959ca",
 InitializationCell->True],
Cell[135987, 2613, 9987, 204, 707, "Input",ExpressionUUID->"c71facfb-b3b5-4ea3-a80d-14a9db985191",
 InitializationCell->True],
Cell[145977, 2819, 11487, 208, 474, "Input",ExpressionUUID->"0fa1b9af-c2af-4a31-87f0-c478399c0048",
 InitializationCell->True],
Cell[157467, 3029, 18230, 373, 1360, "Input",ExpressionUUID->"df8271b4-76d4-4d6e-a2d9-d263223f6a73",
 InitializationCell->True],
Cell[175700, 3404, 11173, 215, 760, "Input",ExpressionUUID->"9fa60e29-e794-41db-b3e2-a7968afbd218",
 InitializationCell->True],
Cell[186876, 3621, 11890, 243, 782, "Input",ExpressionUUID->"dccf99cb-f76e-4032-826e-1a74e804887d",
 InitializationCell->True],
Cell[198769, 3866, 19379, 393, 1327, "Input",ExpressionUUID->"a688782f-78d2-4f16-9e8b-5fb96fc95758",
 InitializationCell->True],
Cell[218151, 4261, 12006, 241, 738, "Input",ExpressionUUID->"6e0748cc-069a-4eaf-adf3-0ac24de5d7a3",
 InitializationCell->True],
Cell[230160, 4504, 14588, 288, 890, "Input",ExpressionUUID->"511fbf59-606a-4dd6-aab7-44ce4061ffa7",
 InitializationCell->True],
Cell[244751, 4794, 9560, 175, 474, "Input",ExpressionUUID->"437e1340-61eb-4afc-aa6d-cb2d04f5bb9e",
 InitializationCell->True],
Cell[254314, 4971, 3569, 75, 236, "Input",ExpressionUUID->"c32d4ee4-b06b-4d87-8cb5-57e3969f03bb",
 InitializationCell->True],
Cell[257886, 5048, 6263, 133, 474, "Input",ExpressionUUID->"231d08ff-b1d8-4ae8-977a-0f863f6a516e",
 InitializationCell->True],
Cell[264152, 5183, 11500, 264, 1238, "Input",ExpressionUUID->"7391ee7a-9ab2-45df-bc00-7ca938dcda8d",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[275677, 5451, 229, 5, 57, "Input",ExpressionUUID->"48dfd724-1060-4d0d-822c-83e8f9f4cd1c",
 InitializationCell->True],
Cell[275909, 5458, 268, 4, 42, "Output",ExpressionUUID->"a8279f58-fb38-49c0-9c63-b7f76a1e7218"]
}, Open  ]],
Cell[276192, 5465, 236, 5, 57, "Input",ExpressionUUID->"607b049a-2cb0-4572-b177-b3f7634c5640",
 InitializationCell->True]
}
]
*)

